@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2010-03-04 14:24:05 +0100 (Thu, 04 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10373 $
+ *     $Date: 2010-05-08 13:09:21 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10907 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -308,7 +308,7 @@ public:
     // Count number of end and stallss
     count(*this, s, stallval, IRT_EQ, nstall);
     count(*this, s,   endval, IRT_EQ,   nend);
-    post(*this, nstall+nend == maxstall);
+    rel(*this, nstall+nend == maxstall);
 
     // Make sure nothing is overloaded
     IntSet one(1, 1);
@@ -335,7 +335,7 @@ public:
       REG r = *REG(notend) + REG(notstallend) + *REG(endval);
       extensional(*this, s, r);
       for (int pos = s.size()-1, i = 0; i < maxstall; ++i, --pos) {
-        post(*this, imp(~(nend > i), ~(s[pos]==endval)));
+        rel(*this, (nend > i) >> (s[pos]==endval));
       }
     } break;
     case PROP_CUSTOM: {
