@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-04-02 20:58:46 +0200 (Thu, 02 Apr 2009) $ by $Author: schulte $
- *     $Revision: 8649 $
+ *     $Date: 2010-05-08 19:24:20 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10910 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -107,54 +107,28 @@ public:
     IntSet germanDS(germanSpeaking, noOfGermanSpeaking);
 
     for (int i=0; i<noOfFlights; i++) {
-      IntVarArray required(*this,5,0,noOfEmployees-1);
-      SetVar team = flight[i];
-
-      int N        = requiredCrew[i].staff;
-      int NStew    = requiredCrew[i].stewards;
-      int NHost    = requiredCrew[i].hostesses;
-      int NFrench  = requiredCrew[i].french;
-      int NSpanish = requiredCrew[i].spanish;
-      int NGerman  = requiredCrew[i].german;
-
-      // The team has N members (as required by the specification)
-      cardinality(*this, team,N,N);
-
-      // Make sure that enough team members of different categories are on board
-
-      SetVar stewardsInTeam(*this);
-      rel(*this, team, SOT_INTER, stewardsDS, SRT_EQ, stewardsInTeam);
-      cardinality(*this, stewardsInTeam, required[0]);
-      rel(*this, required[0], IRT_GQ, NStew);
-
-      SetVar hostessesInTeam(*this);
-      rel(*this, team, SOT_INTER, hostessesDS, SRT_EQ, hostessesInTeam);
-      cardinality(*this, hostessesInTeam, required[1]);
-      rel(*this, required[1], IRT_GQ, NHost);
-
-      SetVar spanishInTeam(*this);
-      rel(*this, team, SOT_INTER, spanishDS, SRT_EQ, spanishInTeam);
-      cardinality(*this, spanishInTeam, required[2]);
-      rel(*this, required[2], IRT_GQ, NSpanish);
-
-      SetVar frenchInTeam(*this);
-      rel(*this, team, SOT_INTER, frenchDS, SRT_EQ, frenchInTeam);
-      cardinality(*this, frenchInTeam, required[3]);
-      rel(*this, required[3], IRT_GQ, NFrench);
-
-      SetVar germanInTeam(*this);
-      rel(*this, team, SOT_INTER, germanDS, SRT_EQ, germanInTeam);
-      cardinality(*this, germanInTeam, required[4]);
-      rel(*this, required[4], IRT_GQ, NGerman);
+      // The flight has staff as required by the specification
+      rel(*this, cardinality(flight[i]) == requiredCrew[i].staff);
 
+      // Enough members of different categories are on board
+      rel(*this, cardinality(flight[i] & stewardsDS) >= 
+          requiredCrew[i].stewards);
+      rel(*this, cardinality(flight[i] & hostessesDS) >=
+          requiredCrew[i].hostesses);
+      rel(*this, cardinality(flight[i] & spanishDS) >=
+          requiredCrew[i].spanish);
+      rel(*this, cardinality(flight[i] & frenchDS) >=
+          requiredCrew[i].french);
+      rel(*this, cardinality(flight[i] & germanDS) >=
+          requiredCrew[i].german);
     }
 
     // No crew member of flight i works on flights i+1 and i+2
     for (int i=0; i<noOfFlights-2; i++) {
-      rel(*this, flight[i], SRT_DISJ, flight[i+1]);
-      rel(*this, flight[i], SRT_DISJ, flight[i+2]);
+      rel(*this, flight[i] || flight[i+1]);
+      rel(*this, flight[i] || flight[i+2]);
     }
-    rel(*this, flight[noOfFlights-2], SRT_DISJ, flight[noOfFlights-1]);
+    rel(*this, flight[noOfFlights-2] || flight[noOfFlights-1]);
 
     branch(*this, flight, SET_VAR_NONE, SET_VAL_MIN_INC);
   }
