@@ -9,8 +9,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2009-09-30 12:12:35 +0200 (Wed, 30 Sep 2009) $ by $Author: tack $
- *     $Revision: 9779 $
+ *     $Date: 2010-05-08 12:56:03 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10906 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -276,11 +276,8 @@ public:
 
     // N-queens constraints
     distinct(*this, queens, ICL_DOM);
-    IntArgs koff(n);
-    for (int i = n; i--; ) koff[i] = i;
-    distinct(*this, koff, queens, ICL_DOM);
-    for (int i = n; i--; ) koff[i] = -i;
-    distinct(*this, koff, queens, ICL_DOM);
+    distinct(*this, IntArgs::create(n,0,1), queens, ICL_DOM);
+    distinct(*this, IntArgs::create(n,0,-1), queens, ICL_DOM);
 
     // N-rooks constraints
     distinct(*this,  rooks, ICL_DOM);
@@ -310,14 +307,14 @@ public:
     if (opt.propagation() == PROP_TUPLE_SET) {
       IntVarArgs b(s.size());
       for (int i = s.size(); i--; )
-        b[i] = channel(*this, post(*this, ~(s[i] == B)));
+        b[i] = channel(*this, expr(*this, (s[i] == B)));
       extensional(*this, b, bishops, EPK_DEF, opt.icl());
     }
 
     // Handle knigths
     // Connect knigths to board
     for(int i = n*n; i--; )
-      knights[i] = post(*this, ~(s[i] == K));
+      knights[i] = expr(*this, (s[i] == K));
     knight_constraints();
 
 
