@@ -9,8 +9,8 @@
  *     Mikael Lagerkvist, 2006
  *
  *  Last modified:
- *     $Date: 2009-08-26 21:10:00 +0200 (Wed, 26 Aug 2009) $ by $Author: schulte $
- *     $Revision: 9632 $
+ *     $Date: 2010-05-08 19:24:20 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10910 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -104,13 +104,13 @@ public:
     // Initialize the separator column in the board
     for (int i=0; i<height; i++) {
       board[i*(width+1)+8] = -1;
-      post(*this, x[i*(width+1)+8]==28);
+      rel(*this, x[i*(width+1)+8]==28);
     }
 
     // Variables representing the coordinates of the first
     // and second half of a domino piece
-    IntVarArray p1(*this, 28, 0, (width+1)*height-1);
-    IntVarArray p2(*this, 28, 0, (width+1)*height-1);
+    IntVarArgs p1(*this, 28, 0, (width+1)*height-1);
+    IntVarArgs p2(*this, 28, 0, (width+1)*height-1);
 
 
     if (opt.propagation() == PROP_ELEMENT) {
@@ -128,7 +128,7 @@ public:
           // at the right border is not adjacent to the first field
           // in the next row.
           IntVar diff(*this, possibleDiffs);
-          abs(*this, minus(*this, p1[dominoCount], p2[dominoCount]),
+          abs(*this, expr(*this, p1[dominoCount]-p2[dominoCount]),
               diff, ICL_DOM);
 
           // If the piece is symmetrical, order the locations
