@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2009-08-26 21:10:00 +0200 (Wed, 26 Aug 2009) $ by $Author: schulte $
- *     $Revision: 9632 $
+ *     $Date: 2010-05-08 13:09:21 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10907 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -48,10 +48,10 @@ using namespace Gecode;
  */
 class EFPAOptions : public Options {
 private:
-  Driver::UnsignedIntOption _v;   ///< Parameter v.
-  Driver::UnsignedIntOption _q;   ///< Parameter q.
-  Driver::UnsignedIntOption _l;   ///< Parameter lambda.
-  Driver::UnsignedIntOption _d;   ///< Parameter d.
+  Driver::UnsignedIntOption _v;   ///< Parameter v
+  Driver::UnsignedIntOption _q;   ///< Parameter q
+  Driver::UnsignedIntOption _l;   ///< Parameter lambda
+  Driver::UnsignedIntOption _d;   ///< Parameter d
   Driver::StringOption _permutation; ///< Use permutation constraints if d=4
 
 public:
@@ -230,7 +230,7 @@ public:
           // ...into values in row2
           for (int i = 0; i < d; ++i) {
             IntVar index(*this, 0, 2*d);
-            post(*this, cform*d + i == index);
+            rel(*this, cform*d + i == index);
             IntVar value(*this, 1, q);
             element(*this, _p, index, value);
             element(*this, row2, perm[i], value);
@@ -238,19 +238,19 @@ public:
 
           /* Rows r1 and r2 are equal at indices not in perm */
           // uses Boolean representations pib for perm[i]
-          BoolVarArray p1b(*this, n, 0, 1);
+          BoolVarArgs p1b(*this, n, 0, 1);
           channel(*this, p1b, perm[0]);
-          BoolVarArray p2b(*this, n, 0, 1);
+          BoolVarArgs p2b(*this, n, 0, 1);
           channel(*this, p2b, perm[1]);
-          BoolVarArray p3b(*this, n, 0, 1);
+          BoolVarArgs p3b(*this, n, 0, 1);
           channel(*this, p3b, perm[2]);
-          BoolVarArray p4b(*this, n, 0, 1);
+          BoolVarArgs p4b(*this, n, 0, 1);
           channel(*this, p4b, perm[3]);
           for (int i = n; i--; ) {
             // No perm-variable uses i is equivalent to the reows
             // being equal at i
-            post(*this, tt(eqv(!p1b[i] && !p2b[i] && !p3b[i] && !p4b[i],
-                               ~(row1[i] == row2[i]))));
+            rel(*this, (!p1b[i] && !p2b[i] && !p3b[i] && !p4b[i]) ==
+                       (row1[i] == row2[i]));
           }
           
           /* Constraints for fixing the permutation */
@@ -268,8 +268,7 @@ public:
           rel(*this, perm[0], IRT_LE, perm[2]);
           rel(*this, perm[0], IRT_LE, perm[3]);
           // Conditional ordering constraint - symmetry breaking for cform 0
-          post(*this, tt(imp(!cformb,
-                             ~(perm[2] < perm[3]))));
+          rel(*this, (!cformb) >> (perm[2] < perm[3]));
         }
       }
     }
