@@ -7,8 +7,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2009-04-02 20:58:46 +0200 (Thu, 02 Apr 2009) $ by $Author: schulte $
- *     $Revision: 8649 $
+ *     $Date: 2010-05-05 21:52:55 +0200 (Wed, 05 May 2010) $ by $Author: schulte $
+ *     $Revision: 10865 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -85,8 +85,8 @@ public:
     };
     // Post equation constraints
     for (int i = e_n; i--; ) {
-      IntArgs c(7,eqs[i][1],eqs[i][2],eqs[i][3],eqs[i][4],
-                eqs[i][5],eqs[i][6],eqs[i][7]);
+      IntArgs c(x_n, eqs[i][1],eqs[i][2],eqs[i][3],eqs[i][4],
+                     eqs[i][5],eqs[i][6],eqs[i][7]);
       linear(*this, c, x, IRT_EQ, eqs[i][0], opt.icl());
     }
     branch(*this, x, INT_VAR_NONE, INT_VAL_MIN);
