@@ -7,8 +7,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2009-09-30 12:12:35 +0200 (Wed, 30 Sep 2009) $ by $Author: tack $
- *     $Revision: 9779 $
+ *     $Date: 2010-05-12 12:10:19 +0200 (Wed, 12 May 2010) $ by $Author: schulte $
+ *     $Revision: 10953 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -69,21 +69,15 @@ public:
   /// The actual model
   Grocery(const Options& opt) : abcd(*this,4,0,s) {
     IntVar a(abcd[0]), b(abcd[1]), c(abcd[2]), d(abcd[3]);
+
     // The sum of all variables is s
-    post(*this, a+b+c+d == s, opt.icl());
+    rel(*this, a+b+c+d == s, opt.icl());
 
     // The product of all variables is s (corrected by scale factor)
-    rel(*this,
-        mult(*this,
-             mult(*this, a, b, opt.icl()),
-             mult(*this, c, d, opt.icl()),
-             opt.icl()),
-        IRT_EQ, p);
+    rel(*this, (a*b)*(c*d) == p, opt.icl());
 
     // Break symmetries: order the variables
-    rel(*this, a, IRT_LQ, b);
-    rel(*this, b, IRT_LQ, c);
-    rel(*this, c, IRT_LQ, d);
+    rel(*this, abcd, IRT_LQ);
 
     branch(*this, abcd, INT_VAR_NONE, INT_VAL_SPLIT_MAX);
   }
