@@ -11,8 +11,8 @@
  *     Mikael Lagerkivst, 2007
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-06-03 21:07:28 +0200 (Thu, 03 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11019 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -374,9 +374,10 @@ namespace {
    * \relates Kakuro
    */
   class DistinctLinear : public Space {
-  public:
+  protected:
     /// The variables
     IntVarArray x;
+  public:
     /// The actual problem
     DistinctLinear(int n, int s) : x(*this,n,1,9) {
       distinct(*this, x);
@@ -392,86 +393,42 @@ namespace {
     copy(bool share) {
       return new DistinctLinear(share,*this);
     }
-  };
-  /** \brief Generate specification for \a n distinct variables withm sum \a c
-   *
-   * This function should be specialised for any type of specification.
-   *
-   * \relates Kakuro
-   */
-  template<class C> C generate(int n, int c);
-
-  /** \brief Generate DFA for \a n distinct variables with sum \a c
-   * \relates Kakuro
-   */
-  template<>
-  DFA generate<DFA>(int n, int c) {
-    // Setup search engine that enumerates all solutions
-    DistinctLinear* e = new DistinctLinear(n,c);
-    DFS<DistinctLinear> d(e);
-    delete e;
-    // Remember in \a ts the previous transitions
-    DFA::Transition* ts = new DFA::Transition[n];
-    for (int i=n; i--; )
-      ts[i].symbol = 0;
-    ts[0].i_state = 0;
-    // Record all transitions in \a ts_all
-    Support::DynamicArray<DFA::Transition,Heap> ts_all(heap);
-    int ts_next = 0;
-    int n_state = 2;
-    while (DistinctLinear* s = d.next()) {
-      int i=0;
-      // Skip common prefix
-      for (; ts[i].symbol == s->x[i].val(); i++) {}
-      // Generate transitions for new suffix
-      int i_state = ts[i].i_state;
-      for (;i<n;i++) {
-        ts[i].i_state = i_state;
-        ts[i].symbol  = s->x[i].val();
-        ts[i].o_state = i_state = n_state++;
-        ts_all[ts_next++] = ts[i];
-      }
-      // Fix final state to 1
-      ts_all[ts_next-1].o_state = 1;
-      delete s;
+    /// Return a solution
+    IntArgs solution(void) const {
+      IntArgs s(x.size());
+      for (int i=0; i<x.size(); i++)
+        s[i]=x[i].val();
+      return s;
     }
-    delete [] ts;
-    ts_all[ts_next].i_state = -1;
-    int final[2] = {1,-1};
-    DFA dfa(0,&ts_all[0],final);
-    return dfa;
-  }
+  };
+
   /** \brief Generate tuple set for \a n distinct variables with sum \a c
    * \relates Kakuro
    */
-  template<>
-  TupleSet generate<TupleSet>(int n, int c) {
+  TupleSet generate(int n, int c) {
     // Setup search engine that enumerates all solutions
     DistinctLinear* e = new DistinctLinear(n,c);
     DFS<DistinctLinear> d(e);
     delete e;
     TupleSet ts;
     while (DistinctLinear* s = d.next()) {
-      IntArgs ia(n);
-      for (int i = n; i--; ) ia[i] = s->x[i].val();
-      ts.add(ia);
-      delete s;
+      ts.add(s->solution()); delete s;
     }
     ts.finalize();
     return ts;
   }
 
-  /** \brief Class to remember already computed specifications of type Data
+  /** \brief Class to remember already computed specifications
    * \relates Kakuro
    */
-  template<class Data>
   class Cache {
   private:
+    /// Cache entry
     class Entry {
     public:
       int n;       ///< Number of variables
       int c;       ///< Sum of variables
-      Data d;      ///< The previously computed DFA
+      TupleSet ts; ///< The previously computed tuple set
       Entry* next; ///< The next cache entry
     };
     Entry* cache; ///< Where all entries start
@@ -479,17 +436,17 @@ namespace {
     /// Initialize cache as empty
     Cache(void) : cache(NULL) {}
     /// Return possibly cached Data for \a n distinct variables with sum \a c
-    Data get(int n, int c) {
+    TupleSet get(int n, int c) {
       for (Entry* e = cache; e != NULL; e = e->next)
         if ((e->n == n) && (e->c == c))
-          return e->d;
+          return e->ts;
       Entry* e = new Entry;
       e->n = n;
       e->c = c;
-      e->d = generate<Data>(n,c);
+      e->ts = generate(n,c);
       e->next = cache;
       cache = e;
-      return cache->d;
+      return cache->ts;
     }
     /// Delete cache entries
     ~Cache(void) {
@@ -510,48 +467,39 @@ namespace {
  *
  * Another puzzle in the style of Sudoku.
  *
+ * Note that "Modeling and Programming with Gecode" uses this example
+ * as a case study.
+ *
  * \ingroup ExProblem
  */
 class Kakuro : public Script {
 protected:
-  const int w;    ///< Width of board
-  const int h;    ///< Height of board
-  IntVarArray _b; ///< Variables for board
+  const int w;   ///< Width of board
+  const int h;   ///< Height of board
+  IntVarArray f; ///< Variables for fields of board
 public:
-  /// Propagation variants
-  enum {
-    PROP_DFA,       ///< Use DFAs for extensional constraints
-    PROP_TUPLE_SET  ///< Use tuple sets for extensional constraints
-  };
   /// Model variants
   enum {
     MODEL_DECOMPOSE,///< Decompose constraints
     MODEL_COMBINE,  ///< Combine distinct and linear constraint
   };
-  /// Access the field at position \a x, \a y
-  IntVar& b(int x, int y) {
-    assert((x >= 0) && (x < w) && (y >= 0) && (y < h));
-    return _b[x+y*w];
-  }
-  /// Access the field at position \a x, \a y
-  const IntVar& b(int x, int y) const {
-    assert((x >= 0) && (x < w) && (y >= 0) && (y < h));
-    return _b[x+y*w];
-  }
-  /// Init the field at position \a x, \a y if necessary
-  void init(int x, int y) {
-    if (b(x,y).min() == 0)
-      b(x,y).init(*this,1,9);
+  /// Init the variable \a x if necessary
+  IntVar init(IntVar& x) {
+    if (x.min() == 0)
+      x = IntVar(*this,1,9);
+    return x;
   }
   /// Post a distinct-linear constraint on variables \a x with sum \a c
-  template<class Data>
-  void distinctlinear(Cache<Data>& dc, const IntVarArgs& x, int c,
+  void distinctlinear(Cache& dc, const IntVarArgs& x, int c,
                       const SizeOptions& opt) {
+    int n=x.size();
     if (opt.model() == MODEL_DECOMPOSE) {
+      if (n < 8)
+        linear(*this, x, IRT_EQ, c, opt.icl());
+      else if (n == 8)
+        rel(*this, x, IRT_NQ, 9*(9+1)/2 - c);
       distinct(*this, x, opt.icl());
-      linear(*this, x, IRT_EQ, c, opt.icl());
     } else {
-      int n=x.size();
       switch (n) {
       case 0:
         return;
@@ -579,14 +527,6 @@ public:
           // sum has unique decomposition: (9-n) + (9-n+2) + ... + 9
           rel(*this, x, IRT_GQ, 9-n);
           rel(*this, x, IRT_NQ, 9-n+1);
-        } else if (n == 2) {
-          // Just use element constraint with no two equal digits
-          IntArgs e(c);
-          e[0]=0;
-          for (int i=1; i<c; i++)
-            e[i]=(c-i == i) ? 0 : c-i;
-          element(*this, e, x[0], x[1]);
-          return;
         } else {
           extensional(*this, x, dc.get(n,c));
           return;
@@ -598,48 +538,45 @@ public:
   /// The actual problem
   Kakuro(const SizeOptions& opt)
     : w(examples[opt.size()][0]),  h(examples[opt.size()][1]),
-      _b(*this,w*h) {
+      f(*this,w*h) {
     IntVar black(*this,0,0);
     // Initialize all fields as black (unused). Only if a field
     // is actually used in a constraint, create a fresh variable
     // for it (done via init).
     for (int i=w*h; i--; )
-      _b[i] = black;
+      f[i] = black;
+
+    // Cache of already computed tuple sets
+    Cache cache;
+
+    // Matrix for accessing board fields
+    Matrix<IntVarArray> b(f,w,h);
+    // Access to hints
     const int* k = &examples[opt.size()][2];
-    // Cache of computed DFAs
-    Cache<DFA> dfa_cache;
-    // Cache of compute tuple sets
-    Cache<TupleSet> ts_cache;
-    // Process vertical constraints
+
+    // Process vertical hints
     while (*k >= 0) {
       int x=*k++; int y=*k++; int n=*k++; int s=*k++;
       IntVarArgs col(n);
-      for (int i=n; i--; ) {
-        init(x,y+i+1); col[i]=b(x,y+i+1);
-      }
-      if (opt.propagation() == PROP_TUPLE_SET)
-        distinctlinear(ts_cache,col,s,opt);
-      else
-        distinctlinear(dfa_cache,col,s,opt);
+      for (int i=n; i--; )
+        col[i]=init(b(x,y+i+1));
+      distinctlinear(cache,col,s,opt);
     }
     k++;
-    // Process horizontal constraints
+
+    // Process horizontal hints
     while (*k >= 0) {
       int x=*k++; int y=*k++; int n=*k++; int s=*k++;
       IntVarArgs row(n);
-      for (int i=n; i--; ) {
-        init(x+i+1,y); row[i]=b(x+i+1,y);
-      }
-      if (opt.propagation() == PROP_TUPLE_SET)
-        distinctlinear(ts_cache,row,s,opt);
-      else
-        distinctlinear(dfa_cache,row,s,opt);
+      for (int i=n; i--; )
+        row[i]=init(b(x+i+1,y));
+      distinctlinear(cache,row,s,opt);
     }
-    branch(*this, _b, INT_VAR_SIZE_MIN, INT_VAL_SPLIT_MIN);
+    branch(*this, f, INT_VAR_SIZE_AFC_MIN, INT_VAL_SPLIT_MIN);
   }
   /// Constructor for cloning \a s
   Kakuro(bool share, Kakuro& s) : Script(share,s), w(s.w), h(s.h) {
-    _b.update(*this, share, s._b);
+    f.update(*this, share, s.f);
   }
   /// Perform copying during cloning
   virtual Space*
@@ -649,6 +586,7 @@ public:
   /// Print solution
   virtual void
   print(std::ostream& os) const {
+    Matrix<IntVarArray> b(f,w,h);
     for (int y=0; y<h; y++) {
       os << '\t';
       for (int x=0; x<w; x++)
@@ -668,18 +606,11 @@ public:
 int
 main(int argc, char* argv[]) {
   SizeOptions opt("Kakuro");
-  opt.propagation(Kakuro::PROP_TUPLE_SET);
-  opt.propagation(Kakuro::PROP_DFA,
-                  "dfa","Use DFAs for storing combinations");
-  opt.propagation(Kakuro::PROP_TUPLE_SET,
-                  "tuple-set","Use tuple sets for storing combinations");
-
   opt.model(Kakuro::MODEL_COMBINE);
   opt.model(Kakuro::MODEL_DECOMPOSE,
                   "decompose","decompose distinct and linear constraints");
   opt.model(Kakuro::MODEL_COMBINE,
                   "combine","combine distinct and linear constraints");
-
   opt.icl(ICL_DOM);
   opt.parse(argc,argv);
   if (opt.size() >= n_examples) {
