@@ -9,8 +9,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-07-02 10:59:05 +0200 (Fri, 02 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11148 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -224,7 +224,7 @@ public:
 };
 
 /**
- * \brief %Example: n-knight's tour (simple model)
+ * \brief %Example: n-Knight's tour (simple model)
  *
  * Fill an n times n chess board with knight's moves such that
  * the knight does a full tour (last move reaches first move
@@ -258,10 +258,10 @@ public:
       IntSet ds = neighbors(f);
       for (IntSetValues i(ds); i(); ++i)
         rel(*this,
-            post(*this, ~(jump[i.val()]-jump[f] == 1)),
+            expr(*this, (jump[i.val()]-jump[f] == 1)),
             BOT_XOR,
-            post(*this, ~(jump[i.val()]-jump[f] == 1-nn)),
-            post(*this, ~(succ[f] == i.val())));
+            expr(*this, (jump[i.val()]-jump[f] == 1-nn)),
+            expr(*this, (succ[f] == i.val())));
       dom(*this, pred[f], ds);
       dom(*this, succ[f], ds);
       rel(*this, succ[f], IRT_NQ, pred[f]);
