@@ -9,8 +9,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-05-14 17:24:02 +0200 (Thu, 14 May 2009) $ by $Author: schulte $
- *     $Revision: 9115 $
+ *     $Date: 2010-04-28 16:44:51 +0200 (Wed, 28 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10820 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -54,6 +54,9 @@ using namespace Gecode;
  *
  * See problem 19 at http://www.csplib.org/.
  *
+ * Note that "Modeling and Programming with Gecode" uses this example
+ * as a case study.
+ *
  * \ingroup ExProblem
  *
  */
@@ -82,11 +85,8 @@ public:
       count(*this, s, s, opt.icl());
       break;
     }
-    IntArgs c(n);
-    for (int j = n; j--; )
-      c[j] = j-1;
-    linear(*this, c, s, IRT_EQ, 0);
-    branch(*this, s, INT_VAR_NONE, INT_VAL_SPLIT_MAX);
+    linear(*this, IntArgs::create(n,-1,1), s, IRT_EQ, 0);
+    branch(*this, s, INT_VAR_NONE, INT_VAL_MAX);
   }
 
   /// Constructor for cloning \a e
