@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-04-02 20:58:46 +0200 (Thu, 02 Apr 2009) $ by $Author: schulte $
- *     $Revision: 8649 $
+ *     $Date: 2010-05-08 19:24:20 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10910 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -80,12 +80,12 @@ public:
     IntVarArgs sxy(2*n), sx(n), sy(n);
 
     for (int i = n; i--; ) {
-      sx[i] = sxy[i] =   sqr(*this, x[i]);
-      sy[i] = sxy[n+i] = sqr(*this, y[i]);
+      sx[i] = sxy[i] =   expr(*this, sqr(x[i]));
+      sy[i] = sxy[n+i] = expr(*this, sqr(y[i]));
     }
     linear(*this, c, sxy, IRT_EQ, 0);
 
-    // Redundant
+    // Redundant constraints
     linear(*this, x, IRT_EQ, 2*n*(2*n+1)/4);
     linear(*this, y, IRT_EQ, 2*n*(2*n+1)/4);
     linear(*this, sx, IRT_EQ, 2*n*(2*n+1)*(4*n+1)/12);
