@@ -11,8 +11,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-06-03 21:07:28 +0200 (Thu, 03 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11019 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -53,10 +53,12 @@ using namespace Gecode;
  *
  * \relates Pentominoes
  */
-struct TileSpec {
-  int width, height;
-  int amount;
-  const char *tile;
+class TileSpec {
+public:
+  int width;  ///< Width of tile
+  int height; ///< Height of tile
+  int amount; ///< Number of tiles
+  const char *tile; ///< Picture of tile
 };
 
 /** \brief Board specifications
@@ -384,9 +386,7 @@ public:
     } else { // opt.propagation() == PROPAGATION_BOOLEAN
       int ncolors = ntiles + 2;
       // Boolean variables for channeling
-      BoolVarArgs p(ncolors * board.size());
-      for (int i=p.size(); i--; )
-        p[i].init(*this,0,1);
+      BoolVarArgs p(*this,ncolors * board.size(),0,1);
 
       // Post channel constraints
       for (int i=board.size(); i--; ) {
