@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2006
  *
  *  Last modified:
- *     $Date: 2010-03-15 17:03:39 +0100 (Mon, 15 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10447 $
+ *     $Date: 2010-05-08 19:24:20 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10910 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -101,11 +101,11 @@ public:
     // Basic rules of the model
     for (int i = n*n; i--; ) {
       // w[i] means that no blacks are allowed on A[i]
-      dom(*this, U, SRT_DISJ, A[i], w[i]);
+      rel(*this, w[i] == (U || A[i]));
       // Make sure blacks and whites are disjoint.
-      post(*this, tt(!w[i] || !b[i]));
+      rel(*this, !w[i] || !b[i]);
       // If i in U, then b[i] has a piece.
-      dom(*this, U, SRT_SUP, i, b[i]);
+      rel(*this, b[i] == (singleton(i) <= U));
     }
 
     // Connect optimization variable to number of pieces
@@ -113,9 +113,8 @@ public:
     linear(*this, b, IRT_GQ, q);
 
     // Connect cardinality of U to the number of black pieces.
-    IntVar unknowns(*this, 0, n*n);
-    cardinality(*this, U, unknowns);
-    post(*this, q <= unknowns);
+    IntVar unknowns = expr(*this, cardinality(U));
+    rel(*this, q <= unknowns);
     linear(*this, b, IRT_EQ, unknowns);
 
     if (opt.branching() == BRANCH_NAIVE) {
@@ -165,7 +164,7 @@ public:
    *
    * \relates QueenArmies
    */
-  class QueenBranch : Brancher {
+  class QueenBranch : public Brancher {
   private:
     /// Cache of last computed decision
     mutable int start;
