@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-05-08 12:56:03 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10906 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -152,7 +152,7 @@ public:
     }
 
     _cost = IntVar(*this, 0, (rd.m*rd.n+1)*(rd.intsSum+1));
-    post(*this, _cost == beamtime*(rd.m*rd.n+1)+K);
+    rel(*this, _cost == beamtime*(rd.m*rd.n+1)+K);
 
     // First branch over beamtime and N
     IntVarArgs ba(1); ba[0] = beamtime;
@@ -166,11 +166,11 @@ public:
 
   /// Post incremental sum constraint 
   void incr_sum(IntVar& x, IntVarArgs& y, int mn) {
-    IntVarArray s(*this, y.size()-1, 0, mn);
+    IntVarArgs s(*this, y.size()-1, 0, mn);
     IntVarArgs t(y.size());
     t[0] = y[0];
     for (int i=1; i<y.size(); i++) {
-      post(*this, s[i-1] >= y[i]-y[i-1]);
+      rel(*this, s[i-1] >= y[i]-y[i-1]);
       t[i] = s[i-1];
     }
     linear(*this, t, IRT_LQ, x);
