@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2008
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-05-07 10:33:59 +0200 (Fri, 07 May 2010) $ by $Author: zayenz $
+ *     $Revision: 10884 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -253,7 +253,7 @@ public:
 
     // Add branching
     if (opt.symmetry() == SYMMETRY_BRANCHING) {
-      // Install custom branching
+      // Symmetry breaking branching
       SteelMillBranch::post(*this);
     } else { // opt.symmetry() == SYMMETRY_NONE
       branch(*this, slab, INT_VAR_MAX_MIN, INT_VAL_MIN);
@@ -409,7 +409,7 @@ public:
       (void) new (home) SteelMillBranch(home);
     }
     /// Delete brancher and return its size
-    virtual size_t dispose(Space& home) {
+    virtual size_t dispose(Space&) {
       return sizeof(*this);
     }
   };
