@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-06-02 09:57:41 +0200 (Wed, 02 Jun 2010) $ by $Author: tack $
+ *     $Revision: 11002 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -51,14 +51,12 @@ using namespace Gecode;
  */
 class Steiner : public Script {
 public:
-
   /// Model variants
   enum {
     MODEL_NONE,   ///< Use simple relation constraint
     MODEL_MATCHING, ///< Use matching constraints
     MODEL_SEQ ///< Use sequence constraints
   };
-
   /// Order of the Steiner problem
   int n;
   /// Number of Steiner triples
@@ -78,8 +76,7 @@ public:
         SetVar y = triples[j];
 
         SetVar atmostOne(*this,IntSet::empty,1,n,0,1);
-        cardinality(*this, atmostOne,0,1);
-        rel(*this, x, SOT_INTER, y, SRT_EQ, atmostOne);
+        rel(*this, (x & y) == atmostOne);
 
         IntVar x1(*this,1,n);
         IntVar x2(*this,1,n);
@@ -92,67 +89,47 @@ public:
           /* Naive alternative:
            * just including the ints in the set
            */
-          rel(*this, x, SRT_SUP, x1);
-          rel(*this, x, SRT_SUP, x2);
-          rel(*this, x, SRT_SUP, x3);
-          rel(*this, y, SRT_SUP, y1);
-          rel(*this, y, SRT_SUP, y2);
-          rel(*this, y, SRT_SUP, y3);
+          rel(*this, singleton(x1) <= x);
+          rel(*this, singleton(x2) <= x);
+          rel(*this, singleton(x3) <= x);
+          rel(*this, singleton(y1) <= y);
+          rel(*this, singleton(y2) <= y);
+          rel(*this, singleton(y3) <= y);
 
-        } else  if (opt.model() == MODEL_MATCHING) {
+        } else if (opt.model() == MODEL_MATCHING) {
           /* Smart alternative:
            * Using matching constraints
            */
 
-          IntVarArgs xargs(3);
-          xargs[0] = x1; xargs[1] = x2; xargs[2] = x3;
-          channel(*this, xargs, x);
-
-          IntVarArgs yargs(3);
-          yargs[0] = y1; yargs[1] = y2; yargs[2] = y3;
-          channel(*this, yargs, y);
+          channel(*this, IntVarArgs()<<x1<<x2<<x3, x);
+          channel(*this, IntVarArgs()<<y1<<y2<<y3, y);
         } else if (opt.model() == MODEL_SEQ) {
-          SetVar tmp20(*this,IntSet::empty,1,n);
-          SetVar tmp21(*this,IntSet::empty,1,n);
-          SetVar tmp22(*this,IntSet::empty,1,n);
-          SetVar tmp23(*this,IntSet::empty,1,n);
-          SetVar tmp24(*this,IntSet::empty,1,n);
-          SetVar tmp25(*this,IntSet::empty,1,n);
-          rel(*this, tmp20, SRT_EQ, x1);
-          rel(*this, tmp21, SRT_EQ, x2);
-          rel(*this, tmp22, SRT_EQ, x3);
-          rel(*this, tmp23, SRT_EQ, y1);
-          rel(*this, tmp24, SRT_EQ, y2);
-          rel(*this, tmp25, SRT_EQ, y3);
-          SetVarArgs xargs(3);
-          xargs[0] = tmp20; xargs[1] = tmp21; xargs[2] = tmp22;
-          SetVarArgs yargs(3);
-          yargs[0] = tmp23; yargs[1] = tmp24; yargs[2] = tmp25;
-          sequence(*this,xargs,x);
-          sequence(*this,yargs,y);
+          SetVar sx1 = expr(*this, singleton(x1));
+          SetVar sx2 = expr(*this, singleton(x2));
+          SetVar sx3 = expr(*this, singleton(x3));
+          SetVar sy1 = expr(*this, singleton(y1));
+          SetVar sy2 = expr(*this, singleton(y2));
+          SetVar sy3 = expr(*this, singleton(y3));
+          sequence(*this,SetVarArgs()<<sx1<<sx2<<sx3,x);
+          sequence(*this,SetVarArgs()<<sy1<<sy2<<sy3,y);
         }
 
         /* Breaking symmetries */
+        rel(*this, x1 < x2);
+        rel(*this, x2 < x3);
+        rel(*this, x1 < x3);
 
-        rel(*this, x1,IRT_LE,x2);
-        rel(*this, x2,IRT_LE,x3);
-        rel(*this, x1,IRT_LE,x3);
+        rel(*this, y1 < y2);
+        rel(*this, y2 < y3);
+        rel(*this, y1 < y3);
 
-        rel(*this, y1,IRT_LE,y2);
-        rel(*this, y2,IRT_LE,y3);
-        rel(*this, y1,IRT_LE,y3);
-
-        IntArgs ia(6,(n+1)*(n+1),n+1,1,-(n+1)*(n+1),-(n+1),-1);
-        IntVarArgs iva(6);
-        iva[0]=x1; iva[1]=x2; iva[2]=x3;
-        iva[3]=y1; iva[4]=y2; iva[5]=y3;
-        linear(*this, ia, iva, IRT_LE, 0);
+        linear(*this, IntArgs(6,(n+1)*(n+1),n+1,1,-(n+1)*(n+1),-(n+1),-1), 
+               IntVarArgs()<<x1<<x2<<x3<<y1<<y2<<y3, IRT_LE, 0);
       }
     }
 
     branch(*this, triples, SET_VAR_NONE, SET_VAL_MIN_INC);
   }
-
   /// Print solution
   virtual void
   print(std::ostream& os) const {
@@ -160,7 +137,6 @@ public:
       os << "\t[" << i << "] = " << triples[i] << std::endl;
     }
   }
-
   /// Constructor for copying \a s
   Steiner(bool share, Steiner& s) : Script(share,s), n(s.n), noOfTriples(s.noOfTriples) {
     triples.update(*this, share, s.triples);
@@ -170,7 +146,6 @@ public:
   copy(bool share) {
     return new Steiner(share,*this);
   }
-
 };
 
 /** \brief Main-function
