@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2010-04-07 10:44:43 +0200 (Wed, 07 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10658 $
+ *     $Date: 2010-06-16 13:43:29 +0200 (Wed, 16 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11077 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,20 +42,20 @@
 using namespace Gecode;
 
 /// Number of warehouses
-const int n_suppliers = 5;
+const int n_warehouses = 5;
 /// Number of stores
 const int n_stores = 10;
 
 /// Fixed cost for one warehouse
-const int fixed_cost = 30;
+const int c_fixed = 30;
 
 /// Capacity of a single warehouse
-const int capacity[n_suppliers] = {
+const int capacity[n_warehouses] = {
   1, 4, 2, 1, 3
 };
 
-/// Cost for store to warehouse
-const int cost_matrix[n_stores][n_suppliers] = {
+/// Cost for supply a store by a warehouse
+const int c_supply[n_stores][n_warehouses] = {
   {20, 24, 11, 25, 30},
   {28, 27, 82, 83, 74},
   {74, 97, 71, 96, 70},
@@ -90,60 +90,66 @@ const int cost_matrix[n_stores][n_suppliers] = {
  *
  * See also problem 34 at http://www.csplib.org/.
  *
+ * Note that "Modeling and Programming with Gecode" uses this example
+ * as a case study.
+ *
  * \ingroup ExProblem
  *
  */
 class Warehouses : public MinimizeScript {
 protected:
-  /// Map store to the supplier
+  /// Which warehouse supplies a store
   IntVarArray supplier;
-  /// Is a supplier open (warehouse needed)
+  /// Is a warehouse open (warehouse needed)
   BoolVarArray open;
   /// Cost of a store
-  IntVarArray store;
+  IntVarArray c_store;
   /// Total cost
-  IntVar total;
+  IntVar c_total;
 public:
   /// Actual model
   Warehouses(const Options&)
-    : supplier(*this, n_stores, 0, n_suppliers-1),
-      open(*this, n_suppliers, 0, 1),
-      store(*this, n_stores, 0, Int::Limits::max),
-      total(*this, 0, Int::Limits::max) {
+    : supplier(*this, n_stores, 0, n_warehouses-1),
+      open(*this, n_warehouses, 0, 1),
+      c_store(*this, n_stores) {
 
-    // Compute total cost
-    post(*this, fixed_cost*sum(open) + sum(store) == total);
+    // A warehouse is open, if it supplies to a store
+    for (int s=0; s<n_stores; s++)
+      element(*this, open, supplier[s], 1);
 
-    // Compute cost for store
-    for (int i=0; i<n_stores; i++) {
-      IntArgs c(n_suppliers, cost_matrix[i]);
-      element(*this, c, supplier[i], store[i]);
+    // Compute cost for each warehouse
+    for (int s=0; s<n_stores; s++) {
+      IntArgs c(n_warehouses, c_supply[s]);
+      c_store[s] = expr(*this, element(c, supplier[s]));
     }
 
     // Do not exceed capacity
-    for (int i=0; i<n_suppliers; i++)
-      count(*this, supplier, i, IRT_LQ, capacity[i]);
-
-    // A warehouse is open, if it supplies to a shop
-    for (int i=0; i<n_suppliers; i++) {
-      BoolVarArgs store_by_supplier(n_stores);
-      for (int j=0; j<n_stores; j++)
-        store_by_supplier[j] = post(*this, ~(supplier[j] == i));
-      rel(*this, BOT_OR, store_by_supplier, open[i]);
+    {
+      IntSetArgs c(n_warehouses);
+      for (int w=0; w<n_warehouses; w++)
+        c[w] = IntSet(0,capacity[w]);
+      count(*this, supplier, c, ICL_DOM);
     }
 
-    branch(*this, store, INT_VAR_REGRET_MIN_MAX, INT_VAL_MIN);
+    // Compute total cost
+    c_total = expr(*this, c_fixed*sum(open) + sum(c_store));
+
+    // Branch with largest minimum regret on store cost
+    branch(*this, c_store, INT_VAR_REGRET_MIN_MAX, INT_VAL_MIN);
+
+    // Branch by assigning a supplier to each store
+    branch(*this, supplier, INT_VAR_NONE, INT_VAL_MIN);
   }
   /// Return solution cost
   virtual IntVar cost(void) const {
-    return total;
+    return c_total;
   }
   /// Constructor for cloning \a s
   Warehouses(bool share, Warehouses& s) : MinimizeScript(share,s) {
     supplier.update(*this, share, s.supplier);
     open.update(*this, share, s.open);
-    store.update(*this, share, s.store);
-    total.update(*this, share, s.total);
+    c_store.update(*this, share, s.c_store);
+    c_total.update(*this, share, s.c_total);
   }
 
   /// Copy during cloning
@@ -154,9 +160,10 @@ public:
   /// Print solution
   virtual void
   print(std::ostream& os) const {
-    os << "\tSupplier:   " << supplier << std::endl
-       << "\tStore cost: " << store << std::endl
-       << "\tTotal cost: " << total << std::endl
+    os << "\tSupplier:        " << supplier << std::endl
+       << "\tOpen warehouses: " << open << std::endl
+       << "\tStore cost:      " << c_store << std::endl
+       << "\tTotal cost:      " << c_total << std::endl
        << std::endl;
   }
 };
