@@ -11,8 +11,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2009-11-09 21:02:40 +0100 (Mon, 09 Nov 2009) $ by $Author: schulte $
- *     $Revision: 10065 $
+ *     $Date: 2010-07-14 12:40:03 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11185 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -86,9 +86,7 @@ public:
     const int n_w = dict.words(w_l);
 
     // Initialize word array
-    IntVarArgs words(w_l);
-    for (int i=0; i<w_l; i++)
-      words[i].init(*this,0,n_w-1);
+    IntVarArgs words(*this, w_l, 0, n_w-1);
 
     // All words must be different
     distinct(*this, words);
@@ -152,13 +150,13 @@ public:
 int
 main(int argc, char* argv[]) {
   FileSizeOptions opt("WordSquare");
-  opt.size(4);
+  opt.size(6);
   opt.branching(WordSquare::BRANCH_LETTERS);
   opt.branching(WordSquare::BRANCH_WORDS,   "words");
   opt.branching(WordSquare::BRANCH_LETTERS, "letters");
   opt.parse(argc,argv);
   dict.init(opt.file());
-  if (opt.size() > dict.len()) {
+  if (opt.size() > static_cast<unsigned int>(dict.len())) {
     std::cerr << "Error: size must be between 0 and "
               << dict.len() << std::endl;
     return 1;
