@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-04-06 14:58:53 +0200 (Tue, 06 Apr 2010) $ by $Author: tack $
- *     $Revision: 10649 $
+ *     $Date: 2010-07-14 20:32:01 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11195 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -310,6 +310,14 @@ namespace Gecode {
     return _time.value();
   }
   
+  inline void
+  Options::interrupt(bool b) {
+    _interrupt.value(b);
+  }
+  inline bool
+  Options::interrupt(void) const {
+    return static_cast<bool>(_interrupt.value());
+  }
   
   
   /*
