@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-04-06 14:58:53 +0200 (Tue, 06 Apr 2010) $ by $Author: tack $
- *     $Revision: 10649 $
+ *     $Date: 2010-06-01 13:59:14 +0200 (Tue, 01 Jun 2010) $ by $Author: tack $
+ *     $Revision: 10996 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,6 +39,10 @@
 #include <iostream>
 #include <iomanip>
 
+#ifndef GECODE_THREADS_WINDOWS
+#include <csignal>
+#endif
+
 namespace Gecode { namespace Driver {
 
   /**
@@ -50,21 +54,27 @@ namespace Gecode { namespace Driver {
     Search::NodeStop* ns; ///< Used node stop object
     Search::FailStop* fs; ///< Used fail stop object
     Search::TimeStop* ts; ///< Used time stop object
+    GECODE_DRIVER_EXPORT
+    static bool sigint;   ///< Whether search was interrupted using Ctrl-C
     /// Initialize stop object
     Cutoff(unsigned int node, unsigned int fail, unsigned int time)
       : ns((node > 0) ? new Search::NodeStop(node) : NULL),
         fs((fail > 0) ? new Search::FailStop(fail) : NULL),
-        ts((time > 0) ? new Search::TimeStop(time) : NULL) {}
+        ts((time > 0) ? new Search::TimeStop(time) : NULL) {
+      sigint = false;
+    }
   public:
     /// Reason why search has been stopped
     enum {
       SR_NODE = 1 << 0, ///< Node limit reached
       SR_FAIL = 1 << 1, ///< Fail limit reached
-      SR_TIME = 1 << 2  ///< Time limit reached
+      SR_TIME = 1 << 2, ///< Time limit reached
+      SR_INT  = 1 << 3  ///< Interrupted by user
     };
     /// Test whether search must be stopped
     virtual bool stop(const Search::Statistics& s, const Search::Options& o) {
       return
+        sigint ||
         ((ns != NULL) && ns->stop(s,o)) ||
         ((fs != NULL) && fs->stop(s,o)) ||
         ((ts != NULL) && ts->stop(s,o));
@@ -74,16 +84,46 @@ namespace Gecode { namespace Driver {
       return 
         (((ns != NULL) && ns->stop(s,o)) ? SR_NODE : 0) |
         (((fs != NULL) && fs->stop(s,o)) ? SR_FAIL : 0) |
-        (((ts != NULL) && ts->stop(s,o)) ? SR_TIME : 0);
+        (((ts != NULL) && ts->stop(s,o)) ? SR_TIME : 0) |
+        (sigint                          ? SR_INT  : 0);
     }
     /// Create appropriate stop-object
     static Search::Stop*
-    create(unsigned int node, unsigned int fail, unsigned int time) {
-      if ((node == 0) && (fail == 0) && (time == 0))
+    create(unsigned int node, unsigned int fail, unsigned int time,
+           bool intr) {
+      if ( (!intr) && (node == 0) && (fail == 0) && (time == 0))
         return NULL;
       else
         return new Cutoff(node,fail,time);
     }
+#ifdef GECODE_THREADS_WINDOWS
+    /// Handler for catching Ctrl-C
+    static BOOL interrupt(DWORD t) {
+      if (t == CTRL_C_EVENT) {
+        sigint = true;
+        installCtrlHandler(false,true);
+        return true;
+      }
+      return false;
+    }
+#else
+    /// Handler for catching Ctrl-C
+    static void
+    interrupt(int) {
+      sigint = true;
+      installCtrlHandler(false,true);
+    }
+#endif
+    /// Install handler for catching Ctrl-C
+    static void installCtrlHandler(bool install, bool force=false) {
+      if (force || !sigint) {
+#ifdef GECODE_THREADS_WINDOWS
+        SetConsoleCtrlHandler( (PHANDLER_ROUTINE) interrupt, install);
+#else
+        std::signal(SIGINT, install ? interrupt : SIG_DFL);
+#endif
+      }
+    }
     /// Destructor
     ~Cutoff(void) {
       delete ns; delete fs; delete ts;
@@ -201,8 +241,11 @@ namespace Gecode { namespace Driver {
           so.threads = o.threads();
           so.c_d     = o.c_d();
           so.a_d     = o.a_d();
-          so.stop    = Cutoff::create(o.node(),o.fail(), o.time());
+          so.stop    = Cutoff::create(o.node(),o.fail(), o.time(), 
+                                      o.interrupt());
           so.clone   = false;
+          if (o.interrupt())
+            Cutoff::installCtrlHandler(true);
           Engine<Script> e(s,so);
           do {
             Script* ex = e.next();
@@ -211,19 +254,25 @@ namespace Gecode { namespace Driver {
             ex->print(std::cout);
             delete ex;
           } while (--i != 0);
+          if (o.interrupt())
+            Cutoff::installCtrlHandler(false);
           Search::Statistics stat = e.statistics();
           cout << endl;
           if (e.stopped()) {
             cout << "Search engine stopped..." << endl
                  << "\treason: ";
             int r = static_cast<Cutoff*>(so.stop)->reason(stat,so);
-            if (r & Cutoff::SR_NODE)
-              cout << "node ";
-            if (r & Cutoff::SR_FAIL)
-              cout << "fail ";
-            if (r & Cutoff::SR_TIME)
-              cout << "time ";
-            cout << "limit reached" << endl << endl;
+            if (r & Cutoff::SR_INT)
+              cout << "user interrupt " << endl;
+            else {
+              if (r & Cutoff::SR_NODE)
+                cout << "node ";
+              if (r & Cutoff::SR_FAIL)
+                cout << "fail ";
+              if (r & Cutoff::SR_TIME)
+                cout << "time ";
+              cout << "limit reached" << endl << endl;
+            }
           }
           cout << "Initial" << endl
                << "\tpropagators: " << n_p << endl
@@ -258,7 +307,10 @@ namespace Gecode { namespace Driver {
           so.threads = o.threads();
           so.c_d     = o.c_d();
           so.a_d     = o.a_d();
-          so.stop    = Cutoff::create(o.node(),o.fail(), o.time());
+          so.stop    = Cutoff::create(o.node(),o.fail(), o.time(),
+                                      o.interrupt());
+          if (o.interrupt())
+            Cutoff::installCtrlHandler(true);
           Engine<Script> e(s,so);
           do {
             Script* ex = e.next();
@@ -266,10 +318,12 @@ namespace Gecode { namespace Driver {
               break;
             delete ex;
           } while (--i != 0);
+          if (o.interrupt())
+            Cutoff::installCtrlHandler(false);
           Search::Statistics stat = e.statistics();
           cout << endl
-               << "\tpropagators: " << n_p << endl
-               << "\tbranchers:   " << n_b << endl
+               << "\tpropagators:  " << n_p << endl
+               << "\tbranchers:    " << n_b << endl
                << "\truntime:      ";
           stop(t, cout);
           cout << endl
@@ -289,9 +343,10 @@ namespace Gecode { namespace Driver {
           cout << o.name() << endl;
           Support::Timer t;
           double* ts = new double[o.samples()];
-          for (unsigned int s = o.samples(); s--; ) {
+          bool stopped = false;
+          for (unsigned int s = o.samples(); !stopped && s--; ) {
             t.start();
-            for (unsigned int k = o.iterations(); k--; ) {
+            for (unsigned int k = o.iterations(); !stopped && k--; ) {
               unsigned int i = o.solutions();
               Script* s = new Script(o);
               Search::Options so;
@@ -299,7 +354,7 @@ namespace Gecode { namespace Driver {
               so.threads = o.threads();
               so.c_d     = o.c_d();
               so.a_d     = o.a_d();
-              so.stop    = Cutoff::create(o.node(),o.fail(), o.time());
+              so.stop    = Cutoff::create(o.node(),o.fail(), o.time(), false);
               Engine<Script> e(s,so);
               do {
                 Script* ex = e.next();
@@ -307,24 +362,31 @@ namespace Gecode { namespace Driver {
                   break;
                 delete ex;
               } while (--i != 0);
+              if (e.stopped())
+                stopped = true;
             }
             ts[s] = t.stop() / o.iterations();
           }
-          double m = am(ts,o.samples());
-          double d = dev(ts,o.samples()) * 100.0;
+          if (stopped) {
+            cout << "\tSTOPPED" << endl;
+          } else {
+            double m = am(ts,o.samples());
+            double d = dev(ts,o.samples()) * 100.0;
+            cout << "\tRuntime: "
+                 << setw(20) << right
+                 << showpoint << fixed
+                 << setprecision(6) << m << "ms"
+                 << setprecision(2) << " (" << d << "% deviation)"
+                 << endl;
+          }
           delete [] ts;
-          cout << "\tRuntime: "
-               << setw(20) << right
-               << showpoint << fixed
-               << setprecision(6) << m << "ms"
-               << setprecision(2) << " (" << d << "% deviation)"
-               << endl;
         }
         break;
       }
     } catch (Exception e) {
-      cout << "Exception: " << e.what() << "." << endl
+      cerr << "Exception: " << e.what() << "." << endl
            << "Stopping..." << endl;
+      exit(EXIT_FAILURE);
     }
   }
 
