@@ -7,8 +7,8 @@
  *     Guido Tack, 2007
  *
  *  Last modified:
- *     $Date: 2010-04-07 19:54:19 +0200 (Wed, 07 Apr 2010) $ by $Author: tack $
- *     $Revision: 10678 $
+ *     $Date: 2010-05-11 12:33:38 +0200 (Tue, 11 May 2010) $ by $Author: tack $
+ *     $Revision: 10940 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -348,7 +348,6 @@ namespace Gecode { namespace FlatZinc {
   void
   FlatZincSpace::createBranchers(AST::Node* ann, bool ignoreUnknown,
                                  std::ostream& err) {
-    bool hadSearchAnnotation = false;
     if (ann) {
       std::vector<AST::Node*> flatAnn;
       if (ann->isArray()) {
@@ -377,7 +376,6 @@ namespace Gecode { namespace FlatZinc {
             va[k++] = iv[vars->a[i]->getIntVar()];
           }
           branch(*this, va, ann2ivarsel(args->a[1]), ann2ivalsel(args->a[2]));
-          hadSearchAnnotation = true;
         } catch (AST::TypeError& e) {
         try {
           AST::Call *call = flatAnn[i]->getCall("int_assign");
@@ -395,7 +393,6 @@ namespace Gecode { namespace FlatZinc {
             va[k++] = iv[vars->a[i]->getIntVar()];
           }
           assign(*this, va, ann2asnivalsel(args->a[1]));
-          hadSearchAnnotation = true;
         } catch (AST::TypeError& e) {
           (void) e;
           try {
@@ -415,7 +412,6 @@ namespace Gecode { namespace FlatZinc {
             }
             branch(*this, va, ann2ivarsel(args->a[1]), 
                    ann2ivalsel(args->a[2]));        
-            hadSearchAnnotation = true;
           } catch (AST::TypeError& e) {
             (void) e;
 #ifdef GECODE_HAS_SET_VARS
@@ -436,7 +432,6 @@ namespace Gecode { namespace FlatZinc {
               }
               branch(*this, va, ann2svarsel(args->a[1]), 
                                ann2svalsel(args->a[2]));        
-              hadSearchAnnotation = true;
             } catch (AST::TypeError& e) {
               (void) e;
               if (!ignoreUnknown) {
@@ -457,37 +452,51 @@ namespace Gecode { namespace FlatZinc {
         }
       }
     }
-    if (!hadSearchAnnotation) {
-      int countUp = 0;
-      int countDown = iv.size()-1;
-      IntVarArgs iva(iv.size());
-      for (int i=0; i<iv.size(); i++)
-        if (iv_introduced[i])
-          iva[countDown--] = iv[i];
-        else
-          iva[countUp++] = iv[i];
-      countUp = 0;
-      countDown = bv.size()-1;
-      BoolVarArgs bva(bv.size());
-      for (int i=0; i<bv.size(); i++)
-        if (bv_introduced[i])
-          bva[countDown--] = bv[i];
-        else
-          bva[countUp++] = bv[i];
-      branch(*this, iva, INT_VAR_NONE, INT_VAL_MIN);
-      branch(*this, bva, INT_VAR_NONE, INT_VAL_MIN);
+    int introduced = 0;
+    for (int i=iv.size(); i--;)
+      if (iv_introduced[i])
+        introduced++;
+    IntVarArgs iv_sol(iv.size()-introduced);
+    IntVarArgs iv_tmp(introduced);
+    for (int i=iv.size(), j=0, k=0; i--;)
+      if (iv_introduced[i])
+        iv_tmp[j++] = iv[i];
+      else
+        iv_sol[k++] = iv[i];
+
+    introduced = 0;
+    for (int i=bv.size(); i--;)
+      if (bv_introduced[i])
+        introduced++;
+    BoolVarArgs bv_sol(bv.size()-introduced);
+    BoolVarArgs bv_tmp(introduced);
+    for (int i=bv.size(), j=0, k=0; i--;)
+      if (bv_introduced[i])
+        bv_tmp[j++] = bv[i];
+      else
+        bv_sol[k++] = bv[i];
+
+    branch(*this, iv_sol, INT_VAR_SIZE_AFC_MIN, INT_VAL_MIN);
+    branch(*this, bv_sol, INT_VAR_AFC_MIN, INT_VAL_MIN);
 #ifdef GECODE_HAS_SET_VARS
-      countUp = 0;
-      countDown = sv.size()-1;
-      SetVarArgs sva(sv.size());
-      for (int i=0; i<sv.size(); i++)
-        if (sv_introduced[i])
-          sva[countDown--] = sv[i];
-        else
-          sva[countUp++] = sv[i];
-      branch(*this, sva, SET_VAR_NONE, SET_VAL_MIN_INC);
+    introduced = 0;
+    for (int i=sv.size(); i--;)
+      if (sv_introduced[i])
+        introduced++;
+    SetVarArgs sv_sol(sv.size()-introduced);
+    SetVarArgs sv_tmp(introduced);
+    for (int i=sv.size(), j=0, k=0; i--;)
+      if (sv_introduced[i])
+        sv_tmp[j++] = sv[i];
+      else
+        sv_sol[k++] = sv[i];
+    branch(*this, sv_sol, SET_VAR_SIZE_AFC_MIN, SET_VAL_MIN_INC);
+#endif
+    branch(*this, iv_tmp, INT_VAR_SIZE_AFC_MIN, INT_VAL_MIN);
+    branch(*this, bv_tmp, INT_VAR_AFC_MIN, INT_VAL_MIN);
+#ifdef GECODE_HAS_SET_VARS
+    branch(*this, sv_tmp, SET_VAR_SIZE_AFC_MIN, SET_VAL_MIN_INC);
 #endif
-    }
   }
 
   AST::Array*
@@ -656,10 +665,12 @@ namespace Gecode { namespace FlatZinc {
       n_p = propagators();
     }
     Search::Options o;
-    o.stop = Driver::Cutoff::create(opt.node(), opt.fail(), opt.time());
+    o.stop = Driver::Cutoff::create(opt.node(), opt.fail(), opt.time(), 
+                                    true);
     o.c_d = opt.c_d();
     o.a_d = opt.a_d();
     o.threads = opt.threads();
+    Driver::Cutoff::installCtrlHandler(true);
     Engine<FlatZincSpace> se(this,o);
     int noOfSolutions = _method == SAT ? opt.solutions() : 0;
     int findSol = noOfSolutions;
@@ -689,6 +700,7 @@ namespace Gecode { namespace FlatZinc {
     }
     delete sol;
     stopped:
+    Driver::Cutoff::installCtrlHandler(false);
     if (opt.mode() == SM_STAT) {
       Gecode::Search::Statistics stat = se.statistics();
       out << endl
@@ -969,10 +981,17 @@ namespace Gecode { namespace FlatZinc {
 #endif
                        ) {
     if (_output == NULL) {
-      iv.resize(home, 0);
-      bv.resize(home, 0);
+      if (optVar == -1) {
+        iv = IntVarArray(home, 0);
+      } else {
+        IntVar ov = iv[optVar];
+        iv = IntVarArray(home, 1);
+        iv[0] = ov;
+        optVar = 0;
+      }
+      bv = BoolVarArray(home, 0);
 #ifdef GECODE_HAS_SET_VARS
-      sv.resize(home, 0);
+      sv = SetVarArray(home, 0);
 #endif
       return;
     }
@@ -996,35 +1015,25 @@ namespace Gecode { namespace FlatZinc {
         shrinkElement(ai,iv_new,bv_new,sv_new);
       }
     }
-    if (static_cast<int>(iv_new.size()) != iv.size()) {
-      IntVarArgs iva(iv_new.size());
-      for (map<int,int>::iterator i=iv_new.begin(); i != iv_new.end(); ++i) {
-        iva[(*i).second] = iv[(*i).first];
-      }
-      for (int i=iva.size(); i--;)
-        iv[i] = iva[i];
-      iv.resize(home, iva.size());
-    }
 
-    if (static_cast<int>(bv_new.size()) != bv.size()) {
-      BoolVarArgs bva(bv_new.size());
-      for (map<int,int>::iterator i=bv_new.begin(); i != bv_new.end(); ++i) {
-        bva[(*i).second] = bv[(*i).first];
-      }
-      for (int i=bva.size(); i--;)
-        bv[i] = bva[i];
-      bv.resize(home, bva.size());
+    IntVarArgs iva(iv_new.size());
+    for (map<int,int>::iterator i=iv_new.begin(); i != iv_new.end(); ++i) {
+      iva[(*i).second] = iv[(*i).first];
     }
+    iv = IntVarArray(home, iva);
+
+    BoolVarArgs bva(bv_new.size());
+    for (map<int,int>::iterator i=bv_new.begin(); i != bv_new.end(); ++i) {
+      bva[(*i).second] = bv[(*i).first];
+    }
+    bv = BoolVarArray(home, bva);
+
 #ifdef GECODE_HAS_SET_VARS
-    if (static_cast<int>(sv_new.size()) != sv.size()) {
-      SetVarArgs sva(sv_new.size());
-      for (map<int,int>::iterator i=sv_new.begin(); i != sv_new.end(); ++i) {
-        sva[(*i).second] = sv[(*i).first];
-      }
-      for (int i=sva.size(); i--;)
-        sv[i] = sva[i];
-      sv.resize(home, sva.size());
+    SetVarArgs sva(sv_new.size());
+    for (map<int,int>::iterator i=sv_new.begin(); i != sv_new.end(); ++i) {
+      sva[(*i).second] = sv[(*i).first];
     }
+    sv = SetVarArray(home, sva);
 #endif
   }
 
