@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2010-04-07 13:30:58 +0200 (Wed, 07 Apr 2010) $ by $Author: tack $
- *     $Revision: 10664 $
+ *     $Date: 2010-07-21 11:42:47 +0200 (Wed, 21 Jul 2010) $ by $Author: tack $
+ *     $Revision: 11243 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -565,32 +565,32 @@ namespace Gecode { namespace FlatZinc {
   
     void p_int_plus(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       if (!ce[0]->isIntVar()) {
-        post(s, ce[0]->getInt() + getIntVar(s, ce[1])
+        rel(s, ce[0]->getInt() + getIntVar(s, ce[1])
                 == getIntVar(s,ce[2]), ann2icl(ann));
       } else if (!ce[1]->isIntVar()) {
-        post(s, getIntVar(s,ce[0]) + ce[1]->getInt()
+        rel(s, getIntVar(s,ce[0]) + ce[1]->getInt()
                 == getIntVar(s,ce[2]), ann2icl(ann));
       } else if (!ce[2]->isIntVar()) {
-        post(s, getIntVar(s,ce[0]) + getIntVar(s,ce[1]) 
+        rel(s, getIntVar(s,ce[0]) + getIntVar(s,ce[1]) 
                 == ce[2]->getInt(), ann2icl(ann));
       } else {
-        post(s, getIntVar(s,ce[0]) + getIntVar(s,ce[1]) 
+        rel(s, getIntVar(s,ce[0]) + getIntVar(s,ce[1]) 
                 == getIntVar(s,ce[2]), ann2icl(ann));
       }
     }
 
     void p_int_minus(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       if (!ce[0]->isIntVar()) {
-        post(s, ce[0]->getInt() - getIntVar(s, ce[1])
+        rel(s, ce[0]->getInt() - getIntVar(s, ce[1])
                 == getIntVar(s,ce[2]), ann2icl(ann));
       } else if (!ce[1]->isIntVar()) {
-        post(s, getIntVar(s,ce[0]) - ce[1]->getInt()
+        rel(s, getIntVar(s,ce[0]) - ce[1]->getInt()
                 == getIntVar(s,ce[2]), ann2icl(ann));
       } else if (!ce[2]->isIntVar()) {
-        post(s, getIntVar(s,ce[0]) - getIntVar(s,ce[1]) 
+        rel(s, getIntVar(s,ce[0]) - getIntVar(s,ce[1]) 
                 == ce[2]->getInt(), ann2icl(ann));
       } else {
-        post(s, getIntVar(s,ce[0]) - getIntVar(s,ce[1]) 
+        rel(s, getIntVar(s,ce[0]) - getIntVar(s,ce[1]) 
                 == getIntVar(s,ce[2]), ann2icl(ann));
       }
     }
@@ -629,33 +629,19 @@ namespace Gecode { namespace FlatZinc {
     void p_int_negate(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       IntVar x0 = getIntVar(s, ce[0]);
       IntVar x1 = getIntVar(s, ce[1]);
-      post(s, x0 == -x1, ann2icl(ann));
+      rel(s, x0 == -x1, ann2icl(ann));
     }
 
     /* Boolean constraints */
     void p_bool_CMP(FlatZincSpace& s, IntRelType irt, const ConExpr& ce, 
                    AST::Node* ann) {
-      if (ce[0]->isBoolVar()) {
-        if (ce[1]->isBoolVar()) {
-          rel(s, getBoolVar(s, ce[0]), irt, getBoolVar(s, ce[1]), 
-              ann2icl(ann));
-        } else {
-          rel(s, getBoolVar(s, ce[0]), irt, ce[1]->getBool(), ann2icl(ann));
-        }
-      } else {
-        if (ce[1]->isBoolVar()) {
-          rel(s, getBoolVar(s, ce[1]), swap(irt), ce[0]->getBool(), 
-              ann2icl(ann));
-        } else {
-          if (ce[0]->getBool() != ce[1]->getBool())
-            s.fail();
-        }
-      }
+      rel(s, getBoolVar(s, ce[0]), irt, getBoolVar(s, ce[1]), 
+          ann2icl(ann));
     }
     void p_bool_CMP_reif(FlatZincSpace& s, IntRelType irt, const ConExpr& ce, 
                    AST::Node* ann) {
       rel(s, getBoolVar(s, ce[0]), irt, getBoolVar(s, ce[1]),
-            getBoolVar(s, ce[2]), ann2icl(ann));
+          getBoolVar(s, ce[2]), ann2icl(ann));
     }
     void p_bool_eq(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       p_bool_CMP(s, IRT_EQ, ce, ann);
@@ -771,7 +757,7 @@ namespace Gecode { namespace FlatZinc {
         }
       }
       IntVar selector = getIntVar(s, ce[0]);
-      post(s, selector > 0);
+      rel(s, selector > 0);
       if (isConstant) {
         IntArgs ia = arg2intargs(ce[1], 1);
         element(s, ia, selector, getIntVar(s, ce[2]), ann2icl(ann));
@@ -791,7 +777,7 @@ namespace Gecode { namespace FlatZinc {
         }
       }
       IntVar selector = getIntVar(s, ce[0]);
-      post(s, selector > 0);
+      rel(s, selector > 0);
       if (isConstant) {
         IntArgs ia = arg2boolargs(ce[1], 1);
         element(s, ia, selector, getBoolVar(s, ce[2]), ann2icl(ann));
@@ -1069,14 +1055,61 @@ namespace Gecode { namespace FlatZinc {
       int n = start.size();
       IntVar bound = getIntVar(s, ce[3]);
 
-      if (bound.assigned()) {
-        IntArgs machine(n);
-        for (int i = n; i--; ) machine[i] = 0;
-        IntArgs limit(1, bound.val());
-        IntVarArgs end(n);
-        for (int i = n; i--; ) end[i] = IntVar(s, 0, Int::Limits::max);
-        cumulatives(s, machine, start, duration, end, height, limit, true,
-                    ann2icl(ann));
+      int minHeight = INT_MAX; int minHeight2 = INT_MAX;
+      for (int i=n; i--;)
+        if (height[i].min() < minHeight)
+          minHeight = height[i].min();
+        else if (height[i].min() < minHeight2)
+          minHeight2 = height[i].min();
+      bool disjunctive =
+       (minHeight > bound.max()/2) ||
+       (minHeight2 > bound.max()/2 && minHeight+minHeight2>bound.max());
+      if (disjunctive) {
+        rel(s, bound >= max(height));
+        // Unary
+        if (duration.assigned()) {
+          IntArgs durationI(n);
+          bool allone = true;
+          for (int i=n; i--;) {
+            durationI[i] = duration[i].val();
+            if (durationI[i] != 1)
+              allone = false;
+          }
+          if (allone) {
+            distinct(s,start,ann2icl(ann));
+          } else {
+            unary(s,start,durationI);
+          }
+        } else {
+          IntVarArgs end(s,n,Int::Limits::min,Int::Limits::max);
+          for (int i=n; i--;)
+            rel(s,start[i]+duration[i]==end[i]);
+          unary(s,start,duration,end);
+        }
+      } else if (bound.assigned()) {
+        if (height.assigned()) {
+          IntArgs heightI(n);
+          for (int i=n; i--;)
+            heightI[i] = height[i].val();
+          if (duration.assigned()) {
+            IntArgs durationI(n);
+            for (int i=n; i--;)
+              durationI[i] = duration[i].val();
+            cumulative(s, bound.val(), start, durationI, heightI);
+          } else {
+            IntVarArgs end(n);
+            for (int i = n; i--; )
+              end[i] = expr(s, start[i]+duration[i]);
+            cumulative(s, bound.val(), start, duration, end, heightI);
+          }
+        } else {
+          IntArgs machine = IntArgs::create(n,0,0);
+          IntArgs limit(1, bound.val());
+          IntVarArgs end(n);
+          for (int i = n; i--; ) end[i] = IntVar(s, 0, Int::Limits::max);
+          cumulatives(s, machine, start, duration, end, height, limit, true,
+                      ann2icl(ann));
+        }        
       } else {
         int min = Gecode::Int::Limits::max;
         int max = Gecode::Int::Limits::min;
@@ -1084,14 +1117,14 @@ namespace Gecode { namespace FlatZinc {
         for (int i = start.size(); i--; ) {
           min = std::min(min, start[i].min());
           max = std::max(max, start[i].max() + duration[i].max());
-          end[i] = post(s, start[i] + duration[i]);
+          end[i] = expr(s, start[i] + duration[i]);
         }
         for (int time = min; time < max; ++time) {
           IntVarArgs x(start.size());
           for (int i = start.size(); i--; ) {
-            IntVar overlaps = channel(s, post(s, (~(start[i] <= time) && 
-                                                  ~(time < end[i]))));
-            x[i] = mult(s, overlaps, height[i]);
+            IntVar overlaps = channel(s, expr(s, (start[i] <= time) && 
+                                                 (time < end[i])));
+            x[i] = expr(s, overlaps * height[i]);
           }
           linear(s, x, IRT_LQ, bound);
         }
@@ -1383,13 +1416,13 @@ namespace Gecode { namespace FlatZinc {
           Iter::Ranges::Inter<IntSetRanges,Iter::Ranges::Singleton> i(dr,sr);
           IntSet d01(i);
           if (d01.size() == 0) {
-            post(s, getBoolVar(s, ce[2]) == 0);
+            rel(s, getBoolVar(s, ce[2]) == 0);
           } else if (d01.max() == 0) {
-            post(s, tt(eqv(getBoolVar(s, ce[2]), !getBoolVar(s, ce[0]))));
+            rel(s, getBoolVar(s, ce[2]) == !getBoolVar(s, ce[0]));
           } else if (d01.min() == 1) {
-            post(s, getBoolVar(s, ce[2]) == getBoolVar(s, ce[0]));
+            rel(s, getBoolVar(s, ce[2]) == getBoolVar(s, ce[0]));
           } else {
-            post(s, getBoolVar(s, ce[2]) == 1);
+            rel(s, getBoolVar(s, ce[2]) == 1);
           }
         } else {
           dom(s, getIntVar(s, ce[0]), d, getBoolVar(s, ce[2]));
@@ -1419,7 +1452,7 @@ namespace Gecode { namespace FlatZinc {
         }
       }
       IntVar selector = getIntVar(s, ce[0]);
-      post(s, selector > 0);
+      rel(s, selector > 0);
       if (isConstant) {
         IntSetArgs sv = arg2intsetargs(s,ce[1],1);
         element(s, sv, selector, getSetVar(s, ce[2]));
