@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2010-03-30 15:49:32 +0200 (Tue, 30 Mar 2010) $ by $Author: tack $
- *     $Revision: 10604 $
+ *     $Date: 2010-04-21 14:22:14 +0200 (Wed, 21 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10784 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -264,7 +264,8 @@ namespace Gecode { namespace Gist {
         }
         break;
       case Gist::BRANCH:
-        painter.setBrush(QBrush(blue));
+        painter.setBrush(n->childrenLayoutIsDone() ? QBrush(blue) : 
+                                                     QBrush(white));
         painter.drawEllipse(myx-halfNodeWidth, myy, nodeWidth, nodeWidth);
         break;
       case Gist::UNDETERMINED:
