@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2010-04-07 14:24:53 +0200 (Wed, 07 Apr 2010) $ by $Author: tack $
- *     $Revision: 10668 $
+ *     $Date: 2010-04-21 14:22:14 +0200 (Wed, 21 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10784 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -555,6 +555,7 @@ namespace Gecode { namespace Gist {
       inspectBeforeFPGroup->setEnabled(false);
       compareNode->setEnabled(false);
       compareNodeBeforeFP->setEnabled(false);
+      showNodeStats->setEnabled(false);
       stop->setEnabled(true);
       reset->setEnabled(false);
       navUp->setEnabled(false);
@@ -612,6 +613,7 @@ namespace Gecode { namespace Gist {
       toggleStop->setEnabled(n->getStatus() == STOP ||
         n->getStatus() == UNSTOP);
 
+      showNodeStats->setEnabled(true);
       inspect->setEnabled(true);
       if (n->getStatus() == UNDETERMINED) {
         inspectGroup->setEnabled(false);
