@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-09-29 12:49:42 +0200 (Tue, 29 Sep 2009) $ by $Author: tack $
- *     $Revision: 9766 $
+ *     $Date: 2010-03-30 12:12:40 +0200 (Tue, 30 Mar 2010) $ by $Author: tack $
+ *     $Revision: 10596 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -102,7 +102,7 @@ namespace Gecode { namespace Gist {
   forceinline
   SpaceNode::SpaceNode(void)
   : copy(NULL), workingSpace(NULL), ownBest(NULL), nstatus(0) {
-    desc.branch = NULL;
+    choice = NULL;
     setStatus(UNDETERMINED);
     setHasSolvedChildren(false);
     setHasFailedChildren(false);
@@ -140,26 +140,6 @@ namespace Gecode { namespace Gist {
     return curBest != NULL && curBest->s == this;
   }
 
-  forceinline void
-  SpaceNode::setSpecialDesc(const SpecialDesc* d) {
-    desc.special = d;
-  }
-
-  forceinline void
-  SpaceNode::setStepDesc(StepDesc* d) {
-    desc.step = d;
-  }
-
-  forceinline bool
-  SpaceNode::isStepNode(void) {
-    return getStatus() == STEP;
-  }
-
-  forceinline StepDesc*
-  SpaceNode::getStepDesc(void) {
-    return (isStepNode() ? desc.step : NULL);
-  }
-
   forceinline bool
   SpaceNode::isOpen(void) {
     return ((getStatus() == UNDETERMINED) ||
@@ -202,6 +182,11 @@ namespace Gecode { namespace Gist {
     return -1;
   }
 
+  forceinline const Choice*
+  SpaceNode::getChoice(void) {
+    return choice;
+  }
+
 }}
 
 // STATISTICS: gist-any
