@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2010-04-08 11:25:15 +0200 (Thu, 08 Apr 2010) $ by $Author: tack $
- *     $Revision: 10682 $
+ *     $Date: 2010-05-11 11:00:07 +0200 (Tue, 11 May 2010) $ by $Author: tack $
+ *     $Revision: 10936 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -247,6 +247,13 @@ namespace Gecode { namespace Gist {
   void
   TreeCanvas::layoutDone(int w, int h, int scale0) {
     targetW = w; targetH = h; targetScale = scale0;
+
+    QSize viewport_size = size();
+    QAbstractScrollArea* sa =
+      static_cast<QAbstractScrollArea*>(parentWidget()->parentWidget());
+    sa->horizontalScrollBar()->setRange(0,w-viewport_size.width());
+    sa->verticalScrollBar()->setRange(0,h-viewport_size.height());
+
     if (layoutDoneTimerId == 0)
       layoutDoneTimerId = startTimer(15);
   }
@@ -323,6 +330,7 @@ namespace Gecode { namespace Gist {
                              t->root->getShape()->depth()*Layout::dist_y*scale);
       }
     }
+
     t->layoutMutex.unlock();
     emit update(w,h,scale0);
   }
@@ -598,92 +606,122 @@ namespace Gecode { namespace Gist {
       return;
     }
 
-    switch (currentNode->getStatus()) {
-    case UNDETERMINED:
-        {
-          unsigned int kids =  
-            currentNode->getNumberOfChildNodes(*na,curBest,stats,c_d,a_d);
-          int depth = -1;
-          for (VisualNode* p = currentNode; p != NULL; p = p->getParent())
-            depth++;
-          if (kids > 0)
-            depth++;
-          stats.maxDepth =
-            std::max(stats.maxDepth, depth);
-          if (currentNode->getStatus() == SOLVED) {
-            assert(currentNode->hasWorkingSpace());
-            emit solution(currentNode->getWorkingSpace());
-            currentNode->purge();
-          }
-          emit statusChanged(currentNode,stats,true);
-          Space* curSpace = currentNode->getSpace(curBest,c_d,a_d);
-          for (int i=0; i<moveInspectors.size(); i++) {
-            if (moveInspectors[i].second) {
-              moveInspectors[i].first->inspect(*curSpace);
+    int failedInspectorType = -1;
+    int failedInspector = -1;
+    try {
+      switch (currentNode->getStatus()) {
+      case UNDETERMINED:
+          {
+            unsigned int kids =  
+              currentNode->getNumberOfChildNodes(*na,curBest,stats,c_d,a_d);
+            int depth = -1;
+            for (VisualNode* p = currentNode; p != NULL; p = p->getParent())
+              depth++;
+            if (kids > 0)
+              depth++;
+            stats.maxDepth =
+              std::max(stats.maxDepth, depth);
+            if (currentNode->getStatus() == SOLVED) {
+              assert(currentNode->hasWorkingSpace());
+              emit solution(currentNode->getWorkingSpace());
+              currentNode->purge();
+            }
+            emit statusChanged(currentNode,stats,true);
+            for (int i=0; i<moveInspectors.size(); i++) {
+              if (moveInspectors[i].second) {
+                failedInspectorType = 0;
+                failedInspector = i;
+                moveInspectors[i].first->
+                  inspect(*currentNode->getWorkingSpace());
+                failedInspectorType = -1;
+              }
             }
           }
+          break;
+      case FAILED:
+      case STOP:
+      case UNSTOP:
+      case BRANCH:
+      case SOLVED:
+        {
+          // SizeCursor sc(currentNode);
+          // PreorderNodeVisitor<SizeCursor> pnv(sc);
+          // int nodes = 1;
+          // while (pnv.next()) { nodes++; }
+          // std::cout << "sizeof(VisualNode): " << sizeof(VisualNode)
+          //           << std::endl;
+          // std::cout << "Size: " << (pnv.getCursor().s)/1024 << std::endl;
+          // std::cout << "Nodes: " << nodes << std::endl;
+          // std::cout << "Size / node: " << (pnv.getCursor().s)/nodes
+          //           << std::endl;
+
+          Space* curSpace;
+        
+          if (fix) {
+            if (currentNode->isRoot() && currentNode->getStatus() == FAILED)
+              break;
+            curSpace = currentNode->getSpace(curBest,c_d,a_d);
+            if (currentNode->getStatus() == SOLVED &&
+                curSpace->status() != SS_SOLVED) {
+              // in the presence of weakly monotonic propagators, we may have to
+              // use search to find the solution here
+              Space* dfsSpace = Gecode::dfs(curSpace);
+              delete curSpace;
+              curSpace = dfsSpace;
+            }          
+          } else {
+            if (currentNode->isRoot())
+              break;
+            VisualNode* p = currentNode->getParent();
+            curSpace = p->getSpace(curBest,c_d,a_d);
+            switch (curSpace->status()) {
+            case SS_SOLVED:
+            case SS_FAILED:
+              break;
+            case SS_BRANCH:
+              curSpace->commit(*p->getChoice(), currentNode->getAlternative());
+              break;
+            default:
+              GECODE_NEVER;
+            }
+          }
+
+          if (inspectorNo==-1) {
+            for (int i=0; i<doubleClickInspectors.size(); i++) {
+              if (doubleClickInspectors[i].second) {
+                failedInspectorType = 1;
+                failedInspector = i;
+                doubleClickInspectors[i].first->inspect(*curSpace);
+                failedInspectorType = -1;
+              }
+            }
+          } else {
+            failedInspectorType = 1;
+            failedInspector = inspectorNo;
+            doubleClickInspectors[inspectorNo].first->inspect(*curSpace);
+            failedInspectorType = -1;
+          }
+          delete curSpace;
         }
         break;
-    case FAILED:
-    case STOP:
-    case UNSTOP:
-    case BRANCH:
-    case SOLVED:
-      {
-        // SizeCursor sc(currentNode);
-        // PreorderNodeVisitor<SizeCursor> pnv(sc);
-        // int nodes = 1;
-        // while (pnv.next()) { nodes++; }
-        // std::cout << "sizeof(VisualNode): " << sizeof(VisualNode)
-        //           << std::endl;
-        // std::cout << "Size: " << (pnv.getCursor().s)/1024 << std::endl;
-        // std::cout << "Nodes: " << nodes << std::endl;
-        // std::cout << "Size / node: " << (pnv.getCursor().s)/nodes
-        //           << std::endl;
-
-        Space* curSpace;
-        
-        if (fix) {
-          if (currentNode->isRoot() && currentNode->getStatus() == FAILED)
-            break;
-          curSpace = currentNode->getSpace(curBest,c_d,a_d);
-          if (currentNode->getStatus() == SOLVED &&
-              curSpace->status() != SS_SOLVED) {
-            // in the presence of weakly monotonic propagators, we may have to
-            // use search to find the solution here
-            Space* dfsSpace = Gecode::dfs(curSpace);
-            delete curSpace;
-            curSpace = dfsSpace;
-          }          
-        } else {
-          if (currentNode->isRoot())
-            break;
-          VisualNode* p = currentNode->getParent();
-          curSpace = p->getSpace(curBest,c_d,a_d);
-          switch (curSpace->status()) {
-          case SS_SOLVED:
-          case SS_FAILED:
-            break;
-          case SS_BRANCH:
-            curSpace->commit(*p->getChoice(), currentNode->getAlternative());
-            break;
-          default:
-            GECODE_NEVER;
-          }
-        }
-
-        if (inspectorNo==-1) {
-          for (int i=0; i<doubleClickInspectors.size(); i++) {
-            if (doubleClickInspectors[i].second) {
-              doubleClickInspectors[i].first->inspect(*curSpace);
-            }
-          }
-        } else {
-          doubleClickInspectors[inspectorNo].first->inspect(*curSpace);          
-        }
-        delete curSpace;
       }
-      break;
+    } catch (Exception e) {
+      switch (failedInspectorType) {
+      case 0:
+        std::cerr << "Exception in move inspector "
+                  << failedInspector;
+        break;
+      case 1:
+        std::cerr << "Exception in double-click inspector "
+                  << failedInspector;
+        break;
+      default:
+        std::cerr << "Exception ";
+        break;
+      }
+      std::cerr << ": " << e.what() << "." << std::endl;
+      std::cerr << "Stopping..." << std::endl;
+      std::exit(EXIT_FAILURE);
     }
 
     currentNode->dirtyUp();
@@ -698,22 +736,49 @@ namespace Gecode { namespace Gist {
 
   void
   TreeCanvas::inspectSolution(const Space* s) {
-    Space* c = NULL;
-    for (int i=0; i<solutionInspectors.size(); i++) {
-      if (solutionInspectors[i].second) {
-        if (c == NULL)
-          c = s->clone();
-        solutionInspectors[i].first->inspect(*c);
+    int failedInspectorType = -1;
+    int failedInspector = -1;
+    try {
+      Space* c = NULL;
+      for (int i=0; i<solutionInspectors.size(); i++) {
+        if (solutionInspectors[i].second) {
+          if (c == NULL)
+            c = s->clone();
+          failedInspectorType = 1;
+          failedInspector = i;
+          solutionInspectors[i].first->inspect(*c);
+          failedInspectorType = -1;
+        }
       }
-    }
-    for (int i=0; i<moveInspectors.size(); i++) {
-      if (moveInspectors[i].second) {
-        if (c == NULL)
-          c = s->clone();
-        moveInspectors[i].first->inspect(*c);
+      for (int i=0; i<moveInspectors.size(); i++) {
+        if (moveInspectors[i].second) {
+          if (c == NULL)
+            c = s->clone();
+          failedInspectorType = 0;
+          failedInspector = i;
+          moveInspectors[i].first->inspect(*c);
+          failedInspectorType = -1;
+        }
       }
+      delete c;
+    } catch (Exception e) {
+      switch (failedInspectorType) {
+      case 0:
+        std::cerr << "Exception in move inspector "
+                  << failedInspector;
+        break;
+      case 1:
+        std::cerr << "Exception in solution inspector "
+                  << failedInspector;
+        break;
+      default:
+        std::cerr << "Exception ";
+        break;
+      }
+      std::cerr << ": " << e.what() << "." << std::endl;
+      std::cerr << "Stopping..." << std::endl;
+      std::exit(EXIT_FAILURE);      
     }
-    delete c;
   }
 
   void
@@ -1205,19 +1270,27 @@ namespace Gecode { namespace Gist {
         if (moveInspectors[i].second) {
           if (curSpace == NULL)
             curSpace = n->getSpace(curBest,c_d,a_d);
-          moveInspectors[i].first->inspect(*curSpace);
+          try {
+            moveInspectors[i].first->inspect(*curSpace);
+          } catch (Exception e) {
+            std::cerr << "Exception in move inspector " << i
+                      << ": " << e.what() << "." << std::endl;
+            std::cerr << "Stopping..." << std::endl;
+            std::exit(EXIT_FAILURE);
+          }
         }
       }
     }
     if (n != NULL) {
-      compareNodes = false;
-      setCursor(QCursor(Qt::ArrowCursor));
       currentNode->setMarked(false);
       currentNode = n;
       currentNode->setMarked(true);
       emit statusChanged(currentNode,stats,true);
-      if (update)
+      if (update) {
+        compareNodes = false;
+        setCursor(QCursor(Qt::ArrowCursor));
         QWidget::update();
+      }
     }
   }
 
