@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-09-29 12:49:42 +0200 (Tue, 29 Sep 2009) $ by $Author: tack $
- *     $Revision: 9766 $
+ *     $Date: 2010-03-30 15:49:32 +0200 (Tue, 30 Mar 2010) $ by $Author: tack $
+ *     $Revision: 10604 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -111,6 +111,14 @@ namespace Gecode { namespace Gist {
     setFlag(HIDDEN, h);
   }
 
+  forceinline void
+  VisualNode::setStop(bool h) {
+    if (getStatus() == BRANCH && h)
+      setStatus(STOP);
+    else if (getStatus() == STOP && !h)
+      setStatus(UNSTOP);
+  }
+
   forceinline int
   VisualNode::getOffset(void) { return offset; }
 
@@ -147,6 +155,16 @@ namespace Gecode { namespace Gist {
     setFlag(MARKED, m);
   }
 
+  forceinline bool
+  VisualNode::isBookmarked(void) {
+    return getFlag(BOOKMARKED);
+  }
+
+  forceinline void
+  VisualNode::setBookmarked(bool m) {
+    setFlag(BOOKMARKED, m);
+  }
+
   forceinline bool
   VisualNode::isOnPath(void) {
     return getFlag(ONPATH);
