@@ -7,8 +7,8 @@
  *     Christian Schulte, 2006
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10365 $
+ *     $Date: 2010-06-04 16:13:00 +0200 (Fri, 04 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11028 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -77,9 +77,7 @@ namespace Gecode {
           const IntVarArgs& x, IntVar z, 
           IntConLevel icl) {
     if (home.failed()) return;
-    IntVarArgs y(x.size());
-    for (int i=x.size(); i--; )
-      y[i].init(home, Int::Limits::min, Int::Limits::max);
+    IntVarArgs y(home, x.size(), Int::Limits::min, Int::Limits::max);
     circuit(home, c, x, y, z, icl);
   }
 
