@@ -7,8 +7,8 @@
  *     Guido Tack, 2008
  *
  *  Last modified:
- *     $Date: 2009-11-04 17:06:58 +0100 (Wed, 04 Nov 2009) $ by $Author: tack $
- *     $Revision: 10046 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -87,7 +87,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
           static_cast<Val>(x2.max())+static_cast<Val>(1))));
     } while (mod);
     return x0.assigned() && x1.assigned() ?
-      ES_SUBSUMED(*this,sizeof(*this)) : ES_FIX;
+      home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
   template<class Val, class VA, class VB, class VC>
@@ -238,7 +238,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     if (x0.val()/x1.val() < 0)
       result = -result;
     GECODE_ME_CHECK(x2.eq(home,result));
-    return ES_SUBSUMED(*this,sizeof(*this));
+    return home.ES_SUBSUMED(*this);
   }
 
   template<class View>
@@ -340,7 +340,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
                            std::max(x2.min(),-x2.min())));
       int x1absmin = any(x1) ? 0 : (pos(x1) ? x1.min() : -x1.max());
       if (x2max < x1absmin)
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
