@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -114,13 +114,13 @@ namespace Gecode { namespace Int { namespace Arithmetic {
   template<class View>
   ExecStatus
   MaxBnd<View>::propagate(Space& home, const ModEventDelta&) {
-    GECODE_ME_CHECK(prop_max_bnd(home,x0,x1,x2));
+    GECODE_ES_CHECK(prop_max_bnd(home,x0,x1,x2));
     if ((x0.max() <= x1.min()) || (x0.max() < x2.min()))
       GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home(*this),x1,x2)));
     if ((x1.max() <= x0.min()) || (x1.max() < x2.min()))
       GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home(*this),x0,x2)));
     return x0.assigned() && x1.assigned() && x2.assigned() ?
-      ES_SUBSUMED(*this,sizeof(*this)) : ES_FIX;
+      home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
   /*
@@ -216,7 +216,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     if ((status & MPS_REMOVED) != 0)
       goto rerun;
     if (((status & MPS_ASSIGNED) != 0) && y.assigned())
-      return ES_SUBSUMED(p,sizeof(p));
+      return home.ES_SUBSUMED(p);
     return ((status & MPS_NEW_BOUND) != 0) ? ES_NOFIX : ES_FIX;
   }
 
@@ -280,14 +280,14 @@ namespace Gecode { namespace Int { namespace Arithmetic {
   ExecStatus
   MaxDom<View>::propagate(Space& home, const ModEventDelta& med) {
     if (View::me(med) != ME_INT_DOM) {
-      GECODE_ME_CHECK(prop_max_bnd(home,x0,x1,x2));
+      GECODE_ES_CHECK(prop_max_bnd(home,x0,x1,x2));
       if ((x0.max() <= x1.min()) || (x0.max() < x2.min()))
         GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home(*this),x1,x2)));
       if ((x1.max() <= x0.min()) || (x1.max() < x2.min()))
         GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home(*this),x0,x2)));
       return x0.assigned() && x1.assigned() && x2.assigned() ?
-        ES_SUBSUMED(*this,sizeof(*this)) :
-        ES_NOFIX_PARTIAL(*this,View::med(ME_INT_DOM));
+        home.ES_SUBSUMED(*this) :
+        home.ES_NOFIX_PARTIAL(*this,View::med(ME_INT_DOM));
     }
     ViewRanges<View> r0(x0), r1(x1);
     Iter::Ranges::Union<ViewRanges<View>,ViewRanges<View> > u(r0,r1);
@@ -371,8 +371,8 @@ namespace Gecode { namespace Int { namespace Arithmetic {
       ExecStatus es = prop_nary_max_bnd(home,*this,x,y,PC_INT_DOM);
       GECODE_ES_CHECK(es);
       return (es == ES_FIX) ?
-        ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM)) :
-        ES_NOFIX_PARTIAL(*this,View::med(ME_INT_DOM));
+        home.ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM)) :
+        home.ES_NOFIX_PARTIAL(*this,View::med(ME_INT_DOM));
     }
     Region r(home);
     ViewRanges<View>* i_x = r.alloc<ViewRanges<View> >(x.size());
