@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-06-03 13:46:55 +0200 (Thu, 03 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11014 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -542,7 +542,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
       GECODE_ES_CHECK((prop_mult_plus_bnd<Val,VA,VB,VC>(home,*this,x0,x1,x2)));
       return home.ES_FIX_PARTIAL(*this,VA::med(ME_INT_DOM));
     }
-    IntView y0(x0.var()), y1(x1.var()), y2(x2.var());
+    IntView y0(x0.varimp()), y1(x1.varimp()), y2(x2.varimp());
     return prop_mult_dom<Val,IntView>(home,*this,y0,y1,y2);
   }
 
