@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -110,7 +110,7 @@ namespace Gecode { namespace Int { namespace Bool {
     default:
       GECODE_NEVER;
     }
-    return ES_SUBSUMED(*this,sizeof(*this));
+    return home.ES_SUBSUMED(*this);
 #undef GECODE_INT_STATUS
   }
 
@@ -182,7 +182,7 @@ namespace Gecode { namespace Int { namespace Bool {
           for (int j=i+1; j<n; j++)
             GECODE_ME_CHECK(x[j].zero(home));
         }
-        return ES_SUBSUMED(*this,sizeof(*this));
+        return home.ES_SUBSUMED(*this);
       }
       i++;
     }
