@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-11 22:16:29 +0100 (Thu, 11 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10418 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,33 +50,33 @@ namespace Gecode {
     case INT_ASSIGN_MIN:
       {
         Branch::AssignValMin<IntView> a(home,o_vals);
-        (void) new (home) ViewValBrancher
+        ViewValBrancher
           <ViewSelNone<IntView>,Branch::AssignValMin<IntView> >
-          (home,xv,v,a);
+          ::post(home,xv,v,a);
       }
       break;
     case INT_ASSIGN_MED:
       {
         Branch::AssignValMed<IntView> a(home,o_vals);
-        (void) new (home) ViewValBrancher
+        ViewValBrancher
           <ViewSelNone<IntView>,Branch::AssignValMed<IntView> >
-          (home,xv,v,a);
+          ::post(home,xv,v,a);
       }
       break;
     case INT_ASSIGN_MAX:
       {
         Branch::AssignValMin<MinusView> a(home,o_vals);
-        (void) new (home) ViewValBrancher
+        ViewValBrancher
           <ViewSelNone<IntView>,Branch::AssignValMin<MinusView> >
-          (home,xv,v,a);
+          ::post(home,xv,v,a);
       }
       break;
     case INT_ASSIGN_RND:
       {
         Branch::AssignValRnd<IntView> a(home,o_vals);
-        (void) new (home) ViewValBrancher
+        ViewValBrancher
           <ViewSelNone<IntView>,Branch::AssignValRnd<IntView> >
-          (home,xv,v,a);
+          ::post(home,xv,v,a);
       }
       break;
     default:
@@ -95,23 +95,23 @@ namespace Gecode {
     case INT_ASSIGN_MIN:
     case INT_ASSIGN_MED: {
         Branch::AssignValZero<BoolView> a(home,o_vals);
-        (void) new (home) ViewValBrancher
+        ViewValBrancher
           <ViewSelNone<BoolView>,Branch::AssignValZero<BoolView> >
-          (home,xv,v,a);
+          ::post(home,xv,v,a);
       }
       break;
     case INT_ASSIGN_MAX: {
         Branch::AssignValZero<NegBoolView> a(home,o_vals);
-        (void) new (home) ViewValBrancher
+        ViewValBrancher
           <ViewSelNone<BoolView>,Branch::AssignValZero<NegBoolView> >
-          (home,xv,v,a);
+          ::post(home,xv,v,a);
       }
       break;
     case INT_ASSIGN_RND: {
         Branch::AssignValRnd<BoolView> a(home,o_vals);
-        (void) new (home) ViewValBrancher
+        ViewValBrancher
           <ViewSelNone<BoolView>,Branch::AssignValRnd<BoolView> >
-          (home,xv,v,a);
+          ::post(home,xv,v,a);
       }
       break;
     default:
