@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-10-20 13:28:57 +0200 (Tue, 20 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9975 $
+ *     $Date: 2010-03-11 22:16:29 +0100 (Thu, 11 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10418 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,8 +50,8 @@ namespace Gecode { namespace Int { namespace Branch {
     case INT_VALUES_MIN:
       {
         ValZeroOne<BoolView> a(home,o_vals);
-        (void) new (home) ViewValBrancher<SelView,ValZeroOne<BoolView> >
-          (home,x,v,a);
+        ViewValBrancher<SelView,ValZeroOne<BoolView> >
+          ::post(home,x,v,a);
       }
       break;
     case INT_VAL_MAX:
@@ -60,15 +60,15 @@ namespace Gecode { namespace Int { namespace Branch {
     case INT_VALUES_MAX:
       {
         ValZeroOne<NegBoolView> a(home,o_vals);
-        (void) new (home) ViewValBrancher<SelView,ValZeroOne<NegBoolView> >
-          (home,x,v,a);
+        ViewValBrancher<SelView,ValZeroOne<NegBoolView> >
+          ::post(home,x,v,a);
       }
       break;
     case INT_VAL_RND:
       {
         ValRnd<BoolView> a(home,o_vals);
-        (void) new (home) ViewValBrancher<SelView,ValRnd<BoolView> >
-          (home,x,v,a);
+        ViewValBrancher<SelView,ValRnd<BoolView> >
+          ::post(home,x,v,a);
       }
       break;
     default:
