@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -71,7 +71,6 @@ namespace Gecode { namespace Int { namespace Count {
   template<class VX, class VY, class VZ, bool shr>
   forceinline size_t
   BaseView<VX,VY,VZ,shr>::dispose(Space& home) {
-    assert(!home.failed());
     x.cancel(home,*this,PC_INT_DOM);
     y.cancel(home,*this,PC_INT_DOM);
     z.cancel(home,*this,PC_INT_BND);
@@ -170,9 +169,9 @@ namespace Gecode { namespace Int { namespace Count {
 
     if (z.assigned()) {
       if (z.val() == atleast())
-        return post_false(home,x,y) ? ES_FAILED : ES_SUBSUMED(*this,home);
+        return post_false(home,x,y) ? ES_FAILED : home.ES_SUBSUMED(*this);
       if (z.val() == atmost())
-        return post_true(home,x,y) ? ES_FAILED : ES_SUBSUMED(*this,home);
+        return post_true(home,x,y) ? ES_FAILED : home.ES_SUBSUMED(*this);
       GECODE_REWRITE(*this,(EqInt<VX,VY>::post(home(*this),x,y,z.val()+c)));
     }
     return shr ? ES_NOFIX : ES_FIX;
@@ -220,12 +219,12 @@ namespace Gecode { namespace Int { namespace Count {
     count(home);
     if (atleast() == atmost()) {
       GECODE_ME_CHECK(z.nq(home,atleast()));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     if (z.max() < atleast())
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     if (z.min() > atmost())
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     if (z.assigned())
       GECODE_REWRITE(*this,(NqInt<VX,VY>::post(home(*this),x,y,z.val()+c)));
     return ES_FIX;
@@ -275,9 +274,9 @@ namespace Gecode { namespace Int { namespace Count {
     count(home);
     GECODE_ME_CHECK(z.gq(home,atleast()));
     if (z.max() == atleast())
-      return post_false(home,x,y) ? ES_FAILED : ES_SUBSUMED(*this,home);
+      return post_false(home,x,y) ? ES_FAILED : home.ES_SUBSUMED(*this);
     if (x.size() == 0)
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     if (z.assigned())
       GECODE_REWRITE(*this,(LqInt<VX,VY>::post(home(*this),x,y,z.val()+c)));
     return shr ? ES_NOFIX : ES_FIX;
@@ -328,9 +327,9 @@ namespace Gecode { namespace Int { namespace Count {
     GECODE_ME_CHECK(z.lq(home,atmost()));
 
     if (z.min() == atmost())
-      return post_true(home,x,y) ? ES_FAILED : ES_SUBSUMED(*this,home);
+      return post_true(home,x,y) ? ES_FAILED : home.ES_SUBSUMED(*this);
     if (x.size() == 0)
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     if (z.assigned())
       GECODE_REWRITE(*this,(GqInt<VX,VY>::post(home(*this),x,y,z.val()+c)));
     return shr ? ES_NOFIX : ES_FIX;
