@@ -9,8 +9,8 @@
  *     Gabor Szokoli, 2003
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10365 $
+ *     $Date: 2010-06-03 20:34:20 +0200 (Thu, 03 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11017 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -78,7 +78,7 @@ namespace Gecode {
       Limits::check(c[i],"Int::distinct");
       Limits::check(cx_min,"Int::distinct");
       Limits::check(cx_max,"Int::distinct");
-      cx[i].init(x[i],c[i]);
+      cx[i] = OffsetView(x[i],c[i]);
     }
     switch (icl) {
     case ICL_BND:
