@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -703,18 +703,18 @@ namespace Gecode { namespace Int { namespace Distinct {
       ExecStatus es = prop_val<View,false>(home,x);
       GECODE_ES_CHECK(es);
       if (x.size() < 2)
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       if (es == ES_FIX)
-        return ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM));
+        return home.ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM));
       es = prop_bnd<View>(home,x);
       GECODE_ES_CHECK(es);
       if (x.size() < 2)
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       es = prop_val<View,true>(home,x);
       GECODE_ES_CHECK(es);
       if (x.size() < 2)
-        return ES_SUBSUMED(*this,home);
-      return ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM));
+        return home.ES_SUBSUMED(*this);
+      return home.ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM));
     }
 
     if (x.size() == 2)
