@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -81,23 +81,17 @@ namespace Gecode { namespace Int { namespace Dom {
     if (b.one()) {
       GECODE_ME_CHECK(x0.gq(home,min));
       GECODE_ME_CHECK(x0.lq(home,max));
-      goto subsumed;
-    }
-    if (b.zero()) {
+    } else if (b.zero()) {
       Iter::Ranges::Singleton r(min,max);
       GECODE_ME_CHECK(x0.minus_r(home,r,false));
-      goto subsumed;
+    } else if ((x0.max() <= max) && (x0.min() >= min)) {
+      GECODE_ME_CHECK(b.one_none(home));
+    } else if ((x0.max() < min) || (x0.min() > max)) {
+      GECODE_ME_CHECK(b.zero_none(home));
+    } else {
+      return ES_FIX;
     }
-    if ((x0.max() <= max) && (x0.min() >= min)) {
-      GECODE_ME_CHECK(b.one_none(home));  goto subsumed;
-    }
-    if ((x0.max() < min) || (x0.min() > max)) {
-      GECODE_ME_CHECK(b.zero_none(home)); goto subsumed;
-    }
-    return ES_FIX;
-  subsumed:
-    x0.cancel(home,*this,PC_INT_BND);
-    return ES_SUBSUMED(*this,sizeof(*this));
+    return home.ES_SUBSUMED(*this);
   }
 
 
