@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-05-28 20:54:33 +0200 (Fri, 28 May 2010) $ by $Author: schulte $
+ *     $Revision: 10982 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,10 +50,11 @@ namespace Gecode { namespace Int { namespace Element {
     return idx<0;
   }
 
+
   // Index iterator
   template<class V0, class V1, class Idx, class Val>
   forceinline
-  Int<V0,V1,Idx,Val>::IterIdx::IterIdx(IdxVal* iv0)
+  Int<V0,V1,Idx,Val>::IterIdxUnmark::IterIdxUnmark(IdxVal* iv0)
     : iv(iv0) {
     Idx p=0;
     i = iv[p].idx_next;
@@ -63,12 +64,12 @@ namespace Gecode { namespace Int { namespace Element {
   }
   template<class V0, class V1, class Idx, class Val>
   forceinline bool
-  Int<V0,V1,Idx,Val>::IterIdx::operator ()(void) const {
+  Int<V0,V1,Idx,Val>::IterIdxUnmark::operator ()(void) const {
     return i != 0;
   }
   template<class V0, class V1, class Idx, class Val>
   forceinline void
-  Int<V0,V1,Idx,Val>::IterIdx::operator ++(void) {
+  Int<V0,V1,Idx,Val>::IterIdxUnmark::operator ++(void) {
     int p=i;
     i = iv[p].idx_next;
     while ((i != 0) && iv[i].marked())
@@ -77,7 +78,7 @@ namespace Gecode { namespace Int { namespace Element {
   }
   template<class V0, class V1, class Idx, class Val>
   forceinline Idx
-  Int<V0,V1,Idx,Val>::IterIdx::val(void) const {
+  Int<V0,V1,Idx,Val>::IterIdxUnmark::val(void) const {
     assert(!iv[i].marked());
     return iv[i].idx;
   }
@@ -107,6 +108,39 @@ namespace Gecode { namespace Int { namespace Element {
 
 
 
+  template<class V0, class V1, class Idx, class Val>
+  forceinline
+  Int<V0,V1,Idx,Val>::IterValUnmark::IterValUnmark(IdxVal* iv0)
+    : iv(iv0) {
+    Idx p=0;
+    i = iv[p].val_next;
+    while ((i != 0) && iv[i].marked())
+      i=iv[i].val_next;
+    iv[p].val_next=i;
+  }
+  template<class V0, class V1, class Idx, class Val>
+  forceinline bool
+  Int<V0,V1,Idx,Val>::IterValUnmark::operator ()(void) const {
+    return i != 0;
+  }
+  template<class V0, class V1, class Idx, class Val>
+  forceinline void
+  Int<V0,V1,Idx,Val>::IterValUnmark::operator ++(void) {
+    int p=i;
+    i = iv[p].val_next;
+    while ((i != 0) && iv[i].marked())
+      i=iv[i].val_next;
+    iv[p].val_next=i;
+  }
+  template<class V0, class V1, class Idx, class Val>
+  forceinline Val
+  Int<V0,V1,Idx,Val>::IterValUnmark::val(void) const {
+    assert(!iv[i].marked());
+    return iv[i].val;
+  }
+
+
+
   // Sort function
   template<class V0, class V1, class Idx, class Val>
   forceinline
@@ -126,7 +160,7 @@ namespace Gecode { namespace Int { namespace Element {
   template<class V0, class V1, class Idx, class Val>
   forceinline
   Int<V0,V1,Idx,Val>::Int(Home home, IntSharedArray& c0, V0 y0, V1 y1)
-    : Propagator(home), x0(y0), x1(y1), c(c0), iv(NULL) {
+    : Propagator(home), x0(y0), s0(0), x1(y1), s1(0), c(c0), iv(NULL) {
     home.notice(*this,AP_DISPOSE);
     x0.subscribe(home,*this,PC_INT_DOM);
     x1.subscribe(home,*this,PC_INT_DOM);
@@ -148,6 +182,8 @@ namespace Gecode { namespace Int { namespace Element {
   Int<V0,V1,Idx,Val>::post(Home home, IntSharedArray& c, V0 x0, V1 x1) {
     if (x0.assigned()) {
       GECODE_ME_CHECK(x1.eq(home,c[x0.val()]));
+    } else if (x1.assigned()) {
+      GECODE_ES_CHECK(assigned_val(home,c,x0,x1));
     } else {
       (void) new (home) Int<V0,V1,Idx,Val>(home,c,x0,x1);
     }
@@ -157,7 +193,7 @@ namespace Gecode { namespace Int { namespace Element {
   template<class V0, class V1, class Idx, class Val>
   forceinline
   Int<V0,V1,Idx,Val>::Int(Space& home, bool share, Int& p)
-    : Propagator(home,share,p), iv(NULL) {
+    : Propagator(home,share,p), s0(0), s1(0), iv(NULL) {
     c.update(home,share,p.c);
     x0.update(home,share,p.x0);
     x1.update(home,share,p.x1);
@@ -171,38 +207,160 @@ namespace Gecode { namespace Int { namespace Element {
 
   template<class V0, class V1, class Idx, class Val>
   PropCost
-  Int<V0,V1,Idx,Val>::cost(const Space&, const ModEventDelta&) const {
-    return PropCost::binary(PropCost::HI);
+  Int<V0,V1,Idx,Val>::cost(const Space&, const ModEventDelta& med) const {
+    if ((V0::me(med) == ME_INT_VAL) ||
+        (V1::me(med) == ME_INT_VAL))
+      return PropCost::unary(PropCost::LO);
+    else
+      return PropCost::binary(PropCost::HI);
+  }
+
+  template<class V0, class V1, class Idx, class Val>
+  void
+  Int<V0,V1,Idx,Val>::prune_idx(void) {
+    Idx p = 0;
+    Idx i = iv[p].idx_next;
+    ViewRanges<V0> v(x0);
+    while (v() && (i != 0)) {
+      assert(!iv[i].marked());
+      if (iv[i].idx < v.min()) {
+        iv[i].mark(); i=iv[i].idx_next; iv[p].idx_next=i;
+      } else if (iv[i].idx > v.max()) {
+        ++v;
+      } else {
+        p=i; i=iv[i].idx_next;
+      }
+    }
+    iv[p].idx_next = 0;
+    while (i != 0) { 
+      iv[i].mark(); i=iv[i].idx_next; 
+    }
+  }
+
+  template<class V0, class V1, class Idx, class Val>
+  void
+  Int<V0,V1,Idx,Val>::prune_val(void) {
+    Idx p = 0;
+    Idx i = iv[p].val_next;
+    ViewRanges<V1> v(x1);
+    while (v() && (i != 0)) {
+      if (iv[i].marked()) {
+        i=iv[i].val_next; iv[p].val_next=i;
+      } else if (iv[i].val < v.min()) {
+        iv[i].mark(); i=iv[i].val_next; iv[p].val_next=i;
+      } else if (iv[i].val > v.max()) {
+        ++v;
+      } else {
+        p=i; i=iv[i].val_next;
+      }
+    }
+    iv[p].val_next = 0;
+    while (i != 0) { 
+      iv[i].mark(); i=iv[i].val_next; 
+    }
+  }
+
+  template<class V0, class V1, class Idx, class Val>
+  ExecStatus
+  Int<V0,V1,Idx,Val>::assigned_val(Space& home, IntSharedArray& c, 
+                                   V0 x0, V1 x1) {
+    Region r(home);
+    int* v = r.alloc<int>(x0.size());
+    int n = 0;
+    for (ViewValues<V0> i(x0); i(); ++i)
+      if (c[i.val()] != x1.val())
+        v[n++]=i.val();
+    Iter::Values::Array i(v,n);
+    GECODE_ME_CHECK(x0.minus_v(home,i,false));
+    return ES_OK;
   }
 
   template<class V0, class V1, class Idx, class Val>
   ExecStatus
   Int<V0,V1,Idx,Val>::propagate(Space& home, const ModEventDelta&) {
+    if (x0.assigned()) {
+      GECODE_ME_CHECK(x1.eq(home,c[x0.val()]));
+      return home.ES_SUBSUMED(*this);
+    }
+
+    if (x1.assigned() && (iv == NULL)) {
+      GECODE_ES_CHECK(assigned_val(home,c,x0,x1));
+      return home.ES_SUBSUMED(*this);
+    }
+
+    if ((static_cast<ValSize>(x1.size()) == s1) &&
+        (static_cast<IdxSize>(x0.size()) != s0)) {
+      assert(iv != NULL);
+      assert(!shared(x0,x1));
+
+      prune_idx();
+
+      IterValUnmark v(iv);
+      GECODE_ME_CHECK(x1.narrow_v(home,v,false));
+      
+      s1=static_cast<ValSize>(x1.size());
+      
+      assert(!x0.assigned());
+      return x1.assigned() ? home.ES_SUBSUMED(*this) : ES_FIX;
+    }
+
+    if ((static_cast<IdxSize>(x0.size()) == s0) &&
+        (static_cast<ValSize>(x1.size()) != s1)) {
+      assert(iv != NULL);
+      assert(!shared(x0,x1));
+
+      prune_val();
+
+      IterIdxUnmark i(iv);
+      GECODE_ME_CHECK(x0.narrow_v(home,i,false));
+      
+      s0=static_cast<IdxSize>(x0.size()); 
+      
+      return (x0.assigned() || x1.assigned()) ?
+          home.ES_SUBSUMED(*this) : ES_FIX;
+    }
+
     bool assigned = x0.assigned() && x1.assigned();
     if (iv == NULL) {
       // Initialize data structure
       iv = home.alloc<IdxVal>(x0.size() + 1);
-
+      
       // The first element in iv[0] is used as sentinel
       // Enter information sorted by idx
       IdxVal* by_idx = &iv[1];
-      {
-        Idx i = 0;
-        ViewValues<V0> v(x0);
-        while (v()) {
-          by_idx[i].idx = static_cast<Idx>(v.val());
-          by_idx[i].val = static_cast<Val>(c[v.val()]);
-          ++i; ++v;
+      Idx size = 0;
+      for (ViewValues<V0> v(x0); v(); ++v)
+        if ((x1.min() <= c[v.val()]) && (x1.max() >= c[v.val()])) {
+          by_idx[size].idx = static_cast<Idx>(v.val());
+          by_idx[size].val = static_cast<Val>(c[v.val()]);
+          size++;
         }
-      }
-      Idx size = static_cast<Idx>(x0.size());
+      if (size == 0)
+        return ES_FAILED;
       // Create val links sorted by val
       Region r(home);
       Idx* by_val = r.alloc<Idx>(size);
-      for (Idx i = size; i--; )
-        by_val[i] = i+1;
-      ByVal less(iv);
-      Support::quicksort<Idx>(by_val,size,less);
+      if (x1.width() <= 128) {
+        int n_buckets = static_cast<int>(x1.width());
+        int* pos = r.alloc<int>(n_buckets);
+        int* buckets = pos - x1.min(); 
+        for (int i=n_buckets; i--; )
+          pos[i]=0;
+        for (Idx i=size; i--; )
+          buckets[by_idx[i].val]++;
+        int p=0;
+        for (int i=0; i<n_buckets; i++) {
+          int n=pos[i]; pos[i]=p; p+=n;
+        }
+        assert(p == size);
+        for (Idx i=size; i--; )
+          by_val[buckets[by_idx[i].val]++] = i+1;
+      } else {
+        for (Idx i = size; i--; )
+          by_val[i] = i+1;
+        ByVal less(iv);
+        Support::quicksort<Idx>(by_val,size,less);
+      }
       // Create val links
       for (Idx i = size-1; i--; ) {
         by_idx[i].idx_next = i+2;
@@ -214,54 +372,26 @@ namespace Gecode { namespace Int { namespace Element {
       iv[0].idx_next = 1;
       iv[0].val_next = by_val[0];
     } else {
-      // Prune index
-      Idx p = 0;
-      Idx i = iv[p].idx_next;
-      ViewRanges<V0> v(x0);
-      while (v() && (i != 0)) {
-        assert(!iv[i].marked());
-        if (iv[i].idx < v.min()) {
-          iv[i].mark(); i=iv[i].idx_next; iv[p].idx_next=i;
-        } else if (iv[i].idx > v.max()) {
-          ++v;
-        } else {
-          p=i; i=iv[i].idx_next;
-        }
-      }
-      iv[p].idx_next = 0;
-      while (i != 0) { iv[i].mark(); i=iv[i].idx_next; }
+      prune_idx();
     }
-
+      
     // Prune values
-    {
-      Idx p = 0;
-      Idx i = iv[p].val_next;
-      ViewRanges<V1> v(x1);
-      while (v() && (i != 0)) {
-        if (iv[i].marked()) {
-          i=iv[i].val_next; iv[p].val_next=i;
-        } else if (iv[i].val < v.min()) {
-          iv[i].mark(); i=iv[i].val_next; iv[p].val_next=i;
-        } else if (iv[i].val > v.max()) {
-          ++v;
-        } else {
-          p=i; i=iv[i].val_next;
-        }
-      }
-      iv[p].val_next = 0;
-      while (i != 0) { iv[i].mark(); i=iv[i].val_next; }
-    }
-
+    prune_val();
+    
     // Peform tell
     {
-      IterIdx i(iv);
+      IterIdxUnmark i(iv);
       GECODE_ME_CHECK(x0.narrow_v(home,i,false));
       IterVal v(iv);
       if (shared(x0,x1)) {
         GECODE_ME_CHECK(x1.inter_v(home,v,false));
+        s0=static_cast<IdxSize>(x0.size()); 
+        s1=static_cast<ValSize>(x1.size());
         return assigned ? home.ES_SUBSUMED(*this) : ES_NOFIX;
       } else {
         GECODE_ME_CHECK(x1.narrow_v(home,v,false));
+        s0=static_cast<IdxSize>(x0.size()); 
+        s1=static_cast<ValSize>(x1.size());
         return (x0.assigned() || x1.assigned()) ?
           home.ES_SUBSUMED(*this) : ES_FIX;
       }
@@ -291,36 +421,20 @@ namespace Gecode { namespace Int { namespace Element {
         return Int<V0,V1,signed char,signed char>::post(home,c,x0,x1);
       case Support::IT_SHRT:
         return Int<V0,V1,signed char,signed short int>::post(home,c,x0,x1);
-      case Support::IT_INT:
-        return Int<V0,V1,signed char,signed int>::post(home,c,x0,x1);
-      default: GECODE_NEVER;
+      default: break;
       }
       break;
     case Support::IT_SHRT:
       switch (val_type) {
       case Support::IT_CHAR:
-        return Int<V0,V1,signed short int,signed char>::post(home,c,x0,x1);
       case Support::IT_SHRT:
         return Int<V0,V1,signed short int,signed short int>::post(home,c,x0,x1);
-      case Support::IT_INT:
-        return Int<V0,V1,signed short int,signed int>::post(home,c,x0,x1);
-      default: GECODE_NEVER;
+      default: break;
       }
       break;
-    case Support::IT_INT:
-      switch (val_type) {
-      case Support::IT_CHAR:
-        return Int<V0,V1,signed int,signed char>::post(home,c,x0,x1);
-      case Support::IT_SHRT:
-        return Int<V0,V1,signed int,signed short int>::post(home,c,x0,x1);
-      case Support::IT_INT:
-        return Int<V0,V1,signed int,signed int>::post(home,c,x0,x1);
-      default: GECODE_NEVER;
-      }
-      break;
-    default: GECODE_NEVER;
+    default: break;
     }
-    return ES_OK;
+    return Int<V0,V1,signed int,signed int>::post(home,c,x0,x1);
   }
 
 }}}
