@@ -11,8 +11,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -425,9 +425,9 @@ namespace Gecode { namespace Int { namespace Element {
     GECODE_ME_CHECK((scan<VA,VB,VC,PC_INT_BND,RelTestBnd<VA,VC> >
                      (home,iv,x0,x1,*this,rt)));
     if (iv.size() == 1) {
-      size_t s = this->dispose(home);
+      ExecStatus es = home.ES_SUBSUMED(*this);
       (void) new (home) Rel::EqBnd<VA,VC>(home,iv[0].view,x1);
-      return ES_SUBSUMED(*this,s);
+      return es;
     }
     assert(iv.size() > 1);
     // Compute new result
@@ -453,7 +453,7 @@ namespace Gecode { namespace Int { namespace Element {
        es = ES_NOFIX;
     }
     return (x1.assigned() && (min == max)) ?
-      ES_SUBSUMED(*this,home) : es;
+      home.ES_SUBSUMED(*this) : es;
   }
 
 
@@ -516,9 +516,9 @@ namespace Gecode { namespace Int { namespace Element {
       GECODE_ME_CHECK((scan<VA,VB,VC,PC_INT_DOM,RelTestBnd<VA,VC> >
                        (home,iv,x0,x1,*this,rt)));
       if (iv.size() == 1) {
-        size_t s = this->dispose(home);
+        ExecStatus es = home.ES_SUBSUMED(*this);
         (void) new (home) Rel::EqDom<VA,VC>(home,iv[0].view,x1);
-        return ES_SUBSUMED(*this,s);
+        return es;
       }
       // Compute new result
       int min = iv[iv.size()-1].view.min();
@@ -530,16 +530,16 @@ namespace Gecode { namespace Int { namespace Element {
       GECODE_ME_CHECK(x1.lq(home,max));
       GECODE_ME_CHECK(x1.gq(home,min));
       return (x1.assigned() && (min == max)) ?
-        ES_SUBSUMED(*this,home) :
-        ES_NOFIX_PARTIAL(*this,VA::med(ME_INT_DOM));
+        home.ES_SUBSUMED(*this) :
+        home.ES_NOFIX_PARTIAL(*this,VA::med(ME_INT_DOM));
     }
     RelTestDom<VA,VC> rt;
     GECODE_ME_CHECK((scan<VA,VB,VC,PC_INT_DOM,RelTestDom<VA,VC> >
                      (home,iv,x0,x1,*this,rt)));
     if (iv.size() == 1) {
-      size_t s = this->dispose(home);
+      ExecStatus es = home.ES_SUBSUMED(*this);
       (void) new (home) Rel::EqDom<VA,VC>(home,iv[0].view,x1);
-      return ES_SUBSUMED(*this,s);
+      return es;
     }
     assert(iv.size() > 1);
     Region r(home);
