@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -48,7 +48,7 @@ namespace Gecode {
     if (x.same(home))
       throw ArgumentSame("Int::extensional");
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Extensional::post_lgp(home,x,dfa));
+    GECODE_ES_FAIL(Extensional::post_lgp(home,x,dfa));
   }
 
   void
@@ -58,7 +58,7 @@ namespace Gecode {
     if (x.same(home))
       throw ArgumentSame("Int::extensional");
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Extensional::post_lgp(home,x,dfa));
+    GECODE_ES_FAIL(Extensional::post_lgp(home,x,dfa));
   }
 
   void
@@ -75,15 +75,15 @@ namespace Gecode {
     ViewArray<IntView> xv(home,x);
     switch (epk) {
     case EPK_SPEED:
-      GECODE_ES_FAIL(home,(Extensional::Incremental<IntView>
+      GECODE_ES_FAIL((Extensional::Incremental<IntView>
                            ::post(home,xv,t)));
       break;
     default:
       if (x.same(home)) {
-        GECODE_ES_FAIL(home,(Extensional::Basic<IntView,true>
+        GECODE_ES_FAIL((Extensional::Basic<IntView,true>
                              ::post(home,xv,t)));
       } else {
-        GECODE_ES_FAIL(home,(Extensional::Basic<IntView,false>
+        GECODE_ES_FAIL((Extensional::Basic<IntView,false>
                              ::post(home,xv,t)));
       }
       break;
@@ -104,15 +104,15 @@ namespace Gecode {
     ViewArray<BoolView> xv(home,x);
     switch (epk) {
     case EPK_SPEED:
-      GECODE_ES_FAIL(home,(Extensional::Incremental<BoolView>
+      GECODE_ES_FAIL((Extensional::Incremental<BoolView>
                            ::post(home,xv,t)));
       break;
     default:
       if (x.same(home)) {
-        GECODE_ES_FAIL(home,(Extensional::Basic<BoolView,true>
+        GECODE_ES_FAIL((Extensional::Basic<BoolView,true>
                              ::post(home,xv,t)));
       } else {
-        GECODE_ES_FAIL(home,(Extensional::Basic<BoolView,false>
+        GECODE_ES_FAIL((Extensional::Basic<BoolView,false>
                              ::post(home,xv,t)));
       }
       break;
