@@ -13,8 +13,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -63,15 +63,15 @@ namespace Gecode {
       cv[i].init(c[i],v[i]);
     switch (icl) {
     case ICL_BND:
-      GECODE_ES_FAIL(home, 
+      GECODE_ES_FAIL( 
                      (GCC::Bnd<GCC::CardView>::post(home,xv,cv)));
       break;
     case ICL_DOM:
-      GECODE_ES_FAIL(home, 
+      GECODE_ES_FAIL( 
                      (GCC::Dom<GCC::CardView>::post(home,xv,cv)));
       break;
     default:
-      GECODE_ES_FAIL(home, 
+      GECODE_ES_FAIL( 
                      (GCC::Val<GCC::CardView>::post(home,xv,cv)));
     }
   }
@@ -113,15 +113,15 @@ namespace Gecode {
           cv[j].init(home,c[j],v[j]);
         switch (icl) {
         case ICL_BND:
-          GECODE_ES_FAIL(home, 
+          GECODE_ES_FAIL( 
                          (GCC::Bnd<GCC::CardView>::post(home, xv, cv)));
           break;
         case ICL_DOM:
-          GECODE_ES_FAIL(home, 
+          GECODE_ES_FAIL( 
                          (GCC::Dom<GCC::CardView>::post(home, xv, cv)));
           break;
         default:
-          GECODE_ES_FAIL(home, 
+          GECODE_ES_FAIL( 
                          (GCC::Val<GCC::CardView>::post(home, xv, cv)));
         }
         return;
@@ -136,15 +136,15 @@ namespace Gecode {
 
     switch (icl) {
     case ICL_BND:
-      GECODE_ES_FAIL(home,
+      GECODE_ES_FAIL(
                      (GCC::Bnd<GCC::CardConst>::post(home, xv, cv)));
       break;
     case ICL_DOM:
-      GECODE_ES_FAIL(home,
+      GECODE_ES_FAIL(
                      (GCC::Dom<GCC::CardConst>::post(home, xv, cv)));
       break;
     default:
-      GECODE_ES_FAIL(home,
+      GECODE_ES_FAIL(
                      (GCC::Val<GCC::CardConst>::post(home, xv, cv)));
     }
   }
