@@ -13,8 +13,8 @@
  *     Guido Tack, 2009
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -66,7 +66,7 @@ namespace Gecode { namespace Int { namespace GCC {
   }
 
   template<class Card>
-  size_t
+  forceinline size_t
   Bnd<Card>::dispose(Space& home) {
     y.cancel(home,*this, PC_INT_BND);
     k.cancel(home,*this, PC_INT_BND);
@@ -590,11 +590,10 @@ namespace Gecode { namespace Int { namespace GCC {
 
   template<class Card>
   ExecStatus
-  Bnd<Card>::propagate(Space& home,
-                                 const ModEventDelta& med) {
+  Bnd<Card>::propagate(Space& home, const ModEventDelta& med) {
     if (IntView::me(med) == ME_INT_VAL) {
       GECODE_ES_CHECK(prop_val<Card>(home,*this,y,k));
-      return ES_NOFIX_PARTIAL(*this,IntView::med(ME_INT_BND));
+      return home.ES_NOFIX_PARTIAL(*this,IntView::med(ME_INT_BND));
     }
 
     if (Card::propagate)
@@ -664,7 +663,7 @@ namespace Gecode { namespace Int { namespace GCC {
     if (all_assigned) {
       for (int i = k.size(); i--; )
         GECODE_ME_CHECK(k[i].eq(home, count[i]));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     if (Card::propagate)
@@ -797,7 +796,7 @@ namespace Gecode { namespace Int { namespace GCC {
     for (int i = k.size(); i--; )
       GECODE_ME_CHECK(k[i].eq(home, count[i]));
 
-    return ES_SUBSUMED(*this,home);
+    return home.ES_SUBSUMED(*this);
   }
 
 
