@@ -13,8 +13,8 @@
  *     Guido Tack, 2009
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-05-11 10:57:01 +0200 (Tue, 11 May 2010) $ by $Author: tack $
+ *     $Revision: 10935 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -215,11 +215,7 @@ namespace Gecode { namespace Int { namespace GCC {
       bool card_assigned = true;
       if (Card::propagate) {
         GECODE_ES_CHECK(prop_card<Card>(home, y, k));
-        
-        for (int i = k.size(); i--; )
-          if (!k[i].assigned()) {
-            card_assigned = false; break;
-          }
+        card_assigned = k.assigned();
       }
       
       if (card_assigned) {
