@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2009-12-02 20:42:32 +0100 (Wed, 02 Dec 2009) $ by $Author: schulte $
+ *     $Revision: 10174 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -119,6 +119,15 @@ namespace Gecode {
     return (o == NULL) ? 0 : o->n;
   }
 
+  forceinline bool
+  IntSet::in(int n) const {
+    IntSetObject* o = static_cast<IntSetObject*>(object());
+    if ((o == NULL) || (n < o->r[0].min) || (n > o->r[o->n-1].max))
+      return false;
+    else
+      return o->in(n);
+  }
+
   forceinline int
   IntSet::min(void) const {
     IntSetObject* o = static_cast<IntSetObject*>(object());
