@@ -9,8 +9,8 @@
  *     Tias Guns, 2009
  *
  *  Last modified:
- *     $Date: 2009-10-20 11:15:31 +0200 (Tue, 20 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9973 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -102,7 +102,6 @@ namespace Gecode { namespace Int { namespace Linear {
   template<class VX>
   forceinline size_t
   LinBoolInt<VX>::dispose(Space& home) {
-    assert(!home.failed());
     Advisors<Advisor> as(co);
     for (int i=n_hs; i--; )
       x[i].cancel(home,as.advisor());
@@ -183,13 +182,8 @@ namespace Gecode { namespace Int { namespace Linear {
       for (int i=n_hs; i--; )
         if (x[i].none())
           GECODE_ME_CHECK(x[i].one_none(home));
-    } else {
-      Advisors<Advisor> as(co);
-      for (int i=n_hs; i--; )
-        x[i].cancel(home,as.advisor());
     }
-    co.dispose(home);
-    return ES_SUBSUMED(*this,sizeof(*this));
+    return home.ES_SUBSUMED(*this);
   }
 
   template<class VX>
@@ -300,8 +294,7 @@ namespace Gecode { namespace Int { namespace Linear {
         if (x[i].none())
           GECODE_ME_CHECK(x[i].one_none(home));
     }
-    co.dispose(home);
-    return ES_SUBSUMED(*this,sizeof(*this));
+    return home.ES_SUBSUMED(*this);
   }
 
   template<class VX>
@@ -352,7 +345,7 @@ namespace Gecode { namespace Int { namespace Linear {
   }
 
   template<class VX>
-  size_t
+  forceinline size_t
   NqBoolInt<VX>::dispose(Space& home) {
     (void) BinaryPropagator<VX,PC_INT_VAL>::dispose(home);
     return sizeof(*this);
@@ -452,9 +445,9 @@ namespace Gecode { namespace Int { namespace Linear {
       s1 = resubscribe(home,x1);
     int n = x.size() + s0 + s1;
     if ((n < c) || (c < 0))
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     if (n == 0)
-      return (c == 0) ? ES_FAILED : ES_SUBSUMED(*this,sizeof(*this));
+      return (c == 0) ? ES_FAILED : home.ES_SUBSUMED(*this);
     if (n == 1) {
       if (s0) {
         if (c == 1) {
@@ -470,7 +463,7 @@ namespace Gecode { namespace Int { namespace Linear {
           GECODE_ME_CHECK(x1.one_none(home));
         }
       }
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
@@ -515,7 +508,6 @@ namespace Gecode { namespace Int { namespace Linear {
   template<class VX, class VB>
   forceinline size_t
   ReLinBoolInt<VX,VB>::dispose(Space& home) {
-    assert(!home.failed());
     Advisors<Advisor> as(co);
     x.cancel(home,as.advisor());
     co.dispose(home);
@@ -531,10 +523,8 @@ namespace Gecode { namespace Int { namespace Linear {
   }
 
 
-  /*
-   * Traits for Boolean view negation
-   */
   template<>
+  /// Traits for Boolean negation view
   class BoolNegTraits<BoolView> {
   public:
     /// The negated view
@@ -546,6 +536,7 @@ namespace Gecode { namespace Int { namespace Linear {
   };
 
   template<>
+  /// Traits for Boolean negation view
   class BoolNegTraits<NegBoolView> {
   public:
     /// The negated view
@@ -611,7 +602,7 @@ namespace Gecode { namespace Int { namespace Linear {
                        ::post(home(*this),nx,x.size()-c+1));
       }
     }
-    return ES_SUBSUMED(*this,home);
+    return home.ES_SUBSUMED(*this);
   }
 
   template<class VX, class VB>
@@ -703,7 +694,7 @@ namespace Gecode { namespace Int { namespace Linear {
         GECODE_REWRITE(*this,(NqBoolInt<VX>::post(home(*this),x,c)));
       }
     }
-    return ES_SUBSUMED(*this,home);
+    return home.ES_SUBSUMED(*this);
   }
 
   template<class VX, class VB>
