@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -75,7 +75,6 @@ namespace Gecode { namespace Int { namespace Linear {
   template<class Val, class A, class B, PropCond pc>
   forceinline size_t
   LinBin<Val,A,B,pc>::dispose(Space& home) {
-    assert(!home.failed());
     x0.cancel(home,*this,pc);
     x1.cancel(home,*this,pc);
     (void) Propagator::dispose(home);
@@ -115,7 +114,6 @@ namespace Gecode { namespace Int { namespace Linear {
   template<class Val, class A, class B, PropCond pc, class Ctrl>
   forceinline size_t
   ReLinBin<Val,A,B,pc,Ctrl>::dispose(Space& home) {
-    assert(!home.failed());
     x0.cancel(home,*this,pc);
     x1.cancel(home,*this,pc);
     b.cancel(home,*this,PC_BOOL_VAL);
@@ -184,7 +182,7 @@ namespace Gecode { namespace Int { namespace Linear {
       GECODE_INT_PV(BM_X0_MAX, x0.lq(home,c-x1.min()), BM_X1_MIN);
       GECODE_INT_PV(BM_X1_MAX, x1.lq(home,c-x0.min()), BM_X0_MIN);
     } while (bm);
-    return x0.assigned() ? ES_SUBSUMED(*this,sizeof(*this)) : ES_FIX;
+    return x0.assigned() ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 #undef GECODE_INT_PV
@@ -231,11 +229,11 @@ namespace Gecode { namespace Int { namespace Linear {
     if (b.one())
       GECODE_REWRITE(*this,(EqBin<Val,A,B>::post(home(*this),x0,x1,c)));
     if ((x0.min() + x1.min() > c) || (x0.max() + x1.max() < c)) {
-      GECODE_ME_CHECK(b.zero_none(home)); return ES_SUBSUMED(*this,home);
+      GECODE_ME_CHECK(b.zero_none(home)); return home.ES_SUBSUMED(*this);
     }
     if (x0.assigned() && x1.assigned()) {
       assert(x0.val() + x1.val() == c);
-      GECODE_ME_CHECK(b.one_none(home)); return ES_SUBSUMED(*this,home);
+      GECODE_ME_CHECK(b.one_none(home)); return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
@@ -294,7 +292,7 @@ namespace Gecode { namespace Int { namespace Linear {
       assert(x1.assigned());
       GECODE_ME_CHECK(x0.nq(home,c-x1.val()));
     }
-    return ES_SUBSUMED(*this,home);
+    return home.ES_SUBSUMED(*this);
   }
 
 
@@ -338,7 +336,7 @@ namespace Gecode { namespace Int { namespace Linear {
   LqBin<Val,A,B>::propagate(Space& home, const ModEventDelta&) {
     GECODE_ME_CHECK(x0.lq(home,c-x1.min()));
     GECODE_ME_CHECK(x1.lq(home,c-x0.min()));
-    return (x0.max()+x1.max() <= c) ? ES_SUBSUMED(*this,home) : ES_FIX;
+    return (x0.max()+x1.max() <= c) ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 
@@ -384,7 +382,7 @@ namespace Gecode { namespace Int { namespace Linear {
   GqBin<Val,A,B>::propagate(Space& home, const ModEventDelta&) {
     GECODE_ME_CHECK(x0.gq(home,c-x1.max()));
     GECODE_ME_CHECK(x1.gq(home,c-x0.max()));
-    return (x0.min()+x1.min() >= c) ? ES_SUBSUMED(*this,home) : ES_FIX;
+    return (x0.min()+x1.min() >= c) ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 
@@ -427,10 +425,10 @@ namespace Gecode { namespace Int { namespace Linear {
     if (b.zero())
       GECODE_REWRITE(*this,(GqBin<Val,A,B>::post(home(*this),x0,x1,c+1)));
     if (x0.max() + x1.max() <= c) {
-      GECODE_ME_CHECK(b.one_none(home)); return ES_SUBSUMED(*this,home);
+      GECODE_ME_CHECK(b.one_none(home)); return home.ES_SUBSUMED(*this);
     }
     if (x0.min() + x1.min() > c) {
-      GECODE_ME_CHECK(b.zero_none(home)); return ES_SUBSUMED(*this,home);
+      GECODE_ME_CHECK(b.zero_none(home)); return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
