@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-11-04 17:06:58 +0100 (Wed, 04 Nov 2009) $ by $Author: tack $
- *     $Revision: 10046 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -85,7 +85,6 @@ namespace Gecode { namespace Int { namespace Linear {
   template<class Val, class P, class N, PropCond pc>
   forceinline size_t
   Lin<Val,P,N,pc>::dispose(Space& home) {
-    assert(!home.failed());
     x.cancel(home,*this,pc);
     y.cancel(home,*this,pc);
     (void) Propagator::dispose(home);
@@ -115,7 +114,6 @@ namespace Gecode { namespace Int { namespace Linear {
   template<class Val, class P, class N, PropCond pc, class Ctrl>
   forceinline size_t
   ReLin<Val,P,N,pc,Ctrl>::dispose(Space& home) {
-    assert(!home.failed());
     b.cancel(home,*this,PC_BOOL_VAL);
     (void) Lin<Val,P,N,pc>::dispose(home);
     return sizeof(*this);
@@ -183,14 +181,14 @@ namespace Gecode { namespace Int { namespace Linear {
     if ((IntView::me(med) == ME_INT_VAL) && ((x.size() + y.size()) <= 1)) {
       if (x.size() == 1) {
         GECODE_ME_CHECK(x[0].eq(home,c));
-        return ES_SUBSUMED(p,sizeof(p));
+        return home.ES_SUBSUMED(p);
       }
       if (y.size() == 1) {
         GECODE_ME_CHECK(y[0].eq(home,-c));
-        return ES_SUBSUMED(p,sizeof(p));
+        return home.ES_SUBSUMED(p);
       }
       return (c == static_cast<Val>(0)) ?
-        ES_SUBSUMED(p,sizeof(p)) : ES_FAILED;
+        home.ES_SUBSUMED(p) : ES_FAILED;
     }
 
     sl += c; su += c;
@@ -253,7 +251,7 @@ namespace Gecode { namespace Int { namespace Linear {
       }
     } while (mod);
 
-    return (sl == su) ? ES_SUBSUMED(p,sizeof(p)) : ES_FIX;
+    return (sl == su) ? home.ES_SUBSUMED(p) : ES_FIX;
   }
 
   /*
@@ -440,11 +438,11 @@ namespace Gecode { namespace Int { namespace Linear {
 
     if ((-sl == c) && (-su == c)) {
       GECODE_ME_CHECK(b.one_none(home));
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     }
     if ((-sl > c) || (-su < c)) {
       GECODE_ME_CHECK(b.zero_none(home));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
@@ -587,13 +585,13 @@ namespace Gecode { namespace Int { namespace Linear {
       }
     if (x.size() + y.size() <= 1) {
       if (x.size() == 1) {
-        GECODE_ME_CHECK(x[0].nq(home,c)); return ES_SUBSUMED(*this,home);
+        GECODE_ME_CHECK(x[0].nq(home,c)); return home.ES_SUBSUMED(*this);
       }
       if (y.size() == 1) {
-        GECODE_ME_CHECK(y[0].nq(home,-c)); return ES_SUBSUMED(*this,home);
+        GECODE_ME_CHECK(y[0].nq(home,-c)); return home.ES_SUBSUMED(*this);
       }
       return (c == static_cast<Val>(0)) ?
-        ES_FAILED : ES_SUBSUMED(*this,sizeof(*this));
+        ES_FAILED : home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
@@ -749,14 +747,14 @@ namespace Gecode { namespace Int { namespace Linear {
       if ((x.size() + y.size()) <= 1) {
         if (x.size() == 1) {
           GECODE_ME_CHECK(x[0].lq(home,c));
-          return ES_SUBSUMED(*this,home);
+          return home.ES_SUBSUMED(*this);
         }
         if (y.size() == 1) {
           GECODE_ME_CHECK(y[0].gq(home,-c));
-          return ES_SUBSUMED(*this,home);
+          return home.ES_SUBSUMED(*this);
         }
         return (c >= static_cast<Val>(0)) ?
-          ES_SUBSUMED(*this,sizeof(*this)) : ES_FAILED;
+          home.ES_SUBSUMED(*this) : ES_FAILED;
       }
     } else {
       for (int i = x.size(); i--; )
@@ -792,7 +790,7 @@ namespace Gecode { namespace Int { namespace Linear {
       if (me_modified(me) && (sly != y[i].min()))
         es = ES_NOFIX;
     }
-    return assigned ? ES_SUBSUMED(*this,sizeof(*this)) : es;
+    return assigned ? home.ES_SUBSUMED(*this) : es;
   }
 
   /*
@@ -850,11 +848,11 @@ namespace Gecode { namespace Int { namespace Linear {
 
     if (-sl > c) {
       GECODE_ME_CHECK(b.zero_none(home));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     if (-su <= c) {
       GECODE_ME_CHECK(b.one_none(home));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     return ES_FIX;
