@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-03-14 22:08:40 +0100 (Sun, 14 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10426 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -35,7 +35,7 @@
  *
  */
 
-namespace Gecode {
+namespace Gecode { namespace Int {
 
   /**
    * \defgroup TaskPropRePat Reified propagator patterns
@@ -305,7 +305,7 @@ namespace Gecode {
     return sizeof(*this);
   }
 
-}
+}}
 
 // STATISTICS: int-prop
 
