@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-11-04 17:06:05 +0100 (Wed, 04 Nov 2009) $ by $Author: tack $
- *     $Revision: 10045 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -102,7 +102,7 @@ namespace Gecode { namespace Int { namespace Rel {
         return ES_FIX;
     }
     assert(x0.assigned() && x1.assigned());
-    return ES_SUBSUMED(*this,sizeof(*this));
+    return home.ES_SUBSUMED(*this);
   }
 
   /*
@@ -167,11 +167,11 @@ namespace Gecode { namespace Int { namespace Rel {
   EqDom<View0,View1>::propagate(Space& home, const ModEventDelta& med) {
     if (x0.assigned()) {
       GECODE_ME_CHECK(x1.eq(home,x0.val()));
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     }
     if (x1.assigned()) {
       GECODE_ME_CHECK(x0.eq(home,x1.val()));
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     }
     if ((View0::me(med) != ME_INT_DOM) && (View1::me(med) != ME_INT_DOM)) {
       do {
@@ -183,17 +183,17 @@ namespace Gecode { namespace Int { namespace Rel {
         GECODE_ME_CHECK(x1.lq(home,x0.max()));
       } while (x0.max() != x1.max());
       if (x0.assigned())
-        return ES_SUBSUMED(*this,sizeof(*this));
+        return home.ES_SUBSUMED(*this);
       if (x0.range() && x1.range())
         return ES_FIX;
-      return ES_FIX_PARTIAL(*this,View0::med(ME_INT_DOM));
+      return home.ES_FIX_PARTIAL(*this,View0::med(ME_INT_DOM));
     }
     ViewRanges<View0> r0(x0);
     GECODE_ME_CHECK(x1.inter_r(home,r0,shared(x0,x1)));
     ViewRanges<View1> r1(x1);
     GECODE_ME_CHECK(x0.narrow_r(home,r1,shared(x0,x1)));
     if (x0.assigned())
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     return ES_FIX;
   }
 
@@ -266,10 +266,9 @@ namespace Gecode { namespace Int { namespace Rel {
           x.move_lst(i);
           for (int j = x.size(); j--; )
             GECODE_ME_CHECK(x[j].eq(home,n));
-          return ES_SUBSUMED(*this,sizeof(*this));
+          return home.ES_SUBSUMED(*this);
         }
       GECODE_NEVER;
-      return ES_SUBSUMED(*this,sizeof(*this));
     }
 
     if (me == ME_INT_BND) {
@@ -298,8 +297,8 @@ namespace Gecode { namespace Int { namespace Rel {
         }
       }
       if (x[0].assigned())
-        return ES_SUBSUMED(*this,sizeof(*this));
-      return ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM));
+        return home.ES_SUBSUMED(*this);
+      return home.ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM));
     }
 
     int n = x.size();
@@ -396,10 +395,9 @@ namespace Gecode { namespace Int { namespace Rel {
           x.move_lst(i);
           for (int j = x.size(); j--; )
             GECODE_ME_CHECK(x[j].eq(home,n));
-          return ES_SUBSUMED(*this,sizeof(*this));
+          return home.ES_SUBSUMED(*this);
         }
       GECODE_NEVER;
-      return ES_SUBSUMED(*this,sizeof(*this));
     }
 
     int mn = x[0].min();
@@ -420,7 +418,7 @@ namespace Gecode { namespace Int { namespace Rel {
         goto restart_max;
       }
     }
-    return x[0].assigned() ? ES_SUBSUMED(*this,sizeof(*this)) : ES_FIX;
+    return x[0].assigned() ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 
@@ -471,9 +469,9 @@ namespace Gecode { namespace Int { namespace Rel {
       GECODE_REWRITE(*this,Nq<View>::post(home(*this),x0,x1));
     switch (rtest_eq_dom(x0,x1)) {
     case RT_TRUE:
-      GECODE_ME_CHECK(b.one_none(home)); return ES_SUBSUMED(*this,home);
+      GECODE_ME_CHECK(b.one_none(home)); return home.ES_SUBSUMED(*this);
     case RT_FALSE:
-      GECODE_ME_CHECK(b.zero_none(home)); return ES_SUBSUMED(*this,home);
+      GECODE_ME_CHECK(b.zero_none(home)); return home.ES_SUBSUMED(*this);
     case RT_MAYBE:
       break;
     default: GECODE_NEVER;
@@ -529,9 +527,9 @@ namespace Gecode { namespace Int { namespace Rel {
       GECODE_REWRITE(*this,Nq<View>::post(home(*this),x0,x1));
     switch (rtest_eq_bnd(x0,x1)) {
     case RT_TRUE:
-      GECODE_ME_CHECK(b.one_none(home));  return ES_SUBSUMED(*this,home);
+      GECODE_ME_CHECK(b.one_none(home));  return home.ES_SUBSUMED(*this);
     case RT_FALSE:
-      GECODE_ME_CHECK(b.zero_none(home)); return ES_SUBSUMED(*this,home);
+      GECODE_ME_CHECK(b.zero_none(home)); return home.ES_SUBSUMED(*this);
     case RT_MAYBE:
       break;
     default: GECODE_NEVER;
@@ -590,30 +588,20 @@ namespace Gecode { namespace Int { namespace Rel {
   ReEqDomInt<View,CtrlView>::propagate(Space& home, const ModEventDelta&) {
     if (b.one()) {
       GECODE_ME_CHECK(x0.eq(home,c));
-      assert(x0.assigned());
-      goto subsumed;
-    }
-    if (b.zero()) {
+    } else if (b.zero()) {
       GECODE_ME_CHECK(x0.nq(home,c));
-      x0.cancel(home,*this,PC_INT_DOM);
-      goto subsumed;
+    } else {
+      switch (rtest_eq_dom(x0,c)) {
+      case RT_TRUE:
+        GECODE_ME_CHECK(b.one_none(home)); break;
+      case RT_FALSE:
+        GECODE_ME_CHECK(b.zero_none(home)); break;
+      case RT_MAYBE:
+        return ES_FIX;
+      default: GECODE_NEVER;
+      }
     }
-    switch (rtest_eq_dom(x0,c)) {
-    case RT_TRUE:
-      GECODE_ME_CHECK(b.one_none(home));
-      assert(x0.assigned());
-      goto subsumed;
-    case RT_FALSE:
-      GECODE_ME_CHECK(b.zero_none(home));
-      x0.cancel(home,*this,PC_INT_DOM);
-      goto subsumed;
-    case RT_MAYBE:
-      break;
-    default: GECODE_NEVER;
-    }
-    return ES_FIX;
-  subsumed:
-    return ES_SUBSUMED(*this,sizeof(*this));
+    return home.ES_SUBSUMED(*this);
   }
 
 
@@ -667,30 +655,20 @@ namespace Gecode { namespace Int { namespace Rel {
   ReEqBndInt<View,CtrlView>::propagate(Space& home, const ModEventDelta&) {
     if (b.one()) {
       GECODE_ME_CHECK(x0.eq(home,c));
-      assert(x0.assigned());
-      goto subsumed;
-    }
-    if (b.zero()) {
+    } else if (b.zero()) {
       GECODE_ME_CHECK(x0.nq(home,c));
-      x0.cancel(home,*this,PC_INT_BND);
-      goto subsumed;
+    } else {
+      switch (rtest_eq_bnd(x0,c)) {
+      case RT_TRUE:
+        GECODE_ME_CHECK(b.one_none(home)); break;
+      case RT_FALSE:
+        GECODE_ME_CHECK(b.zero_none(home)); break;
+      case RT_MAYBE:
+        return ES_FIX;
+      default: GECODE_NEVER;
+      }
     }
-    switch (rtest_eq_bnd(x0,c)) {
-    case RT_TRUE:
-      GECODE_ME_CHECK(b.one_none(home));
-      assert(x0.assigned());
-      goto subsumed;
-    case RT_FALSE:
-      GECODE_ME_CHECK(b.zero_none(home));
-      x0.cancel(home,*this,PC_INT_BND);
-      goto subsumed;
-    case RT_MAYBE:
-      break;
-    default: GECODE_NEVER;
-    }
-    return ES_FIX;
-  subsumed:
-    return ES_SUBSUMED(*this,sizeof(*this));
+    return home.ES_SUBSUMED(*this);
   }
 
 }}}
