@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -66,6 +66,16 @@ namespace Gecode { namespace Int { namespace Rel {
     return PropCost::linear(PropCost::LO, x.size());
   }
 
+  template<class View>
+  forceinline size_t
+  Lex<View>::dispose(Space& home) {
+    assert(!home.failed());
+    x.cancel(home,*this,PC_INT_BND);
+    y.cancel(home,*this,PC_INT_BND);
+    (void) Propagator::dispose(home);
+    return sizeof(*this);
+  }
+
   template<class View>
   ExecStatus
   Lex<View>::propagate(Space& home, const ModEventDelta&) {
@@ -85,14 +95,14 @@ namespace Gecode { namespace Int { namespace Rel {
       }
 
       if (i == n) // case: $
-        return strict ? ES_FAILED : ES_SUBSUMED(*this,sizeof(*this));
+        return strict ? ES_FAILED : home.ES_SUBSUMED(*this);
 
       // Possible cases left: <, <=, > (yields failure), ?
       GECODE_ME_CHECK(x[i].lq(home,y[i].max()));
       GECODE_ME_CHECK(y[i].gq(home,x[i].min()));
 
       if (x[i].max() < y[i].min()) // case: < (after tell)
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
 
       // x[i] can never be equal to y[i] (otherwise: >=)
       assert(!(x[i].assigned() && y[i].assigned() &&
@@ -236,16 +246,6 @@ namespace Gecode { namespace Int { namespace Rel {
     return ES_OK;
   }
 
-  template<class View>
-  size_t
-  Lex<View>::dispose(Space& home) {
-    assert(!home.failed());
-    x.cancel(home,*this,PC_INT_BND);
-    y.cancel(home,*this,PC_INT_BND);
-    (void) Propagator::dispose(home);
-    return sizeof(*this);
-  }
-
 }}}
 
 // STATISTICS: int-prop
