@@ -7,8 +7,8 @@
  *     Patrick Pekczynski, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -218,7 +218,7 @@ namespace Gecode { namespace Int { namespace Sorted {
       return ES_FAILED;
 
     if (subsumed || array_subs)
-      return ES_SUBSUMED(p,home);
+      return home.ES_SUBSUMED(p);
 
     /*
      * STEP 2: creating tau
@@ -370,9 +370,8 @@ namespace Gecode { namespace Int { namespace Sorted {
   }
 
   template<class View, bool Perm>
-  size_t
+  forceinline size_t
   Sorted<View,Perm>::dispose(Space& home) {
-    assert(!home.failed());
     x.cancel(home,*this, PC_INT_BND);
     y.cancel(home,*this, PC_INT_BND);
     if (Perm)
@@ -416,7 +415,7 @@ namespace Gecode { namespace Int { namespace Sorted {
       return ES_FAILED;
 
     if (array_subs)
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
 
     sort_sigma<View,Perm>(home,x,z);
 
@@ -427,7 +426,7 @@ namespace Gecode { namespace Int { namespace Sorted {
       return ES_FAILED;
 
     if (subsumed)
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
 
     if (Perm) {
       // dropping possibly yields inconsistent indices on permutation variables
@@ -617,13 +616,13 @@ namespace Gecode { namespace Int { namespace Sorted {
       return ES_FAILED;
 
     if (array_subs)
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
 
     if (!check_subsumption<View,Perm>(x,y,z,subsumed,dropfst))
       return ES_FAILED;
 
     if (subsumed)
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
 
     return nofix ? ES_NOFIX : ES_FIX;
   }
