@@ -11,8 +11,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-06-02 21:01:00 +0200 (Wed, 02 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11008 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -337,12 +337,12 @@ namespace Gecode { namespace Int {
     /**
      * \brief Subscribe propagator \a p with propagation condition \a pc to variable
      *
-     * In case \a process is false, the propagator is just subscribed but
-     * not processed for execution (this must be used when creating
+     * In case \a schedule is false, the propagator is just subscribed but
+     * not scheduled for execution (this must be used when creating
      * subscriptions during propagation).
      *
      */
-    void subscribe(Space& home, Propagator& p, PropCond pc, bool process=true);
+    void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
     /// Cancel subscription of propagator \a p with propagation condition \a pc
     void cancel(Space& home, Propagator& p, PropCond pc);
     /// Subscribe advisor \a a to variable
@@ -370,8 +370,6 @@ namespace Gecode { namespace Int {
 
     /// \name Delta information for advisors
     //@{
-    /// Return modification event
-    static ModEvent modevent(const Delta& d);
     /// Return minimum value just pruned
     static int min(const Delta& d);
     /// Return maximum value just pruned
@@ -472,14 +470,6 @@ namespace Gecode { namespace Int {
 namespace Gecode {
 
   class IntVar;
-
-  /** \brief Traits class for variable implementations and variables */
-  template<>
-  class VarImpVarTraits<Int::IntVarImp> {
-  public:
-    typedef IntVar Var;
-  };
-
   class BoolVar;
 }
 
@@ -653,14 +643,14 @@ namespace Gecode { namespace Int {
     /**
      * \brief Subscribe propagator \a p to variable with propagation condition \a pc
      *
-     * In case \a process is false, the propagator is just subscribed but
-     * not processed for execution (this must be used when creating
+     * In case \a schedule is false, the propagator is just subscribed but
+     * not scheduled for execution (this must be used when creating
      * subscriptions during propagation).
      *
      * The propagation condition \a pc can be a propagation condition
      * for integer variables, which will be mapped to PC_BOOL_VAL.
      */
-    void subscribe(Space& home, Propagator& p, PropCond pc, bool process=true);
+    void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
     /**
      * \brief Cancel subscription of propagator \a p with propagation condition \a pc
      *
@@ -716,14 +706,5 @@ namespace Gecode { namespace Int {
 
 #include <gecode/int/var-imp/bool.hpp>
 
-namespace Gecode {
-  /** \brief Traits class for variable implementations and variables */
-  template<>
-  class VarImpVarTraits<Int::BoolVarImp> {
-  public:
-    typedef BoolVar Var;
-  };
-}
-
 // STATISTICS: int-var
 
