@@ -7,8 +7,8 @@
  *     Christian Schulte, 2006
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-05-29 12:02:54 +0200 (Sat, 29 May 2010) $ by $Author: schulte $
+ *     $Revision: 10988 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -402,10 +402,10 @@ namespace Gecode { namespace Int {
    */
   forceinline void
   BoolVarImp::subscribe(Space& home, Propagator& p, PropCond,
-                        bool process) {
+                        bool schedule) {
     // Subscription can be used with integer propagation conditions,
     // which must be remapped to the single Boolean propagation condition.
-    BoolVarImpBase::subscribe(home,p,PC_BOOL_VAL,assigned(),process);
+    BoolVarImpBase::subscribe(home,p,PC_BOOL_VAL,assigned(),schedule);
   }
   forceinline void
   BoolVarImp::cancel(Space& home, Propagator& p, PropCond) {
