@@ -11,8 +11,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-06-02 14:54:28 +0200 (Wed, 02 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11005 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -321,10 +321,6 @@ namespace Gecode { namespace Int {
    * Support for delta information
    *
    */
-  forceinline ModEvent
-  IntVarImp::modevent(const Delta& d) {
-    return d.modevent();
-  }
   forceinline int
   IntVarImp::min(const Delta& d) {
     return static_cast<const IntDelta&>(d).min();
@@ -1012,8 +1008,8 @@ namespace Gecode { namespace Int {
    *
    */
   forceinline void
-  IntVarImp::subscribe(Space& home, Propagator& p, PropCond pc, bool process) {
-    IntVarImpBase::subscribe(home,p,pc,dom.min()==dom.max(),process);
+  IntVarImp::subscribe(Space& home, Propagator& p, PropCond pc, bool schedule) {
+    IntVarImpBase::subscribe(home,p,pc,dom.min()==dom.max(),schedule);
   }
   forceinline void
   IntVarImp::cancel(Space& home, Propagator& p, PropCond pc) {
