@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-07-20 14:36:47 +0200 (Mon, 20 Jul 2009) $ by $Author: schulte $
- *     $Revision: 9376 $
+ *     $Date: 2010-06-30 14:31:56 +0200 (Wed, 30 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11134 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,91 +41,79 @@ namespace Gecode {
   BoolVar::_init(Space& home, int min, int max) {
     assert((min >= 0) && (max <= 1) && (min <= max));
     if (min > 0)
-      varimp = &Int::BoolVarImp::s_one;
+      x = &Int::BoolVarImp::s_one;
     else if (max == 0)
-      varimp = &Int::BoolVarImp::s_zero;
+      x = &Int::BoolVarImp::s_zero;
     else
-      varimp = new (home) Int::BoolVarImp(home,0,1);
+      x = new (home) Int::BoolVarImp(home,0,1);
   }
 
   forceinline
   BoolVar::BoolVar(void) {}
   forceinline
-  BoolVar::BoolVar(const BoolVar& x)
-    : VarBase<Int::BoolVarImp>(x.varimp) {}
+  BoolVar::BoolVar(const BoolVar& y)
+    : Var<Int::BoolVarImp>(y.varimp()) {}
   forceinline
-  BoolVar::BoolVar(const Int::BoolView& x)
-    : VarBase<Int::BoolVarImp>(x.var()) {}
+  BoolVar::BoolVar(const Int::BoolView& y)
+    : Var<Int::BoolVarImp>(y.varimp()) {}
 
   forceinline int
   BoolVar::val(void) const {
-    if (!varimp->assigned())
+    if (!x->assigned())
       throw Int::ValOfUnassignedVar("BoolVar::val");
-    return varimp->val();
+    return x->val();
   }
   forceinline int
   BoolVar::min(void) const {
-    return varimp->min();
+    return x->min();
   }
   forceinline int
   BoolVar::med(void) const {
-    return varimp->med();
+    return x->med();
   }
   forceinline int
   BoolVar::max(void) const {
-    return varimp->max();
+    return x->max();
   }
 
 
   forceinline unsigned int
   BoolVar::width(void) const {
-    return varimp->width();
+    return x->width();
   }
   forceinline unsigned int
   BoolVar::size(void) const {
-    return varimp->size();
+    return x->size();
   }
   forceinline unsigned int
   BoolVar::regret_min(void) const {
-    return varimp->regret_min();
+    return x->regret_min();
   }
   forceinline unsigned int
   BoolVar::regret_max(void) const {
-    return varimp->regret_max();
+    return x->regret_max();
   }
 
-
-
-  forceinline bool
-  BoolVar::assigned(void) const {
-    return varimp->assigned();
-  }
   forceinline bool
   BoolVar::range(void) const {
-    return varimp->range();
+    return x->range();
   }
   forceinline bool
   BoolVar::in(int n) const {
-    return varimp->in(n);
-  }
-
-
-  forceinline void
-  BoolVar::update(Space& home, bool share, BoolVar& x) {
-    varimp = x.varimp->copy(home,share);
+    return x->in(n);
   }
 
   forceinline bool
   BoolVar::zero(void) const {
-    return varimp->zero();
+    return x->zero();
   }
   forceinline bool
   BoolVar::one(void) const {
-    return varimp->one();
+    return x->one();
   }
   forceinline bool
   BoolVar::none(void) const {
-    return varimp->none();
+    return x->none();
   }
 
 }
