@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-07-20 14:36:47 +0200 (Mon, 20 Jul 2009) $ by $Author: schulte $
- *     $Revision: 9376 $
+ *     $Date: 2010-06-30 14:31:56 +0200 (Wed, 30 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11134 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,79 +39,67 @@ namespace Gecode {
 
   forceinline void
   IntVar::_init(Space& home, int min, int max) {
-    varimp = new (home) Int::IntVarImp(home,min,max);
+    x = new (home) Int::IntVarImp(home,min,max);
   }
 
   forceinline void
   IntVar::_init(Space& home, const IntSet& ds) {
-    varimp = new (home) Int::IntVarImp(home,ds);
+    x = new (home) Int::IntVarImp(home,ds);
   }
 
   forceinline
   IntVar::IntVar(void) {}
   forceinline
-  IntVar::IntVar(const IntVar& x)
-    : VarBase<Int::IntVarImp>(x.varimp) {}
+  IntVar::IntVar(const IntVar& y)
+    : Var<Int::IntVarImp>(y.varimp()) {}
   forceinline
-  IntVar::IntVar(const Int::IntView& x)
-    : VarBase<Int::IntVarImp>(x.var()) {}
+  IntVar::IntVar(const Int::IntView& y)
+    : Var<Int::IntVarImp>(y.varimp()) {}
 
   forceinline int
   IntVar::val(void) const {
-    if (!varimp->assigned())
+    if (!x->assigned())
       throw Int::ValOfUnassignedVar("IntVar::val");
-    return varimp->val();
+    return x->val();
   }
   forceinline int
   IntVar::min(void) const {
-    return varimp->min();
+    return x->min();
   }
   forceinline int
   IntVar::med(void) const {
-    return varimp->med();
+    return x->med();
   }
   forceinline int
   IntVar::max(void) const {
-    return varimp->max();
+    return x->max();
   }
 
 
   forceinline unsigned int
   IntVar::width(void) const {
-    return varimp->width();
+    return x->width();
   }
   forceinline unsigned int
   IntVar::size(void) const {
-    return varimp->size();
+    return x->size();
   }
   forceinline unsigned int
   IntVar::regret_min(void) const {
-    return varimp->regret_min();
+    return x->regret_min();
   }
   forceinline unsigned int
   IntVar::regret_max(void) const {
-    return varimp->regret_max();
+    return x->regret_max();
   }
 
-
-
-  forceinline bool
-  IntVar::assigned(void) const {
-    return varimp->assigned();
-  }
   forceinline bool
   IntVar::range(void) const {
-    return varimp->range();
+    return x->range();
   }
   forceinline bool
   IntVar::in(int n) const {
-    return varimp->in(n);
-  }
-
-
-  forceinline void
-  IntVar::update(Space& home, bool share, IntVar& x) {
-    varimp = x.varimp->copy(home,share);
+    return x->in(n);
   }
 
   /*
@@ -123,11 +111,11 @@ namespace Gecode {
 
   forceinline
   IntVarRanges::IntVarRanges(const IntVar& x)
-    : Int::IntVarImpFwd(x.var()) {}
+    : Int::IntVarImpFwd(x.varimp()) {}
 
   forceinline void
   IntVarRanges::init(const IntVar& x) {
-    Int::IntVarImpFwd::init(x.var());
+    Int::IntVarImpFwd::init(x.varimp());
   }
 
 
