@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-06-29 10:39:13 +0200 (Tue, 29 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11118 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,11 +44,11 @@ namespace Gecode { namespace Int {
   forceinline
   IntView::IntView(void) {}
   forceinline
-  IntView::IntView(const IntVar& x)
-    : VarViewBase<IntVarImp>(x.var()) {}
+  IntView::IntView(const IntVar& y)
+    : VarImpView<IntVarImp>(y.varimp()) {}
   forceinline
-  IntView::IntView(IntVarImp* x)
-    : VarViewBase<IntVarImp>(x) {}
+  IntView::IntView(IntVarImp* y)
+    : VarImpView<IntVarImp>(y) {}
 
   /*
    * Value access
@@ -56,36 +56,36 @@ namespace Gecode { namespace Int {
    */
   forceinline int
   IntView::min(void) const {
-    return varimp->min();
+    return x->min();
   }
   forceinline int
   IntView::max(void) const {
-    return varimp->max();
+    return x->max();
   }
   forceinline int
   IntView::med(void) const {
-    return varimp->med();
+    return x->med();
   }
   forceinline int
   IntView::val(void) const {
-    return varimp->val();
+    return x->val();
   }
 
   forceinline unsigned int
   IntView::size(void) const {
-    return varimp->size();
+    return x->size();
   }
   forceinline unsigned int
   IntView::width(void) const {
-    return varimp->width();
+    return x->width();
   }
   forceinline unsigned int
   IntView::regret_min(void) const {
-    return varimp->regret_min();
+    return x->regret_min();
   }
   forceinline unsigned int
   IntView::regret_max(void) const {
-    return varimp->regret_max();
+    return x->regret_max();
   }
 
 
@@ -95,20 +95,15 @@ namespace Gecode { namespace Int {
    */
   forceinline bool
   IntView::range(void) const {
-    return varimp->range();
+    return x->range();
   }
-  forceinline bool
-  IntView::assigned(void) const {
-    return varimp->assigned();
-  }
-
   forceinline bool
   IntView::in(int n) const {
-    return varimp->in(n);
+    return x->in(n);
   }
   forceinline bool
   IntView::in(double n) const {
-    return varimp->in(n);
+    return x->in(n);
   }
 
 
@@ -118,16 +113,16 @@ namespace Gecode { namespace Int {
    */
   forceinline ModEvent
   IntView::lq(Space& home, int n) {
-    return varimp->lq(home,n);
+    return x->lq(home,n);
   }
   forceinline ModEvent
   IntView::lq(Space& home, double n) {
-    return varimp->lq(home,n);
+    return x->lq(home,n);
   }
 
   forceinline ModEvent
   IntView::le(Space& home, int n) {
-    return varimp->lq(home,n-1);
+    return x->lq(home,n-1);
   }
   forceinline ModEvent
   IntView::le(Space& home, double n) {
@@ -136,16 +131,16 @@ namespace Gecode { namespace Int {
 
   forceinline ModEvent
   IntView::gq(Space& home, int n) {
-    return varimp->gq(home,n);
+    return x->gq(home,n);
   }
   forceinline ModEvent
   IntView::gq(Space& home, double n) {
-    return varimp->gq(home,n);
+    return x->gq(home,n);
   }
 
   forceinline ModEvent
   IntView::gr(Space& home, int n) {
-    return varimp->gq(home,n+1);
+    return x->gq(home,n+1);
   }
   forceinline ModEvent
   IntView::gr(Space& home, double n) {
@@ -154,20 +149,20 @@ namespace Gecode { namespace Int {
 
   forceinline ModEvent
   IntView::nq(Space& home, int n) {
-    return varimp->nq(home,n);
+    return x->nq(home,n);
   }
   forceinline ModEvent
   IntView::nq(Space& home, double n) {
-    return varimp->nq(home,n);
+    return x->nq(home,n);
   }
 
   forceinline ModEvent
   IntView::eq(Space& home, int n) {
-    return varimp->eq(home,n);
+    return x->eq(home,n);
   }
   forceinline ModEvent
   IntView::eq(Space& home, double n) {
-    return varimp->eq(home,n);
+    return x->eq(home,n);
   }
 
 
@@ -179,37 +174,37 @@ namespace Gecode { namespace Int {
   forceinline ModEvent
   IntView::narrow_r(Space& home, I& i, bool depend) {
     Iter::Ranges::IsRangeIter<I>();
-    return varimp->narrow_r(home,i,depend);
+    return x->narrow_r(home,i,depend);
   }
   template<class I>
   forceinline ModEvent
   IntView::inter_r(Space& home, I& i, bool depend) {
     Iter::Ranges::IsRangeIter<I>();
-    return varimp->inter_r(home,i,depend);
+    return x->inter_r(home,i,depend);
   }
   template<class I>
   forceinline ModEvent
   IntView::minus_r(Space& home, I& i, bool depend) {
     Iter::Ranges::IsRangeIter<I>();
-    return varimp->minus_r(home,i,depend);
+    return x->minus_r(home,i,depend);
   }
   template<class I>
   forceinline ModEvent
   IntView::narrow_v(Space& home, I& i, bool depend) {
     Iter::Values::IsValueIter<I>();
-    return varimp->narrow_v(home,i,depend);
+    return x->narrow_v(home,i,depend);
   }
   template<class I>
   forceinline ModEvent
   IntView::inter_v(Space& home, I& i, bool depend) {
     Iter::Values::IsValueIter<I>();
-    return varimp->inter_v(home,i,depend);
+    return x->inter_v(home,i,depend);
   }
   template<class I>
   forceinline ModEvent
   IntView::minus_v(Space& home, I& i, bool depend) {
     Iter::Values::IsValueIter<I>();
-    return varimp->minus_v(home,i,depend);
+    return x->minus_v(home,i,depend);
   }
 
 
@@ -219,10 +214,6 @@ namespace Gecode { namespace Int {
    * Delta information for advisors
    *
    */
-  forceinline ModEvent
-  IntView::modevent(const Delta& d) {
-    return IntVarImp::modevent(d);
-  }
   forceinline int
   IntView::min(const Delta& d) const {
     return IntVarImp::min(d);
@@ -239,18 +230,7 @@ namespace Gecode { namespace Int {
 
   forceinline ModEventDelta
   IntView::med(ModEvent me) {
-    return VarViewBase<IntVarImp>::med(me);
-  }
-
-
-
-  /*
-   * Cloning
-   *
-   */
-  forceinline void
-  IntView::update(Space& home, bool share, IntView& x) {
-    varimp = x.varimp->copy(home,share);
+    return VarImpView<IntVarImp>::med(me);
   }
 
 
@@ -277,11 +257,11 @@ namespace Gecode { namespace Int {
 
   forceinline
   ViewRanges<IntView>::ViewRanges(const IntView& x)
-    : IntVarImpFwd(x.var()) {}
+    : IntVarImpFwd(x.varimp()) {}
 
   forceinline void
   ViewRanges<IntView>::init(const IntView& x) {
-    IntVarImpFwd::init(x.var());
+    IntVarImpFwd::init(x.varimp());
   }
 
 }}
