@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11192 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -91,18 +91,18 @@ namespace Gecode { namespace Iter { namespace Ranges {
     /// The array of iterators to be appended
     I* r;
     /// Number of iterators
-    unsigned int n;
+    int n;
     /// Number of current iterator being processed
-    unsigned int active;
+    int active;
   public:
     /// \name Constructors and initialization
     //@{
     /// Default constructor
     NaryAppend(void);
     /// Initialize with \a n iterators in \a i
-    NaryAppend(I* i, unsigned int n);
+    NaryAppend(I* i, int n);
     /// Initialize with \a n iterators in \a i
-    void init(I* i, unsigned int n);
+    void init(I* i, int n);
     //@}
 
     /// \name Iteration control
@@ -196,7 +196,7 @@ namespace Gecode { namespace Iter { namespace Ranges {
 
   template<class I>
   inline
-  NaryAppend<I>::NaryAppend(I* r0, unsigned int n0)
+  NaryAppend<I>::NaryAppend(I* r0, int n0)
     : r(r0), n(n0), active(0) {
     while (active < n && !r[active]())
       active++;
@@ -209,7 +209,7 @@ namespace Gecode { namespace Iter { namespace Ranges {
 
   template<class I>
   inline void
-  NaryAppend<I>::init(I* r0, unsigned int n0) {
+  NaryAppend<I>::init(I* r0, int n0) {
     r = r0; n = n0; active = 0;
     while (active < n && !r[active]())
       active++;
