@@ -9,8 +9,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-06-03 13:46:55 +0200 (Thu, 03 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11014 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -46,6 +46,21 @@ namespace Gecode {
   template<class Var> class VarArray;
   template<class Var> class VarArgArray;
 
+  /** \brief Traits of arrays in %Gecode
+   *
+   * This class collects the traits of an array in Gecode.
+   * The traits used are the following.
+   *     - <code>typedef Type StorageType</code>  where \c Type is the type
+   *       of an appropriate storage type for this array.
+   *     - <code>typedef Type ValueType</code>  where \c Type is the type
+   *       of the elements of this array.
+   *     - <code>typedef Type ArgsType</code>  where \c Type is the type
+   *       of the appropriate Args-array type (e.g., \c BoolVarArgs if \c A is
+   *       \c BoolVarArray).
+   */
+  template<class A>
+  class ArrayTraits {};
+
   /**
    * \brief %Variable arrays
    *
@@ -66,8 +81,6 @@ namespace Gecode {
   protected:
     /// Number of variables (size)
     int n;
-    /// Allocated size of the array
-    int capacity;
     /// Array of variables
     Var* x;
   public:
@@ -83,19 +96,12 @@ namespace Gecode {
     VarArray(const VarArray<Var>& a);
     /// Initialize from variable array \a a (share elements)
     const VarArray<Var>& operator =(const VarArray<Var>& a);
-    /// Destructor
-    ~VarArray(void);
     //@}
 
     /// \name Array size
     //@{
     /// Return size of array (number of elements)
     int size(void) const;
-    /**
-      * \brief Insert or remove (uninitialized!) elements at the end such
-      * that size becomes \a m
-      */
-    void resize(Space& home, int m);
     //@}
 
     /// \name Array elements
@@ -104,10 +110,18 @@ namespace Gecode {
     Var& operator [](int i);
     /// Return variable at position \a i
     const Var& operator [](int i) const;
-    /// Insert a new element \a v at the end of the array (increase size by 1)
-    void add(Space& home, const Var& v);
+    /** Return slice \f$y\f$ of length at most \a n such that forall \f$0\leq i<n\f$, \f$y_i=x_{\text{start}+i\cdot\text{inc}}\f$
+     *
+     * If \a n is -1, then all possible elements starting from \a start
+     * with increment \a inc are returned.
+     */
+    typename ArrayTraits<VarArgArray<Var> >::ArgsType
+    slice(int start, int inc=1, int n=-1);
     //@}
 
+    /// Test if all variables are assigned
+    bool assigned(void) const;
+
     /// \name Cloning
     //@{
     /**
@@ -124,6 +138,40 @@ namespace Gecode {
     static void  operator delete(void*,size_t);
   };
 
+  /** Concatenate \a x and \a y and return result
+   * \relates VarArray
+   */
+  template<class T>
+  typename ArrayTraits<VarArray<T> >::ArgsType
+  operator +(const VarArray<T>& x, const VarArgArray<T>& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates VarArray
+   */
+  template<class T>
+  typename ArrayTraits<VarArray<T> >::ArgsType
+  operator +(const VarArray<T>& x, const VarArray<T>& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates VarArray
+   */
+  template<class T>
+  typename ArrayTraits<VarArray<T> >::ArgsType
+  operator +(const VarArgArray<T>& x, const VarArray<T>& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates VarArray
+   */
+  template<class T>
+  typename ArrayTraits<VarArray<T> >::ArgsType
+  operator +(const VarArray<T>& x, const T& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates VarArray
+   */
+  template<class T>
+  typename ArrayTraits<VarArray<T> >::ArgsType
+  operator +(const T& x, const VarArray<T>& y);
 
   /**
    * \brief View arrays
@@ -293,6 +341,9 @@ namespace Gecode {
     void drop_lst(int i, Space& home, Advisor& a);
     //@}
 
+    /// Test if all variables are assigned
+    bool assigned(void) const;
+
     /// \name View equality
     //@{
     /**
@@ -350,27 +401,52 @@ namespace Gecode {
    * from the heap.
    *
    * This base-class is not to be used directly, use PrimArgArray for
-   * argument arrays of primitive types and VarArgArray for argument
-   * arrays storing variables.
+   * argument arrays of primitive types, VarArgArray for argument
+   * arrays storing variables, and ArgArray for any other type.
    */
   template<class T>
   class ArgArrayBase {
   protected:
     /// Number of elements
     int n;
+    /// Allocated size of the array
+    int capacity;
     /// Element array
     T*  a;
-    /// How much elements are possible inside array
+    /// How many elements are possible inside array
     static const int onstack_size = 16;
     /// In-array storage for elements
     T onstack[onstack_size];
     /// Allocate memory for \a n elements
     T* allocate(int n);
+    /// Resize to hold at least \a i additional elements
+    void resize(int i);
+    /// Return this array concatenated with \a x
+    template<class A>
+    A concat(const ArgArrayBase<T>& x) const;
+    /// Return this array concatenated with \a x
+    template<class A>
+    A concat(const T& x) const;
+    /// Insert a new element \a x at the end of the array (increase size by 1)
+    template<class A>
+    A& append(const T& x);
+    /// Append \a x to the end of the array
+    template<class A>
+    A& append(const ArgArrayBase<T>& x);
+    /** Return slice \f$y\f$ of length at most \a n such that forall \f$0\leq i<n\f$, \f$y_i=x_{\text{start}+i\cdot\text{inc}}\f$
+     *
+     * If \a n is -1, then all possible elements starting from \a start
+     * with increment \a inc are returned.
+     */
+    template<class A>
+    A slice(int start, int inc=1, int n=-1);
   public:
     /// \name Constructors and initialization
     //@{
+    /// Allocate empty array
+    ArgArrayBase(void);
     /// Allocate array with \a n elements
-    ArgArrayBase(int n);
+    explicit ArgArrayBase(int n);
     /// Initialize from argument array \a a (copy elements)
     ArgArrayBase(const ArgArrayBase<T>& a);
     /// Initialize from view array \a a (copy elements)
@@ -401,6 +477,28 @@ namespace Gecode {
     static void  operator delete(void*,size_t);
   };
 
+  template<class> class PrimArgArray;
+
+  /** Concatenate \a x and \a y and return result
+   * \relates PrimArgArray
+   */
+  template<class T>
+  typename ArrayTraits<PrimArgArray<T> >::ArgsType
+  operator +(const PrimArgArray<T>& x, const PrimArgArray<T>& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates PrimArgArray
+   */
+  template<class T>
+  typename ArrayTraits<PrimArgArray<T> >::ArgsType
+  operator +(const PrimArgArray<T>& x, const T& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates PrimArgArray
+   */
+  template<class T>
+  typename ArrayTraits<PrimArgArray<T> >::ArgsType
+  operator +(const T& x, const PrimArgArray<T>& y);
 
   /**
    * \brief Argument array for primtive types
@@ -421,6 +519,8 @@ namespace Gecode {
     using ArgArrayBase<T>::size;
     /// \name Constructors and initialization
     //@{
+    /// Allocate empty array
+    PrimArgArray(void);
     /// Allocate array with \a n elements
     explicit PrimArgArray(int n);
     /// Allocate array with \a n elements and initialize with \a e0, ...
@@ -430,8 +530,58 @@ namespace Gecode {
     /// Initialize from primitive argument array \a a (copy elements)
     PrimArgArray(const PrimArgArray<T>& a);
     //@}
+    /// \name Array elements
+    //@{
+    /** Return slice \f$y\f$ of length at most \a n such that forall \f$0\leq i<n\f$, \f$y_i=x_{\text{start}+i\cdot\text{inc}}\f$
+     *
+     * If \a n is -1, then all possible elements starting from \a start
+     * with increment \a inc are returned.
+     */
+    typename ArrayTraits<PrimArgArray<T> >::ArgsType
+    slice(int start, int inc=1, int n=-1);
+    //@}
+    /// \name Appending elements
+    //@{
+    /// Insert a new element \a x at the end of the array (increase size by 1)
+    typename ArrayTraits<PrimArgArray<T> >::ArgsType&
+    operator <<(const T& x);
+    /// Append \a x to the end of the array
+    typename ArrayTraits<PrimArgArray<T> >::ArgsType&
+    operator <<(const PrimArgArray<T>& x);
+    //@}
+
+    friend typename ArrayTraits<PrimArgArray<T> >::ArgsType
+    operator + <>(const PrimArgArray<T>& x, const PrimArgArray<T>& y);
+    friend typename ArrayTraits<PrimArgArray<T> >::ArgsType
+    operator + <>(const PrimArgArray<T>& x, const T& y);
+    friend
+    typename ArrayTraits<PrimArgArray<T> >::ArgsType
+    operator + <>(const T& x, const PrimArgArray<T>& y);
   };
 
+  template<class> class ArgArray;
+
+  /** Concatenate \a x and \a y and return result
+   * \relates ArgArray
+   */
+  template<class T>
+  typename ArrayTraits<ArgArray<T> >::ArgsType
+  operator +(const ArgArray<T>& x, const ArgArray<T>& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates ArgArray
+   */
+  template<class T>
+  typename ArrayTraits<ArgArray<T> >::ArgsType
+  operator +(const ArgArray<T>& x, const T& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates ArgArray
+   */
+  template<class T>
+  typename ArrayTraits<ArgArray<T> >::ArgsType
+  operator +(const T& x, const ArgArray<T>& y);
+
   /**
    * \brief Argument array for non-primitive types
    *
@@ -451,6 +601,8 @@ namespace Gecode {
     using ArgArrayBase<T>::size;
     /// \name Constructors and initialization
     //@{
+    /// Allocate empty array
+    ArgArray(void);
     /// Allocate array with \a n elements
     explicit ArgArray(int n);
     /// Allocate array with \a n elements and initialize with elements from array \a e
@@ -458,8 +610,54 @@ namespace Gecode {
     /// Initialize from primitive argument array \a a (copy elements)
     ArgArray(const ArgArray<T>& a);
     //@}
+    /// \name Array elements
+    //@{
+    /// Return slice \f$y\f$ of length \a n such that forall \f$0\leq i<n\f$, \f$y_i=x_{\text{start}+i\cdot\text{inc}}\f$
+    typename ArrayTraits<ArgArray<T> >::ArgsType
+    slice(int start, int inc=1, int n=-1);
+    //@}
+    /// \name Appending elements
+    //@{
+    /// Insert a new element \a x at the end of the array (increase size by 1)
+    typename ArrayTraits<ArgArray<T> >::ArgsType&
+    operator <<(const T& x);
+    /// Append \a x to the end of the array
+    typename ArrayTraits<ArgArray<T> >::ArgsType&
+    operator <<(const ArgArray<T>& x);
+    //@}
+
+    friend typename ArrayTraits<ArgArray<T> >::ArgsType
+    operator + <>(const ArgArray<T>& x, const ArgArray<T>& y);
+    friend typename ArrayTraits<ArgArray<T> >::ArgsType
+    operator + <>(const ArgArray<T>& x, const T& y);
+    friend
+    typename ArrayTraits<ArgArray<T> >::ArgsType
+    operator + <>(const T& x, const ArgArray<T>& y);
   };
 
+  template<class> class VarArgArray;
+
+  /** Concatenate \a x and \a y and return result
+   * \relates ArgArray
+   */
+  template<class Var>
+  typename ArrayTraits<VarArgArray<Var> >::ArgsType
+  operator +(const VarArgArray<Var>& x, const VarArgArray<Var>& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates ArgArray
+   */
+  template<class Var>
+  typename ArrayTraits<VarArgArray<Var> >::ArgsType
+  operator +(const VarArgArray<Var>& x, const Var& y);
+
+  /** Concatenate \a x and \a y and return result
+   * \relates ArgArray
+   */
+  template<class Var>
+  typename ArrayTraits<VarArgArray<Var> >::ArgsType
+  operator +(const Var& x, const VarArgArray<Var>& y);
+
   /**
    * \brief Argument array for variables
    *
@@ -485,6 +683,8 @@ namespace Gecode {
     using ArgArrayBase<Var>::size;
     /// \name Constructors and initialization
     //@{
+    /// Allocate empty array
+    VarArgArray(void);
     /// Allocate array with \a n elements
     explicit VarArgArray(int n);
     /// Initialize from variable argument array \a a (copy elements)
@@ -492,6 +692,33 @@ namespace Gecode {
     /// Initialize from variable array \a a (copy elements)
     VarArgArray(const VarArray<Var>& a);
     //@}
+    /// \name Array elements
+    //@{
+    /// Return slice \f$y\f$ of length \a n such that forall \f$0\leq i<n\f$, \f$y_i=x_{\text{start}+i\cdot\text{inc}}\f$
+    typename ArrayTraits<VarArgArray<Var> >::ArgsType
+    slice(int start, int inc=1, int n=-1);
+    //@}
+    /// \name Appending elements
+    //@{
+    /// Insert a new element \a x at the end of the array (increase size by 1)
+    typename ArrayTraits<VarArgArray<Var> >::ArgsType&
+    operator <<(const Var& x);
+    /// Append \a x to the end of the array
+    typename ArrayTraits<VarArgArray<Var> >::ArgsType&
+    operator <<(const VarArgArray<Var>& x);
+    //@}
+
+    /// Test if all variables are assigned
+    bool assigned(void) const;
+
+    friend typename ArrayTraits<VarArgArray<Var> >::ArgsType
+    operator + <>(const VarArgArray<Var>& x, const VarArgArray<Var>& y);
+    friend typename ArrayTraits<VarArgArray<Var> >::ArgsType
+    operator + <>(const VarArgArray<Var>& x, const Var& y);
+    friend
+    typename ArrayTraits<VarArgArray<Var> >::ArgsType
+    operator + <>(const Var& x, const VarArgArray<Var>& y);
+
     /// \name Variable equality
     //@{
     /**
@@ -541,22 +768,6 @@ namespace Gecode {
   operator <<(std::basic_ostream<Char,Traits>& os, const ArgArrayBase<T>& x);
 
 
-
-  /** \brief Traits of arrays in %Gecode
-   *
-   * This class collects the traits of an array in Gecode.
-   * The traits used are the following.
-   *     - <code>typedef Type storage_type</code>  where \c Type is the type
-   *       of an appropriate storage type for this array.
-   *     - <code>typedef Type value_type</code>  where \c Type is the type
-   *       of the elements of this array.
-   *     - <code>typedef Type args_type</code>  where \c Type is the type
-   *       of the appropriate Args-array type (e.g., \c BoolVarArgs if \c A is
-   *       \c BoolVarArray).
-   */
-  template<class A>
-  class ArrayTraits {};
-
   /*
    * Implementation
    *
@@ -574,12 +785,12 @@ namespace Gecode {
 
   template<class Var>
   forceinline
-  VarArray<Var>::VarArray(void) : n(0), capacity(0), x(NULL) {}
+  VarArray<Var>::VarArray(void) : n(0), x(NULL) {}
 
   template<class Var>
   forceinline
   VarArray<Var>::VarArray(Space& home, int n0)
-    : n(n0), capacity(n0) {
+    : n(n0) {
     // Allocate from space
     x = (n>0) ? home.alloc<Var>(n) : NULL;
   }
@@ -587,22 +798,13 @@ namespace Gecode {
   template<class Var>
   forceinline
   VarArray<Var>::VarArray(const VarArray<Var>& a) {
-    n = a.n; capacity = a.capacity; x = a.x;
+    n = a.n; x = a.x;
   }
 
   template<class Var>
-  forceinline
-  VarArray<Var>::~VarArray(void) {
-    if (n != capacity) {
-      // Array was allocated on the heap
-      heap.free<Var>(x, capacity);
-    }
-  }
-
-  template<class Var>
-  forceinline const VarArray<Var>&
+  inline const VarArray<Var>&
   VarArray<Var>::operator =(const VarArray<Var>& a) {
-    n = a.n; capacity = a.capacity; x = a.x;
+    n = a.n; x = a.x;
     return *this;
   }
 
@@ -612,39 +814,6 @@ namespace Gecode {
     return n;
   }
 
-  template<class Var>
-  forceinline void
-  VarArray<Var>::resize(Space& home, int m) {
-    int newsize;
-    int newn;
-    if (m<n) {
-      // Shrink array and leave capacity at m+1, forcing heap allocation
-      newsize = m+1;
-      newn = m;
-    } else if (m<capacity) {
-      // As m>=n<capacity, the array is heap allocated, just resize
-      n = m;
-      return;
-    } else {
-      // Resize, so that newsize != m forcing heap allocation
-      newsize = std::max(m+1, (3*capacity)/2);
-      newn = n;
-    }
-
-    if (n == capacity) {
-      // Array was space allocated, copy to heap with new size
-      Var* oldx = x;
-      x = heap.copy<Var>(heap.alloc<Var>(newsize), x, newn);
-      home.rfree(oldx, capacity);
-    } else {
-      // Array was heap allocated, just reallocate with new size
-      x = heap.realloc<Var>(x, n, newsize);
-    }
-    capacity = newsize; n = m;
-    // After resizing, the array is always heap allocated
-    assert(capacity != n);
-  }
-
   template<class Var>
   forceinline Var&
   VarArray<Var>::operator [](int i) {
@@ -660,26 +829,46 @@ namespace Gecode {
   }
 
   template<class Var>
-  forceinline void
-  VarArray<Var>::add(Space& home, const Var& v) {
-    resize(home, n+1);
-    new (&(*this)[n-1]) Var(v);
+  typename ArrayTraits<VarArgArray<Var> >::ArgsType
+  VarArray<Var>::slice(int start, int inc, int maxN) {
+    assert(start < n);
+    if (maxN<0)
+      maxN = n;
+    int s;
+    if (inc == 0)
+      s = n-start;
+    else if (inc > 0)
+      s = (n-start)/inc + ((n-start) % inc == 0 ? 0 : 1);
+    else
+      s = (start+1)/-inc + ((start+1) % -inc == 0 ? 0 : 1);
+    typename ArrayTraits<VarArgArray<Var> >::ArgsType r(std::min(maxN,s));
+    for (int i=0; i<r.size(); i++, start+=inc)
+      r[i] = x[start];
+    return r;
   }
 
   template<class Var>
   forceinline void
   VarArray<Var>::update(Space& home, bool share, VarArray<Var>& a) {
-    capacity = a.n;
-    n = capacity;
-    if (capacity > 0) {
-      x = home.alloc<Var>(capacity);
-      for (int i = capacity; i--; )
+    n = a.n;
+    if (n > 0) {
+      x = home.alloc<Var>(n);
+      for (int i = n; i--;)
         x[i].update(home, share, a.x[i]);
     } else {
       x = NULL;
     }
   }
 
+  template<class Var>
+  forceinline bool
+  VarArray<Var>::assigned(void) const {
+    for (int i = n; i--;)
+      if (!x[i].assigned())
+        return false;
+    return true;
+  }
+  
   template<class Var>
   void*
   VarArray<Var>::operator new(size_t) {
@@ -691,6 +880,59 @@ namespace Gecode {
   VarArray<Var>::operator delete(void*,size_t) {
   }
 
+  template<class Var>
+  typename ArrayTraits<VarArray<Var> >::ArgsType
+  operator +(const VarArray<Var>& x, const VarArray<Var>& y) {
+    typename ArrayTraits<VarArray<Var> >::ArgsType r(x.size()+y.size());
+    for (int i=x.size(); i--;)
+      r[i] = x[i];
+    for (int i=y.size(); i--;)
+      r[x.size()+i] = y[i];
+    return r;
+  }
+
+  template<class Var>
+  typename ArrayTraits<VarArray<Var> >::ArgsType
+  operator +(const VarArray<Var>& x, const VarArgArray<Var>& y) {
+    typename ArrayTraits<VarArray<Var> >::ArgsType r(x.size()+y.size());
+    for (int i=x.size(); i--;)
+      r[i] = x[i];
+    for (int i=y.size(); i--;)
+      r[x.size()+i] = y[i];
+    return r;
+  }
+
+  template<class Var>
+  typename ArrayTraits<VarArray<Var> >::ArgsType
+  operator +(const VarArgArray<Var>& x, const VarArray<Var>& y) {
+    typename ArrayTraits<VarArray<Var> >::ArgsType r(x.size()+y.size());
+    for (int i=x.size(); i--;)
+      r[i] = x[i];
+    for (int i=y.size(); i--;)
+      r[x.size()+i] = y[i];
+    return r;
+  }
+
+  template<class Var>
+  typename ArrayTraits<VarArray<Var> >::ArgsType
+  operator +(const VarArray<Var>& x, const Var& y) {
+    typename ArrayTraits<VarArray<Var> >::ArgsType r(x.size()+1);
+    for (int i=x.size(); i--;)
+      r[i] = x[i];
+    r[x.size()] = y;
+    return r;    
+  }
+
+  template<class Var>
+  typename ArrayTraits<VarArray<Var> >::ArgsType
+  operator +(const Var& x, const VarArray<Var>& y) {
+    typename ArrayTraits<VarArray<Var> >::ArgsType r(y.size()+1);
+    r[0] = x;
+    for (int i=y.size(); i--;)
+      r[1+i] = y[i];
+    return r;
+  }
+
   /*
    * View arrays
    *
@@ -897,6 +1139,15 @@ namespace Gecode {
       x[i].cancel(home,a);
   }
 
+  template<class View>
+  forceinline bool
+  ViewArray<View>::assigned(void) const {
+    for (int i = n; i--;)
+      if (!x[i].assigned())
+        return false;
+    return true;
+  }
+
   template<class View>
   forceinline bool
   __before(const View& x, const View& y) {
@@ -1058,32 +1309,55 @@ namespace Gecode {
       heap.alloc<T>(static_cast<unsigned int>(n)) : &onstack[0];
   }
 
+  template<class T>
+  forceinline void
+  ArgArrayBase<T>::resize(int i) {
+    if (n+i >= capacity) {
+      assert(n+i >= onstack_size);
+      int newCapacity = (3*capacity)/2;
+      if (newCapacity <= n+i)
+        newCapacity = n+i;
+      T* newA = allocate(newCapacity);
+      heap.copy<T>(newA,a,n);
+      if (capacity > onstack_size)
+        heap.free(a,capacity);
+      capacity = newCapacity;
+      a = newA;
+    }
+  }
+
+  template<class T>
+  forceinline
+  ArgArrayBase<T>::ArgArrayBase(void)
+    : n(0), capacity(onstack_size), a(allocate(0)) {}
+
   template<class T>
   forceinline
   ArgArrayBase<T>::ArgArrayBase(int n0)
-    : n(n0), a(allocate(n)) {}
+    : n(n0), capacity(n < onstack_size ? onstack_size : n), a(allocate(n)) {}
 
   template<class T>
   inline
   ArgArrayBase<T>::ArgArrayBase(const ArgArrayBase<T>& aa)
-    : n(aa.n), a(allocate(n)) {
+    : n(aa.n), capacity(n < onstack_size ? onstack_size : n), a(allocate(n)) {
     heap.copy<T>(a,aa.a,n);
   }
 
   template<class T>
   forceinline
   ArgArrayBase<T>::~ArgArrayBase(void) {
-    if (n > onstack_size)
-      heap.free(a,n);
+    if (capacity > onstack_size)
+      heap.free(a,capacity);
   }
 
   template<class T>
   forceinline const ArgArrayBase<T>&
   ArgArrayBase<T>::operator =(const ArgArrayBase<T>& aa) {
     if (&aa != this) {
-      if (n > onstack_size)
-        heap.free(a,n);
+      if (capacity > onstack_size)
+        heap.free(a,capacity);
       n = aa.n;
+      capacity = (n < onstack_size ? onstack_size : n);
       a = allocate(aa.n);
       heap.copy<T>(a,aa.a,n);
     }
@@ -1110,6 +1384,62 @@ namespace Gecode {
     return a[i];
   }
 
+  template<class T> template<class A>
+  A
+  ArgArrayBase<T>::slice(int start, int inc, int maxN) {
+    assert(start < n);
+    if (maxN<0)
+      maxN = n;
+    int s;
+    if (inc == 0)
+      s = n-start;
+    else if (inc > 0)
+      s = (n-start)/inc + ((n-start) % inc == 0 ? 0 : 1);
+    else
+      s = (start+1)/-inc + ((start+1) % -inc == 0 ? 0 : 1);
+    A r(std::min(maxN,s));
+    for (int i=0; i<r.size(); i++, start+=inc)
+      new (&r[i]) T(a[start]);
+    return r;
+  }
+
+  template<class T> template<class A>
+  inline A&
+  ArgArrayBase<T>::append(const T& x) {
+    resize(1);
+    new (&a[n++]) T(x);
+    return static_cast<A&>(*this);
+  }
+
+  template<class T> template<class A>
+  inline A&
+  ArgArrayBase<T>::append(const ArgArrayBase<T>& x) {
+    resize(x.size());
+    for (int i=0; i<x.size(); i++)
+      new (&a[n++]) T(x[i]);
+    return static_cast<A&>(*this);
+  }
+
+  template<class T> template<class A>
+  inline A
+  ArgArrayBase<T>::concat(const ArgArrayBase<T>& x) const {
+    A r(n+x.n);
+    for (int i=n; i--;)
+      new (&r[i]) T(a[i]);
+    for (int i=x.n; i--;)
+      new (&r[n+i]) T(x.a[i]);
+    return r;
+  }
+
+  template<class T> template<class A>
+  inline A
+  ArgArrayBase<T>::concat(const T& x) const {
+    A r(n+1);
+    for (int i=n; i--;)
+      new (&r[i]) T(a[i]);
+    new (&r[n]) T(x);
+    return r;
+  }
 
   /*
    * Argument arrays for primitive types
@@ -1118,8 +1448,11 @@ namespace Gecode {
 
   template<class T>
   forceinline
-  PrimArgArray<T>::PrimArgArray(int n)
-    : ArgArrayBase<T>(n) {}
+  PrimArgArray<T>::PrimArgArray(void) {}
+
+  template<class T>
+  forceinline
+  PrimArgArray<T>::PrimArgArray(int n) : ArgArrayBase<T>(n) {}
 
   template<class T>
   PrimArgArray<T>::PrimArgArray(int n, T a0, ...)
@@ -1144,6 +1477,51 @@ namespace Gecode {
   PrimArgArray<T>::PrimArgArray(const PrimArgArray<T>& aa)
     : ArgArrayBase<T>(aa) {}
 
+  template<class T>
+  forceinline typename ArrayTraits<PrimArgArray<T> >::ArgsType
+  PrimArgArray<T>::slice(int start, int inc, int maxN) {
+    return ArgArrayBase<T>::template slice
+      <typename ArrayTraits<PrimArgArray<T> >::ArgsType>
+        (start,inc,maxN);
+  }
+
+  template<class T>
+  forceinline typename ArrayTraits<PrimArgArray<T> >::ArgsType&
+  PrimArgArray<T>::operator <<(const T& x) {
+    return
+      ArgArrayBase<T>::template append
+        <typename ArrayTraits<PrimArgArray<T> >::ArgsType>(x);
+  }
+
+  template<class T>
+  forceinline typename ArrayTraits<PrimArgArray<T> >::ArgsType&
+  PrimArgArray<T>::operator <<(const PrimArgArray<T>& x) {
+    return
+      ArgArrayBase<T>::template append
+        <typename ArrayTraits<PrimArgArray<T> >::ArgsType>(x);
+  }
+
+  template<class T>
+  typename ArrayTraits<PrimArgArray<T> >::ArgsType
+  operator +(const PrimArgArray<T>& x, const PrimArgArray<T>& y) {
+    return x.template concat
+      <typename ArrayTraits<PrimArgArray<T> >::ArgsType>(y);
+  }
+
+  template<class T>
+  typename ArrayTraits<PrimArgArray<T> >::ArgsType
+  operator +(const PrimArgArray<T>& x, const T& y) {
+    return x.template concat
+      <typename ArrayTraits<PrimArgArray<T> >::ArgsType>(y);    
+  }
+
+  template<class T>
+  typename ArrayTraits<PrimArgArray<T> >::ArgsType
+  operator +(const T& x, const PrimArgArray<T>& y) {
+    return PrimArgArray<T>(1,x).template concat
+      <typename ArrayTraits<PrimArgArray<T> >::ArgsType>(y);    
+  }
+
 
   /*
    * Argument arrays for non-primitive types
@@ -1152,8 +1530,11 @@ namespace Gecode {
 
   template<class T>
   forceinline
-  ArgArray<T>::ArgArray(int n)
-    : ArgArrayBase<T>(n) {}
+  ArgArray<T>::ArgArray(void) {}
+
+  template<class T>
+  forceinline
+  ArgArray<T>::ArgArray(int n) : ArgArrayBase<T>(n) {}
 
   template<class T>
   ArgArray<T>::ArgArray(int n, const T* a0)
@@ -1167,7 +1548,52 @@ namespace Gecode {
   ArgArray<T>::ArgArray(const ArgArray<T>& aa)
     : ArgArrayBase<T>(aa) {}
 
+  template<class T>
+  forceinline typename ArrayTraits<ArgArray<T> >::ArgsType
+  ArgArray<T>::slice(int start, int inc, int maxN) {
+    return ArgArrayBase<T>::template slice
+      <typename ArrayTraits<ArgArray<T> >::ArgsType>
+      (start,inc,maxN);
+  }
 
+  template<class T>
+  forceinline typename ArrayTraits<ArgArray<T> >::ArgsType&
+  ArgArray<T>::operator <<(const T& x) {
+    return
+      ArgArrayBase<T>::template append
+        <typename ArrayTraits<ArgArray<T> >::ArgsType>(x);
+  }
+
+  template<class T>
+  forceinline typename ArrayTraits<ArgArray<T> >::ArgsType&
+  ArgArray<T>::operator <<(const ArgArray<T>& x) {
+    return
+      ArgArrayBase<T>::template append
+        <typename ArrayTraits<ArgArray<T> >::ArgsType>(x);
+  }
+
+  template<class T>
+  typename ArrayTraits<ArgArray<T> >::ArgsType
+  operator +(const ArgArray<T>& x, const ArgArray<T>& y) {
+    return x.template concat
+      <typename ArrayTraits<ArgArray<T> >::ArgsType>(y);
+  }
+
+  template<class T>
+  typename ArrayTraits<ArgArray<T> >::ArgsType
+  operator +(const ArgArray<T>& x, const T& y) {
+    return x.template concat
+      <typename ArrayTraits<ArgArray<T> >::ArgsType>(y);    
+  }
+
+  template<class T>
+  typename ArrayTraits<ArgArray<T> >::ArgsType
+  operator +(const T& x, const ArgArray<T>& y) {
+    ArgArray<T> xa(1);
+    xa[0] = x;
+    return xa.template concat
+      <typename ArrayTraits<ArgArray<T> >::ArgsType>(y);    
+  }
 
   /*
    * Argument arrays for variables
@@ -1176,8 +1602,11 @@ namespace Gecode {
 
   template<class Var>
   forceinline
-  VarArgArray<Var>::VarArgArray(int n)
-    : ArgArrayBase<Var>(n) {}
+  VarArgArray<Var>::VarArgArray(void) {}
+
+  template<class Var>
+  forceinline
+  VarArgArray<Var>::VarArgArray(int n) : ArgArrayBase<Var>(n) {}
 
   template<class Var>
   forceinline
@@ -1192,10 +1621,66 @@ namespace Gecode {
       a[i]=x[i];
   }
 
+  template<class Var>
+  forceinline typename ArrayTraits<VarArgArray<Var> >::ArgsType
+  VarArgArray<Var>::slice(int start, int inc, int maxN) {
+    return ArgArrayBase<Var>::template slice
+      <typename ArrayTraits<VarArgArray<Var> >::ArgsType>
+        (start,inc,maxN);
+  }
+
+  template<class Var>
+  forceinline typename ArrayTraits<VarArgArray<Var> >::ArgsType&
+  VarArgArray<Var>::operator <<(const Var& x) {
+    return
+      ArgArrayBase<Var>::template append
+        <typename ArrayTraits<VarArgArray<Var> >::ArgsType>(x);
+  }
+
+  template<class Var>
+  forceinline typename ArrayTraits<VarArgArray<Var> >::ArgsType&
+  VarArgArray<Var>::operator <<(const VarArgArray<Var>& x) {
+    return
+      ArgArrayBase<Var>::template append
+        <typename ArrayTraits<VarArgArray<Var> >::ArgsType>(x);
+  }
+
+  template<class Var>
+  typename ArrayTraits<VarArgArray<Var> >::ArgsType
+  operator +(const VarArgArray<Var>& x, const VarArgArray<Var>& y) {
+    return x.template concat
+      <typename ArrayTraits<VarArgArray<Var> >::ArgsType>(y);
+  }
+
+  template<class Var>
+  typename ArrayTraits<VarArgArray<Var> >::ArgsType
+  operator +(const VarArgArray<Var>& x, const Var& y) {
+    return x.template concat
+      <typename ArrayTraits<VarArgArray<Var> >::ArgsType>(y);    
+  }
+
+  template<class Var>
+  typename ArrayTraits<VarArgArray<Var> >::ArgsType
+  operator +(const Var& x, const VarArgArray<Var>& y) {
+    VarArgArray<Var> xa(1);
+    xa[0] = x;
+    return xa.template concat
+      <typename ArrayTraits<VarArgArray<Var> >::ArgsType>(y);    
+  }
+
   template<class Var>
   forceinline bool
   VarArgArray<Var>::VarLess::operator ()(const Var& a, const Var& b) {
-    return a.var() < b.var();
+    return a.varimp() < b.varimp();
+  }
+
+  template<class Var>
+  forceinline bool
+  VarArgArray<Var>::assigned(void) const {
+    for (int i = n; i--;)
+      if (!a[i].assigned())
+        return false;
+    return true;
   }
 
   template<class Var>
@@ -1210,7 +1695,7 @@ namespace Gecode {
     VarLess vl;
     Support::quicksort<Var,VarLess>(y,n,vl);
     for (int i = n-1; i--; )
-      if (!y[i].assigned() && (y[i+1].var() == y[i].var())) {
+      if (!y[i].assigned() && (y[i+1].varimp() == y[i].varimp())) {
         r.free<Var>(y,n);
         return true;
       }
@@ -1233,7 +1718,7 @@ namespace Gecode {
     VarLess vl;
     Support::quicksort<Var,VarLess>(z,m,vl);
     for (int i = m-1; i--; )
-      if (!z[i].assigned() && (z[i+1].var() == z[i].var())) {
+      if (!z[i].assigned() && (z[i+1].varimp() == z[i].varimp())) {
         r.free<Var>(z,m);
         return true;
       }
@@ -1247,7 +1732,7 @@ namespace Gecode {
     if (y.assigned())
       return false;
     for (int i = n; i--; )
-      if (a[i].var() == y.var())
+      if (a[i].varimp() == y.varimp())
         return true;
     return false;
   }
@@ -1265,10 +1750,10 @@ namespace Gecode {
   template<class Var>
   inline
   VarArray<Var>::VarArray(Space& home, const VarArgArray<Var>& a)
-    : n(a.size()), capacity(a.size()) {
-    if (capacity>0) {
-      x = home.alloc<Var>(capacity);
-      for (int i = capacity; i--; )
+    : n(a.size()) {
+    if (n>0) {
+      x = home.alloc<Var>(n);
+      for (int i=n; i--;)
         x[i] = a[i];
     } else {
       x = NULL;
