@@ -9,8 +9,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-11 22:16:29 +0100 (Thu, 11 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10418 $
+ *     $Date: 2010-06-03 13:46:55 +0200 (Thu, 03 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11014 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -357,7 +357,7 @@ namespace Gecode {
   const Choice*
   ViewValBrancher<ViewSel,ValSel>::choice(Space& home) {
     Pos p = ViewBrancher<ViewSel>::pos(home);
-    typename ValSel::View v(ViewBrancher<ViewSel>::view(p).var());
+    typename ValSel::View v(ViewBrancher<ViewSel>::view(p).varimp());
     typename ValSel::Val val(valsel.val(home,v));
     return new PosValChoice<ViewSel,ValSel>
       (*this,p,
@@ -371,7 +371,7 @@ namespace Gecode {
     const PosValChoice<ViewSel,ValSel>& pvc
       = static_cast<const PosValChoice<ViewSel,ValSel>&>(c);
     typename ValSel::View
-      v(ViewBrancher<ViewSel>::view(pvc.pos()).var());
+      v(ViewBrancher<ViewSel>::view(pvc.pos()).varimp());
     viewsel.commit(home, pvc.viewchoice(), a);
     valsel.commit(home, pvc.valchoice(), a);
     return me_failed(valsel.tell(home,a,v,pvc.val())) ? ES_FAILED : ES_OK;
