@@ -9,8 +9,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-02-05 11:48:53 +0100 (Thu, 05 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8155 $
+ *     $Date: 2009-11-03 11:29:41 +0100 (Tue, 03 Nov 2009) $ by $Author: schulte $
+ *     $Revision: 10026 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,7 +50,7 @@ namespace Gecode {
    * are shared among several objects.
    *
    */
-  template <class T>
+  template<class T>
   class SharedArray : public SharedHandle {
   protected:
     /// Implementation of object for shared arrays
@@ -97,6 +97,8 @@ namespace Gecode {
     void init(int n);
     /// Initialize from shared array \a a (share elements)
     SharedArray(const SharedArray& a);
+    /// Initialize from argument array \a a
+    SharedArray(const ArgArrayBase<T>& a);
 
     /// Access element at position \a i
     T& operator [](int i);
@@ -126,13 +128,13 @@ namespace Gecode {
    * Shared arrays
    *
    */
-  template <class T>
+  template<class T>
   forceinline
   SharedArray<T>::SAO::SAO(int n0) : n(n0) {
     a = (n>0) ? heap.alloc<T>(n) : NULL;
   }
 
-  template <class T>
+  template<class T>
   SharedHandle::Object*
   SharedArray<T>::SAO::copy(void) const {
     SAO* o = new SAO(n);
@@ -141,28 +143,28 @@ namespace Gecode {
     return o;
   }
 
-  template <class T>
+  template<class T>
   SharedArray<T>::SAO::~SAO(void) {
     if (n>0) {
       heap.free<T>(a,n);
     }
   }
 
-  template <class T>
+  template<class T>
   forceinline T&
   SharedArray<T>::SAO::operator [](int i) {
     assert((i>=0) && (i<n));
     return a[i];
   }
 
-  template <class T>
+  template<class T>
   forceinline const T&
   SharedArray<T>::SAO::operator [](int i) const {
     assert((i>=0) && (i<n));
     return a[i];
   }
 
-  template <class T>
+  template<class T>
   forceinline int
   SharedArray<T>::SAO::size(void) const {
     return n;
@@ -170,42 +172,50 @@ namespace Gecode {
 
 
 
-  template <class T>
+  template<class T>
   forceinline
   SharedArray<T>::SharedArray(void) {}
 
-  template <class T>
+  template<class T>
   forceinline
   SharedArray<T>::SharedArray(int n)
     : SharedHandle(new SAO(n)) {}
 
-  template <class T>
+  template<class T>
   forceinline
   SharedArray<T>::SharedArray(const SharedArray<T>& sa)
     : SharedHandle(sa) {}
 
-  template <class T>
+  template<class T>
   forceinline void
   SharedArray<T>::init(int n) {
     assert(object() == NULL);
     object(new SAO(n));
   }
 
-  template <class T>
+  template<class T>
   forceinline T&
   SharedArray<T>::operator [](int i) {
     assert(object() != NULL);
     return (*static_cast<SAO*>(object()))[i];
   }
 
-  template <class T>
+  template<class T>
   forceinline const T&
   SharedArray<T>::operator [](int i) const {
     assert(object() != NULL);
     return (*static_cast<SAO*>(object()))[i];
   }
 
-  template <class T>
+  template<class T>
+  forceinline
+  SharedArray<T>::SharedArray(const ArgArrayBase<T>& a)
+    : SharedHandle(new SAO(a.size())) {
+    for (int i=a.size(); i--; )
+      operator [](i)=a[i];
+  }
+
+  template<class T>
   forceinline int
   SharedArray<T>::size(void) const {
     assert(object() != NULL);
