@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-10-13 16:57:59 +0200 (Tue, 13 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9894 $
+ *     $Date: 2010-06-30 14:31:56 +0200 (Wed, 30 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11134 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,30 +42,43 @@ namespace Gecode {
    * \ingroup TaskVarView
    */
   template<class VarImp>
-  class VarBase {
+  class Var {
   protected:
     /// Pointer to variable implementation
-    VarImp* varimp;
+    VarImp* x;
     /// Default constructor
-    VarBase(void);
-    /// Initialize with variable implementation \a x
-    VarBase(VarImp* x);
+    Var(void);
+    /// Initialize with variable implementation \a y
+    Var(VarImp* y);
   public:
     /// \name Generic variable information
     //@{
     /// Return variable implementation of variable
-    VarImp* var(void) const;
+    VarImp* varimp(void) const;
     /// Return degree (number of subscribed propagators and advisors)
     unsigned int degree(void) const;
     /// Return accumulated failure count (plus degree)
     double afc(void) const;
     //@}
+
+    /// \name Domain tests
+    //@{
+    /// Test whether view is assigned
+    bool assigned(void) const;
+    //@}
+
+    /// \name Cloning
+    //@{
+    /// Update this variable to be a clone of variable \a y
+    void update(Space& home, bool share, Var<VarImp>& y);
+    //@}
+
     /// \name Variable comparison
     //@{
-    /// Test whether view is the same as \a y
-    bool same(const VarBase<VarImp>& y) const;
-    /// Test whether view comes before \a y (arbitrary order)
-    bool before(const VarBase<VarImp>& y) const;
+    /// Test whether variable is the same as \a y
+    bool same(const Var<VarImp>& y) const;
+    /// Test whether variable comes before \a y (arbitrary order)
+    bool before(const Var<VarImp>& y) const;
     //@}
   };
 
@@ -76,36 +89,46 @@ namespace Gecode {
    */
   template<class VarImp>
   forceinline
-  VarBase<VarImp>::VarBase(void)
-    : varimp(NULL) {}
+  Var<VarImp>::Var(void)
+    : x(NULL) {}
   template<class VarImp>
   forceinline
-  VarBase<VarImp>::VarBase(VarImp* x)
-    : varimp(x) {}
+  Var<VarImp>::Var(VarImp* y)
+    : x(y) {}
   template<class VarImp>
   forceinline VarImp*
-  VarBase<VarImp>::var(void) const {
-    return varimp;
+  Var<VarImp>::varimp(void) const {
+    return x;
   }
   template<class VarImp>
   forceinline unsigned int
-  VarBase<VarImp>::degree(void) const {
-    return varimp->degree();
+  Var<VarImp>::degree(void) const {
+    return x->degree();
   }
   template<class VarImp>
   forceinline double
-  VarBase<VarImp>::afc(void) const {
-    return varimp->afc();
+  Var<VarImp>::afc(void) const {
+    return x->afc();
   }
   template<class VarImp>
   forceinline bool
-  VarBase<VarImp>::same(const VarBase<VarImp>& y) const {
-    return var() == y.var();
+  Var<VarImp>::assigned(void) const {
+    return x->assigned();
+  }
+  template<class VarImp>
+  forceinline void
+  Var<VarImp>::update(Space& home, bool share, Var<VarImp>& y) {
+    x = y.x->copy(home,share);
   }
   template<class VarImp>
   forceinline bool
-  VarBase<VarImp>::before(const VarBase<VarImp>& y) const {
-    return var() < y.var();
+  Var<VarImp>::same(const Var<VarImp>& y) const {
+    return varimp() == y.varimp();
+  }
+  template<class VarImp>
+  forceinline bool
+  Var<VarImp>::before(const Var<VarImp>& y) const {
+    return varimp() < y.varimp();
   }
 
 }
