@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2009-11-04 17:06:58 +0100 (Wed, 04 Nov 2009) $ by $Author: tack $
- *     $Revision: 10046 $
+ *     $Date: 2010-06-29 10:39:13 +0200 (Tue, 29 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11118 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,47 +41,27 @@ namespace Gecode {
    * \brief Base-class for constant views
    * \ingroup TaskVarView
    */
-  class ConstViewBase {
+  template<class View>
+  class ConstView {
   public:
+    /// The variable type corresponding to the constant view
+    typedef typename View::VarImpType VarImpType;
     /// \name Generic view information
     //@{
     /// Return degree (number of subscribed propagators and advisors)
     unsigned int degree(void) const;
     /// Return accumulated failure count (plus degree)
     double afc(void) const;
-    /// Return whether this view is derived from a VarViewBase
+    /// Return whether this view is derived from a VarImpView
     static bool varderived(void);
     /// Return dummy variable implementation of view
-    VarImpBase* var(void) const;
+    VarImpType* varimp(void) const;
     //@}
-  };
 
-
-
-  /**
-   * \brief Base-class for variable views
-   * \ingroup TaskVarView
-   */
-  template<class VarImp>
-  class VarViewBase {
-  protected:
-    /// Pointer to variable implementation
-    VarImp* varimp;
-    /// Default constructor
-    VarViewBase(void);
-    /// Initialize with variable implementation x
-    VarViewBase(VarImp* x);
-  public:
-    /// \name Generic view information
+    /// \name Domain tests
     //@{
-    /// Return whether this view is derived from a VarViewBase
-    static bool varderived(void);
-    /// Return variable implementation of view
-    VarImp* var(void) const;
-    /// Return degree (number of subscribed propagators and advisors)
-    unsigned int degree(void) const;
-    /// Return accumulated failure count (plus degree)
-    double afc(void) const;
+    /// Test whether view is assigned
+    bool assigned(void) const;
     //@}
 
     /// \name View-dependent propagator support
@@ -92,8 +72,6 @@ namespace Gecode {
     static ModEvent me(const ModEventDelta& med);
     /// Translate modification event \a me to modification event delta for view
     static ModEventDelta med(ModEvent me);
-    /// Combine modifications events \a me1 and \a me2
-    static ModEvent me_combine(ModEvent me1, ModEvent me2);
     //@}
 
     /// \name Dependencies
@@ -101,11 +79,11 @@ namespace Gecode {
     /**
      * \brief Subscribe propagator \a p with propagation condition \a pc to view
      *
-     * In case \a process is false, the propagator is just subscribed but
-     * not processed for execution (this must be used when creating
+     * In case \a schedule is false, the propagator is just subscribed but
+     * not scheduled for execution (this must be used when creating
      * subscriptions during propagation).
      */
-    void subscribe(Space& home, Propagator& p, PropCond pc, bool process=true);
+    void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
     /// Cancel subscription of propagator \a p with propagation condition \a pc to view
     void cancel(Space& home, Propagator& p, PropCond pc);
     /// Subscribe advisor \a a to view
@@ -113,15 +91,104 @@ namespace Gecode {
     /// Cancel subscription of advisor \a a
     void cancel(Space& home, Advisor& a);
     //@}
+
+    /// \name Delta information for advisors
+    //@{
+    /// Return modification event
+    static ModEvent modevent(const Delta& d);
+    //@}
+
+    /// \name Cloning
+    //@{
+    /// Update this view to be a clone of view \a y
+    void update(Space& home, bool share, ConstView& y);
+    //@}
+  };
+
+
+
+  /**
+   * \brief Base-class for variable implementation views
+   * \ingroup TaskVarView
+   */
+  template<class VarImp>
+  class VarImpView {
+  protected:
+    /// Pointer to variable implementation
+    VarImp* x;
+    /// Default constructor
+    VarImpView(void);
+    /// Initialize with variable implementation \a y
+    VarImpView(VarImp* y);
+  public:
+    /// The variable implementation type corresponding to the view
+    typedef VarImp VarImpType;
+    /// \name Generic view information
+    //@{
+    /// Return whether this view is derived from a VarImpView
+    static bool varderived(void);
+    /// Return variable implementation of view
+    VarImp* varimp(void) const;
+    /// Return degree (number of subscribed propagators and advisors)
+    unsigned int degree(void) const;
+    /// Return accumulated failure count (plus degree)
+    double afc(void) const;
+    //@}
+
+    /// \name Domain tests
+    //@{
+    /// Test whether view is assigned
+    bool assigned(void) const;
+    //@}
+
+    /// \name View-dependent propagator support
+    //@{
+    /// Schedule propagator \a p with modification event \a me
+    static void schedule(Space& home, Propagator& p, ModEvent me);
+    /// Return modification event for view type in \a med
+    static ModEvent me(const ModEventDelta& med);
+    /// Translate modification event \a me to modification event delta for view
+    static ModEventDelta med(ModEvent me);
+    //@}
+
+    /// \name Dependencies
+    //@{
+    /**
+     * \brief Subscribe propagator \a p with propagation condition \a pc to view
+     *
+     * In case \a schedule is false, the propagator is just subscribed but
+     * not scheduled for execution (this must be used when creating
+     * subscriptions during propagation).
+     */
+    void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
+    /// Cancel subscription of propagator \a p with propagation condition \a pc to view
+    void cancel(Space& home, Propagator& p, PropCond pc);
+    /// Subscribe advisor \a a to view
+    void subscribe(Space& home, Advisor& a);
+    /// Cancel subscription of advisor \a a
+    void cancel(Space& home, Advisor& a);
+    //@}
+
+    /// \name Delta information for advisors
+    //@{
+    /// Return modification event
+    static ModEvent modevent(const Delta& d);
+    //@}
+
+    /// \name Cloning
+    //@{
+    /// Update this view to be a clone of view \a y
+    void update(Space& home, bool share, VarImpView<VarImp>& y);
+    //@}
   };
 
   /** \name View comparison
-   *  \relates VarViewBase
+   *  \relates VarImpView
    */
   //@{
   /// Test whether views \a x and \a y are the same
   template<class VarImpA, class VarImpB>
-  bool same(const VarViewBase<VarImpA>& x, const VarViewBase<VarImpB>& y);
+  bool same(const VarImpView<VarImpA>& x, const VarImpView<VarImpB>& y);
   /// Test whether view \a x comes before \a y (arbitrary order)
   template<class ViewA, class ViewB>
   bool before(const ViewA& x, const ViewB& y);
@@ -133,25 +200,23 @@ namespace Gecode {
    * \ingroup TaskVarView
    */
   template<class View>
-  class DerivedViewBase {
+  class DerivedView {
   protected:
     /// View from which this view is derived
-    View view;
+    View x;
     /// Default constructor
-    DerivedViewBase(void);
-    /// Initialize with view x
-    DerivedViewBase(const View& x);
-
+    DerivedView(void);
+    /// Initialize with view \a y
+    DerivedView(const View& y);
   public:
-    /// The variable type belonging to the \a View
-    typedef typename ViewVarImpTraits<View>::VarImp VarImp;
-
+    /// The variable implementation type belonging to the \a View
+    typedef typename View::VarImpType VarImpType;
     /// \name Generic view information
     //@{
-    /// Return whether this view is derived from a VarViewBase
+    /// Return whether this view is derived from a VarImpView
     static bool varderived(void);
     /// Return variable implementation of view
-    VarImp* var(void) const;
+    VarImpType* varimp(void) const;
     /// Return view from which this view is derived
     View base(void) const;
     /// Return degree (number of subscribed propagators)
@@ -159,6 +224,52 @@ namespace Gecode {
     /// Return accumulated failure count (plus degree)
     double afc(void) const;
     //@}
+
+    /// \name Domain tests
+    //@{
+    /// Test whether view is assigned
+    bool assigned(void) const;
+    //@}
+
+    /// \name View-dependent propagator support
+    //@{
+    /// Schedule propagator \a p with modification event \a me
+    static void schedule(Space& home, Propagator& p, ModEvent me);
+    /// Return modification event for view type in \a med
+    static ModEvent me(const ModEventDelta& med);
+    /// Translate modification event \a me to modification event delta for view
+    static ModEventDelta med(ModEvent);
+    //@}
+
+    /// \name Dependencies
+    //@{
+    /**
+     * \brief Subscribe propagator \a p with propagation condition \a pc to view
+     *
+     * In case \a schedule is false, the propagator is just subscribed but
+     * not scheduled for execution (this must be used when creating
+     * subscriptions during propagation).
+     */
+    void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
+    /// Cancel subscription of propagator \a p with propagation condition \a pc to view
+    void cancel(Space& home, Propagator& p, PropCond pc);
+    /// Subscribe advisor \a a to view
+    void subscribe(Space& home, Advisor& a);
+    /// Cancel subscription of advisor \a a
+    void cancel(Space& home, Advisor& a);
+    //@}
+
+    /// \name Delta information for advisors
+    //@{
+    /// Return modification event
+    static ModEvent modevent(const Delta& d);
+    //@}
+
+    /// \name Cloning
+    //@{
+    /// Update this view to be a clone of view \a y
+    void update(Space& home, bool share, DerivedView<View>& y);
+    //@}
   };
 
 
@@ -166,108 +277,130 @@ namespace Gecode {
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
-  bool shared(const ConstViewBase&, const ConstViewBase&);
+  template<class ViewA, class ViewB>
+  bool shared(const ConstView<ViewA>&, const ConstView<ViewB>&);
   /**
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
-  template<class VarImp>
-  bool shared(const VarViewBase<VarImp>&, const ConstViewBase&);
+  template<class VarImp, class View>
+  bool shared(const VarImpView<VarImp>&, const ConstView<View>&);
   /**
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
-  template<class ViewA>
-  bool shared(const DerivedViewBase<ViewA>&, const ConstViewBase&);
+  template<class ViewA, class ViewB>
+  bool shared(const DerivedView<ViewA>&, const ConstView<ViewB>&);
   /**
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
-  template<class VarImp>
-  bool shared(const ConstViewBase&, const VarViewBase<VarImp>&);
+  template<class View, class VarImp>
+  bool shared(const ConstView<View>&, const VarImpView<VarImp>&);
   /**
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
-  template<class ViewA>
-  bool shared(const ConstViewBase&, const DerivedViewBase<ViewA>&);
+  template<class ViewA, class ViewB>
+  bool shared(const ConstView<ViewA>&, const DerivedView<ViewB>&);
   /**
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
   template<class VarImpA, class VarImpB>
-  bool shared(const VarViewBase<VarImpA>&, const VarViewBase<VarImpB>&);
+  bool shared(const VarImpView<VarImpA>&, const VarImpView<VarImpB>&);
   /**
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
   template<class VarImpA, class ViewB>
-  bool shared(const VarViewBase<VarImpA>&, const DerivedViewBase<ViewB>&);
+  bool shared(const VarImpView<VarImpA>&, const DerivedView<ViewB>&);
   /**
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
   template<class ViewA, class VarImpB>
-  bool shared(const DerivedViewBase<ViewA>&, const VarViewBase<VarImpB>&);
+  bool shared(const DerivedView<ViewA>&, const VarImpView<VarImpB>&);
   /**
    * \brief Test whether views share same variable
    * \ingroup TaskVarView
    */
   template<class ViewA, class ViewB>
-  bool shared(const DerivedViewBase<ViewA>&, const DerivedViewBase<ViewB>&);
+  bool shared(const DerivedView<ViewA>&, const DerivedView<ViewB>&);
 
 
-  /// Test whether two views are the same
-  inline
-  bool same(const ConstViewBase&, const ConstViewBase&) {
-    return false;
-  }
-  /// Test whether two views are the same
-  template<class VarImp>
-  bool same(const VarViewBase<VarImp>&, const ConstViewBase&) {
-    return false;
-  }
-  /// Test whether two views are the same
-  template<class ViewA>
-  bool same(const ConstViewBase&, const DerivedViewBase<ViewA>&) {
-    return false;
-  }
-  /// Test whether two views are the same
-  template<class VarImpA, class ViewB>
-  bool same(const VarViewBase<VarImpA>&, const DerivedViewBase<ViewB>&) {
-    return false;
-  }
-  /// Test whether two views are the same
-  template<class ViewA, class VarImpB>
-  bool same(const DerivedViewBase<ViewA>&, const VarViewBase<VarImpB>&) {
-    return false;
-  }
-  /// Test whether two views are the same
-  template<class ViewA, class ViewB>
-  bool same(const DerivedViewBase<ViewA>&, const DerivedViewBase<ViewB>&) {
-    return false;
-  }
-
   /*
    * Constant view: has no variable implementation
    *
    */
+  template<class View>
   forceinline unsigned int
-  ConstViewBase::degree(void) const {
+  ConstView<View>::degree(void) const {
     return 0;
   }
+  template<class View>
   forceinline double
-  ConstViewBase::afc(void) const {
+  ConstView<View>::afc(void) const {
     return 0.0;
   }
+  template<class View>
   forceinline bool
-  ConstViewBase::varderived(void) {
+  ConstView<View>::varderived(void) {
     return false;
   }
-  forceinline VarImpBase*
-  ConstViewBase::var(void) const {
+  template<class View>
+  forceinline typename View::VarImpType*
+  ConstView<View>::varimp(void) const {
     return NULL;
   }
+  template<class View>
+  forceinline bool
+  ConstView<View>::assigned(void) const {
+    return true;
+  }
+  template<class View>
+  forceinline void
+  ConstView<View>::subscribe(Space& home, Propagator& p, PropCond, 
+                             bool schedule) {
+    if (schedule)
+      View::schedule(home,p,ME_GEN_ASSIGNED);
+  }
+  template<class View>
+  forceinline void
+  ConstView<View>::cancel(Space&, Propagator&, PropCond) {
+  }
+  template<class View>
+  forceinline void
+  ConstView<View>::subscribe(Space&, Advisor&) {
+  }
+  template<class View>
+  forceinline void
+  ConstView<View>::cancel(Space&, Advisor&) {
+  }
+  template<class View>
+  forceinline void
+  ConstView<View>::schedule(Space& home, Propagator& p, ModEvent me) {
+    View::schedule(home,p,me);
+  }
+  template<class View>
+  forceinline ModEvent
+  ConstView<View>::me(const ModEventDelta& med) {
+    return View::me(med);
+  }
+  template<class View>
+  forceinline ModEventDelta
+  ConstView<View>::med(ModEvent me) {
+    return View::med(me);
+  }
+  template<class View>
+  forceinline ModEvent
+  ConstView<View>::modevent(const Delta& d) {
+    return ME_GEN_NONE;
+  }
+  template<class View>
+  forceinline void
+  ConstView<View>::update(Space&, bool, ConstView&) {
+  }
 
   /*
    * Variable view: contains a pointer to a variable implementation
@@ -275,83 +408,82 @@ namespace Gecode {
    */
   template<class VarImp>
   forceinline
-  VarViewBase<VarImp>::VarViewBase(void)
-    : varimp(NULL) {}
+  VarImpView<VarImp>::VarImpView(void)
+    : x(NULL) {}
   template<class VarImp>
   forceinline
-  VarViewBase<VarImp>::VarViewBase(VarImp* x)
-    : varimp(x) {}
+  VarImpView<VarImp>::VarImpView(VarImp* y)
+    : x(y) {}
   template<class VarImp>
   forceinline bool
-  VarViewBase<VarImp>::varderived(void) {
+  VarImpView<VarImp>::varderived(void) {
     return true;
   }
   template<class VarImp>
   forceinline VarImp*
-  VarViewBase<VarImp>::var(void) const {
-    return varimp;
+  VarImpView<VarImp>::varimp(void) const {
+    return x;
   }
   template<class VarImp>
   forceinline unsigned int
-  VarViewBase<VarImp>::degree(void) const {
-    return varimp->degree();
+  VarImpView<VarImp>::degree(void) const {
+    return x->degree();
   }
   template<class VarImp>
   forceinline double
-  VarViewBase<VarImp>::afc(void) const {
-    return varimp->afc();
+  VarImpView<VarImp>::afc(void) const {
+    return x->afc();
+  }
+  template<class VarImp>
+  forceinline bool
+  VarImpView<VarImp>::assigned(void) const {
+    return x->assigned();
   }
   template<class VarImp>
   forceinline void
-  VarViewBase<VarImp>::subscribe(Space& home, Propagator& p, PropCond pc,
-                                 bool process) {
-    varimp->subscribe(home,p,pc,process);
+  VarImpView<VarImp>::subscribe(Space& home, Propagator& p, PropCond pc,
+                                bool schedule) {
+    x->subscribe(home,p,pc,schedule);
   }
   template<class VarImp>
   forceinline void
-  VarViewBase<VarImp>::cancel(Space& home, Propagator& p, PropCond pc) {
-    varimp->cancel(home,p,pc);
+  VarImpView<VarImp>::cancel(Space& home, Propagator& p, PropCond pc) {
+    x->cancel(home,p,pc);
   }
   template<class VarImp>
   forceinline void
-  VarViewBase<VarImp>::subscribe(Space& home, Advisor& a) {
-    varimp->subscribe(home,a);
+  VarImpView<VarImp>::subscribe(Space& home, Advisor& a) {
+    x->subscribe(home,a);
   }
   template<class VarImp>
   forceinline void
-  VarViewBase<VarImp>::cancel(Space& home, Advisor& a) {
-    varimp->cancel(home,a);
+  VarImpView<VarImp>::cancel(Space& home, Advisor& a) {
+    x->cancel(home,a);
   }
   template<class VarImp>
   forceinline void
-  VarViewBase<VarImp>::schedule(Space& home, Propagator& p, ModEvent me) {
-    return VarImp::schedule(home,p,me);
+  VarImpView<VarImp>::schedule(Space& home, Propagator& p, ModEvent me) {
+    VarImp::schedule(home,p,me);
   }
   template<class VarImp>
   forceinline ModEvent
-  VarViewBase<VarImp>::me(const ModEventDelta& med) {
+  VarImpView<VarImp>::me(const ModEventDelta& med) {
     return VarImp::me(med);
   }
   template<class VarImp>
   forceinline ModEventDelta
-  VarViewBase<VarImp>::med(ModEvent me) {
+  VarImpView<VarImp>::med(ModEvent me) {
     return VarImp::med(me);
   }
   template<class VarImp>
   forceinline ModEvent
-  VarViewBase<VarImp>::me_combine(ModEvent me1, ModEvent me2) {
-    return VarImp::me_combine(me1,me2);
+  VarImpView<VarImp>::modevent(const Delta& d) {
+    return VarImp::modevent(d);
   }
-
   template<class VarImp>
-  forceinline bool
-  same(const VarViewBase<VarImp>& x, const VarViewBase<VarImp>& y) {
-    return x.var() == y.var();
-  }
-  template<class ViewA, class ViewB>
-  forceinline bool
-  before(const ViewA& x, const ViewB& y) {
-    return x.var() < y.var();
+  forceinline void
+  VarImpView<VarImp>::update(Space& home, bool share, VarImpView<VarImp>& y) {
+    x = y.x->copy(home,share);
   }
 
   /*
@@ -361,40 +493,153 @@ namespace Gecode {
 
   template<class View>
   forceinline
-  DerivedViewBase<View>::DerivedViewBase(void) {}
+  DerivedView<View>::DerivedView(void) {}
 
   template<class View>
   forceinline
-  DerivedViewBase<View>::DerivedViewBase(const View& x)
-    : view(x) {}
+  DerivedView<View>::DerivedView(const View& y)
+    : x(y) {}
 
   template<class View>
   forceinline bool
-  DerivedViewBase<View>::varderived(void) {
+  DerivedView<View>::varderived(void) {
     return View::varderived();
   }
 
   template<class View>
-  forceinline typename ViewVarImpTraits<View>::VarImp*
-  DerivedViewBase<View>::var(void) const {
-    return view.var();
+  forceinline typename View::VarImpType*
+  DerivedView<View>::varimp(void) const {
+    return x.varimp();
   }
 
   template<class View>
   forceinline View
-  DerivedViewBase<View>::base(void) const {
-    return view;
+  DerivedView<View>::base(void) const {
+    return x;
   }
 
   template<class View>
   forceinline unsigned int
-  DerivedViewBase<View>::degree(void) const {
-    return view.degree();
+  DerivedView<View>::degree(void) const {
+    return x.degree();
   }
   template<class View>
   forceinline double
-  DerivedViewBase<View>::afc(void) const {
-    return view.afc();
+  DerivedView<View>::afc(void) const {
+    return x.afc();
+  }
+  template<class View>
+  forceinline bool
+  DerivedView<View>::assigned(void) const {
+    return x.assigned();
+  }
+
+  template<class View>
+  forceinline void
+  DerivedView<View>::schedule(Space& home, Propagator& p, ModEvent me) {
+    return View::schedule(home,p,me);
+  }
+  template<class View>
+  forceinline ModEvent
+  DerivedView<View>::me(const ModEventDelta& med) {
+    return View::me(med);
+  }
+  template<class View>
+  forceinline ModEventDelta
+  DerivedView<View>::med(ModEvent me) {
+    return View::med(me);
+  }
+
+  template<class View>
+  forceinline void
+  DerivedView<View>::subscribe(Space& home, Propagator& p, PropCond pc,
+                               bool schedule) {
+    x.subscribe(home,p,pc,schedule);
+  }
+  template<class View>
+  forceinline void
+  DerivedView<View>::cancel(Space& home, Propagator& p, PropCond pc) {
+    x.cancel(home,p,pc);
+  }
+  template<class View>
+  forceinline void
+  DerivedView<View>::subscribe(Space& home, Advisor& a) {
+    x.subscribe(home,a);
+  }
+  template<class View>
+  forceinline void
+  DerivedView<View>::cancel(Space& home, Advisor& a) {
+    x.cancel(home,a);
+  }
+  template<class View>
+  forceinline ModEvent
+  DerivedView<View>::modevent(const Delta& d) {
+    return View::modevent(d);
+  }
+  template<class View>
+  forceinline void
+  DerivedView<View>::update(Space& home, bool share, DerivedView<View>& y) {
+    x.update(home,share,y.x);
+  }
+
+
+  /*
+   * Tests whether two views are the same
+   *
+   */
+
+  /// Test whether two views are the same
+  template<class ViewA, class ViewB>
+  forceinline bool 
+  same(const ConstView<ViewA>&, const ConstView<ViewB>&) {
+    return false;
+  }
+  /// Test whether two views are the same
+  template<class VarImp, class View>
+  forceinline bool 
+  same(const VarImpView<VarImp>&, const ConstView<View>&) {
+    return false;
+  }
+  /// Test whether two views are the same
+  template<class ViewA, class ViewB>
+  forceinline bool 
+  same(const ConstView<ViewA>&, const DerivedView<ViewB>&) {
+    return false;
+  }
+  /// Test whether two views are the same
+  template<class VarImpA, class ViewB>
+  forceinline bool 
+  same(const VarImpView<VarImpA>&, const DerivedView<ViewB>&) {
+    return false;
+  }
+  /// Test whether two views are the same
+  template<class ViewA, class VarImpB>
+  forceinline bool 
+  same(const DerivedView<ViewA>&, const VarImpView<VarImpB>&) {
+    return false;
+  }
+  /// Test whether two views are the same
+  template<class VarImp>
+  forceinline bool
+  same(const VarImpView<VarImp>& x, const VarImpView<VarImp>& y) {
+    return x.varimp() == y.varimp();
+  }
+  /// Test whether two views are the same
+  template<class ViewA, class ViewB>
+  forceinline bool 
+  same(const DerivedView<ViewA>& x, const DerivedView<ViewB>& y) {
+    return same(x.base(),y.base());
+  }
+
+
+  /*
+   * Tests whether one view is before the other
+   *
+   */
+  template<class ViewA, class ViewB>
+  forceinline bool
+  before(const ViewA& x, const ViewB& y) {
+    return x.varimp() < y.varimp();
   }
 
 
@@ -403,61 +648,57 @@ namespace Gecode {
    *
    */
 
+  template<class ViewA, class ViewB>
   forceinline bool
-  shared(const ConstViewBase&, const ConstViewBase&) {
+  shared(const ConstView<ViewA>&, const ConstView<ViewB>&) {
     return false;
   }
-
-  template<class VarImp>
+  template<class VarImp, class View>
   forceinline bool
-  shared(const VarViewBase<VarImp>&, const ConstViewBase&) {
+  shared(const VarImpView<VarImp>&, const ConstView<View>&) {
     return false;
   }
-
-  template<class View>
-  forceinline bool
-  shared(const DerivedViewBase<View>&, const ConstViewBase&) {
-    return false;
-  }
-
-  template<class VarImp>
-  forceinline bool
-  shared(const ConstViewBase&, const VarViewBase<VarImp>&) {
-    return false;
-  }
-
-  template<class View>
-  forceinline bool
-  shared(const ConstViewBase&, const DerivedViewBase<View>&) {
-    return false;
-  }
-
-  template<class VarImpA, class VarImpB>
-  forceinline bool
-  shared(const VarViewBase<VarImpA>& x, const VarViewBase<VarImpB>& y) {
-    return (static_cast<VarImpBase*>(x.var()) ==
-            static_cast<VarImpBase*>(y.var()));
-  }
-  template<class VarImpA, class ViewB>
-  forceinline bool
-  shared(const VarViewBase<VarImpA>& x, const DerivedViewBase<ViewB>& y) {
-    return (ViewB::varderived() &&
-            static_cast<VarImpBase*>(x.var()) ==
-            static_cast<VarImpBase*>(y.var()));
-  }
-  template<class ViewA, class VarImpB>
-  forceinline bool
-  shared(const DerivedViewBase<ViewA>& x, const VarViewBase<VarImpB>& y) {
-    return (ViewA::varderived() &&
-            static_cast<VarImpBase*>(x.var()) ==
-            static_cast<VarImpBase*>(y.var()));
-  }
   template<class ViewA, class ViewB>
   forceinline bool
-  shared(const DerivedViewBase<ViewA>& x, const DerivedViewBase<ViewB>& y) {
+  shared(const DerivedView<ViewA>&, const ConstView<ViewB>&) {
+    return false;
+  }
+  template<class View, class VarImp>
+  forceinline bool
+  shared(const ConstView<View>&, const VarImpView<VarImp>&) {
+    return false;
+  }
+  template<class ViewA, class ViewB>
+  forceinline bool
+  shared(const ConstView<ViewA>&, const DerivedView<ViewB>&) {
+    return false;
+  }
+  template<class VarImpA, class VarImpB>
+  forceinline bool
+  shared(const VarImpView<VarImpA>& x, const VarImpView<VarImpB>& y) {
+    return (static_cast<VarImpBase*>(x.varimp()) ==
+            static_cast<VarImpBase*>(y.varimp()));
+  }
+  template<class VarImpA, class ViewB>
+  forceinline bool
+  shared(const VarImpView<VarImpA>& x, const DerivedView<ViewB>& y) {
+    return (ViewB::varderived() &&
+            static_cast<VarImpBase*>(x.varimp()) ==
+            static_cast<VarImpBase*>(y.varimp()));
+  }
+  template<class ViewA, class VarImpB>
+  forceinline bool
+  shared(const DerivedView<ViewA>& x, const VarImpView<VarImpB>& y) {
+    return (ViewA::varderived() &&
+            static_cast<VarImpBase*>(x.varimp()) ==
+            static_cast<VarImpBase*>(y.varimp()));
+  }
+  template<class ViewA, class ViewB>
+  forceinline bool
+  shared(const DerivedView<ViewA>& x, const DerivedView<ViewB>& y) {
     return (ViewA::varderived() && ViewB::varderived() &&
-            static_cast<VarImpBase*>(x.var()) ==
-            static_cast<VarImpBase*>(y.var()));
+            static_cast<VarImpBase*>(x.varimp()) ==
+            static_cast<VarImpBase*>(y.varimp()));
   }
 
 }
