@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2010-02-03 11:13:34 +0100 (Wed, 03 Feb 2010) $ by $Author: schulte $
- *     $Revision: 10262 $
+ *     $Date: 2010-07-16 10:51:05 +0200 (Fri, 16 Jul 2010) $ by $Author: tack $
+ *     $Revision: 11208 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -70,8 +70,8 @@ namespace Gecode {
   forceinline
   BoolExpr::BoolExpr(const BoolExpr& l, NodeType t, const BoolExpr& r)
     : n(new Node) {
-    unsigned int ls = ((l.n->t == t) || (l.n->t == NT_VAR)) ? l.n->same : 1;
-    unsigned int rs = ((r.n->t == t) || (r.n->t == NT_VAR)) ? r.n->same : 1;
+    int ls = ((l.n->t == t) || (l.n->t == NT_VAR)) ? l.n->same : 1;
+    int rs = ((r.n->t == t) || (r.n->t == NT_VAR)) ? r.n->same : 1;
     n->same = ls+rs;
     n->t    = t;
     n->l    = l.n;
@@ -107,16 +107,38 @@ namespace Gecode {
     n->rl   = rl;
   }
 
-  forceinline BoolVar
-  BoolExpr::post(Home home, IntConLevel icl) const {
-    Region r(home);
-    return NNF::nnf(r,n,false)->post(home,icl);
+#ifdef GECODE_HAS_SET_VARS
+  forceinline
+  BoolExpr::BoolExpr(const SetRel& rs)
+    : n(new Node) {
+    n->same = 1;
+    n->t    = NT_RSET;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->rs   = rs;
   }
 
-  forceinline void
-  BoolExpr::post(Home home, bool t, IntConLevel icl) const {
+  forceinline
+  BoolExpr::BoolExpr(const SetCmpRel& rs)
+    : n(new Node) {
+    n->same = 1;
+    n->t    = NT_RSET;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->rs   = rs;
+  }
+#endif
+
+  inline BoolVar
+  BoolExpr::expr(Home home, IntConLevel icl) const {
     Region r(home);
-    return NNF::nnf(r,n,false)->post(home,t,icl);
+    return NNF::nnf(r,n,false)->expr(home,icl);
+  }
+
+  inline void
+  BoolExpr::rel(Home home, IntConLevel icl) const {
+    Region r(home);
+    return NNF::nnf(r,n,false)->rel(home,icl);
   }
 
 }
