@@ -10,8 +10,8 @@
  *     Olof Sivertsson <olof@olofsivertsson.com>
  *
  *  Last modified:
- *     $Date: 2009-10-13 21:19:13 +0200 (Tue, 13 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9898 $
+ *     $Date: 2010-05-15 16:19:43 +0200 (Sat, 15 May 2010) $ by $Author: schulte $
+ *     $Revision: 10954 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,15 +44,16 @@ namespace Gecode {
 
   template<class A>
   inline
-  Matrix<A>::Slice::Slice(Matrix<A>& a,
-                          int fc, int tc, int fr, int tr)
+  Slice<A>::Slice(const Matrix<A>& a, int fc, int tc, int fr, int tr)
     : _r(0), _fc(fc), _tc(tc), _fr(fr), _tr(tr) {
     if (tc > a.width() || tr > a.height())
-      throw MiniModel::ArgumentOutOfRange("Matrix::Slice::Slice");
-    if (fc >= tc || fr >= tr)
-      throw MiniModel::ArgumentOutOfRange("Matrix::Slice::Slice");
+      throw MiniModel::ArgumentOutOfRange("Slice::Slice");
+    if (fc >= tc || fr >= tr) {
+      _fc=0; _tc=0; _fr=0; _tr=0;
+      return;
+    }
 
-    _r = args_type((tc-fc)*(tr-fr));
+    _r = ArgsType((tc-fc)*(tr-fr));
 
     int i = 0;
     for (int h = fr; h < tr; h++)
@@ -61,8 +62,8 @@ namespace Gecode {
   }
 
   template<class A>
-  typename Matrix<A>::Slice&
-  Matrix<A>::Slice::reverse(void) {
+  Slice<A>&
+  Slice<A>::reverse(void) {
     for (int i = 0; i < _r.size()/2; i++)
       std::swap(_r[i], _r[_r.size()-i-1]);
     return *this;
@@ -70,15 +71,60 @@ namespace Gecode {
 
   template<class A>
   forceinline
-  Matrix<A>::Slice::operator typename Matrix<A>::args_type(void) {
+  Slice<A>::operator ArgsType(void) {
     return _r;
   }
   template<class A>
   forceinline
-  Matrix<A>::Slice::operator Matrix<typename Matrix<A>::args_type>(void) {
-    return Matrix<args_type>(_r, _tc-_fc, _tr-_fr);
+  Slice<A>::operator Matrix<typename Slice<A>::ArgsType>(void) {
+    return Matrix<ArgsType>(_r, _tc-_fc, _tr-_fr);
+  }
+  template<class A>
+  forceinline
+  Slice<A>::operator const typename Slice<A>::ArgsType(void) const {
+    return _r;
+  }
+  template<class A>
+  forceinline
+  Slice<A>::operator const Matrix<typename Slice<A>::ArgsType>(void) const {
+    return Matrix<ArgsType>(_r, _tc-_fc, _tr-_fr);
   }
 
+  template<class A>
+  typename Slice<A>::ArgsType
+  operator+(const Slice<A>& x, const Slice<A>& y) {
+    typename Slice<A>::ArgsType xx = x;
+    typename Slice<A>::ArgsType yy = y;
+    return xx+yy;
+  }
+
+  template<class A>
+  typename Slice<A>::ArgsType
+  operator+(const Slice<A>& x, const typename ArrayTraits<A>::ArgsType& y) {
+    typename Slice<A>::ArgsType xx = x;
+    return xx+y;
+  }
+
+  template<class A>
+  typename Slice<A>::ArgsType
+  operator+(const typename ArrayTraits<A>::ArgsType& x, const Slice<A>& y) {
+    typename Slice<A>::ArgsType yy = y;
+    return x+yy;
+  }
+
+  template<class A>
+  typename Slice<A>::ArgsType
+  operator+(const Slice<A>& x, const typename ArrayTraits<A>::ValueType& y) {
+    typename Slice<A>::ArgsType xx = x;
+    return xx+y;
+  }
+
+  template<class A>
+  typename Slice<A>::ArgsType
+  operator+(const typename ArrayTraits<A>::ValueType& x, const Slice<A>& y) {
+    typename Slice<A>::ArgsType yy = y;
+    return x+yy;
+  }
 
   template<class A>
   forceinline
@@ -103,13 +149,13 @@ namespace Gecode {
   forceinline int
   Matrix<A>::height(void) const { return _h; }
   template<class A>
-  inline typename Matrix<A>::args_type const
+  inline typename Matrix<A>::ArgsType const
   Matrix<A>::get_array(void) const {
-    return args_type(_a);
+    return ArgsType(_a);
   }
 
   template<class A>
-  forceinline typename Matrix<A>::value_type&
+  forceinline typename Matrix<A>::ValueType&
   Matrix<A>::operator ()(int c, int r) {
     if ((c >= _w) || (r >= _h))
       throw MiniModel::ArgumentOutOfRange("Matrix::operator ()");
@@ -117,23 +163,50 @@ namespace Gecode {
   }
 
   template<class A>
-  forceinline typename Matrix<A>::Slice
-  Matrix<A>::slice(int fc, int tc, int fr, int tr) {
-    return Slice(*this, fc, tc, fr, tr);
+  forceinline const typename Matrix<A>::ValueType&
+  Matrix<A>::operator ()(int c, int r) const {
+    if ((c >= _w) || (r >= _h))
+      throw MiniModel::ArgumentOutOfRange("Matrix::operator ()");
+    return _a[r*_w + c];
   }
 
   template<class A>
-  forceinline typename Matrix<A>::Slice
-  Matrix<A>::row(int r) {
+  forceinline Slice<A>
+  Matrix<A>::slice(int fc, int tc, int fr, int tr) const {
+    return Slice<A>(*this, fc, tc, fr, tr);
+  }
+
+  template<class A>
+  forceinline Slice<A>
+  Matrix<A>::row(int r) const {
     return slice(0, width(), r, r+1);
   }
 
   template<class A>
-  forceinline typename Matrix<A>::Slice
-  Matrix<A>::col(int c) {
+  forceinline Slice<A>
+  Matrix<A>::col(int c) const {
     return slice(c, c+1, 0, height());
   }
 
+  template<class Char, class Traits, class A>
+  std::basic_ostream<Char,Traits>&
+  operator <<(std::basic_ostream<Char,Traits>& os, const Matrix<A>& m) {
+    std::basic_ostringstream<Char,Traits> s;
+    s.copyfmt(os); s.width(0);
+    for (int i=0; i<m.height(); i++) {
+      for (int j=0; j<m.width(); j++) {
+        s << m(j,i) << "\t";
+      }
+      s << std::endl;
+    }
+    return os << s.str();
+  }
+
+  template<class Char, class Traits, class A>
+  std::basic_ostream<Char,Traits>&
+  operator <<(std::basic_ostream<Char,Traits>& os, const Slice<A>& s) {
+    return os << static_cast<typename Slice<A>::ArgsType>(s);
+  }
 
   forceinline void
   element(Home home, const Matrix<IntArgs>& m, IntVar x, IntVar y,  
