@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2010-02-12 14:34:51 +0100 (Fri, 12 Feb 2010) $ by $Author: schulte $
- *     $Revision: 10272 $
+ *     $Date: 2010-05-27 13:09:22 +0200 (Thu, 27 May 2010) $ by $Author: tack $
+ *     $Revision: 10977 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -60,6 +60,16 @@ namespace Gecode { namespace Scheduling {
   FwdToBwd<TaskView>::lct(void) const {
     return -TaskView::est();
   }
+  template<class TaskView>
+  forceinline int
+  FwdToBwd<TaskView>::pmin(void) const {
+    return TaskView::pmin();
+  }
+  template<class TaskView>
+  forceinline int
+  FwdToBwd<TaskView>::pmax(void) const {
+    return TaskView::pmax();
+  }
 
   template<class TaskView>
   forceinline ModEvent 
