@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2010-02-15 22:02:53 +0100 (Mon, 15 Feb 2010) $ by $Author: schulte $
- *     $Revision: 10285 $
+ *     $Date: 2010-06-03 13:11:11 +0200 (Thu, 03 Jun 2010) $ by $Author: tack $
+ *     $Revision: 11013 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,6 +43,18 @@ namespace Gecode { namespace Scheduling {
     return (x == -Int::Limits::infinity) ? x : x+y;
   }
 
+  forceinline double 
+  plus(double x, double y) {
+    assert(y != -Int::Limits::double_infinity);
+    return (x == -Int::Limits::double_infinity) ? x : x+y;
+  }
+
+  forceinline double 
+  div(double x, double y) {
+    assert(y != -Int::Limits::double_infinity);
+    return (x == -Int::Limits::double_infinity) ? x : x / y;
+  }
+
   template<class TaskView, class Node>
   forceinline int 
   TaskTree<TaskView,Node>::n_inner(void) const {
@@ -62,7 +74,7 @@ namespace Gecode { namespace Scheduling {
   template<class TaskView, class Node>
   forceinline bool 
   TaskTree<TaskView,Node>::n_leaf(int i) const {
-    return i > n_inner();
+    return i >= n_inner();
   }
   template<class TaskView, class Node>
   forceinline int 
@@ -152,6 +164,17 @@ namespace Gecode { namespace Scheduling {
         _leaf[i] += fst;
   }
 
+  template<class TaskView, class Node> template<class Node2>
+  forceinline
+  TaskTree<TaskView,Node>::TaskTree(Region& r, 
+                                    const TaskTree<TaskView,Node2>& t)
+    : tasks(t.tasks), 
+      node(r.alloc<Node>(n_nodes())),
+      _leaf(r.alloc<int>(tasks.size())) {
+    for (int i=tasks.size(); i--; )
+      _leaf[i] = t._leaf[i];
+  }
+
 }}
 
 // STATISTICS: scheduling-prop
