@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2009-05-12 14:35:52 +0200 (Tue, 12 May 2009) $ by $Author: schulte $
- *     $Revision: 9065 $
+ *     $Date: 2009-08-26 21:10:00 +0200 (Wed, 26 Aug 2009) $ by $Author: schulte $
+ *     $Revision: 9632 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -35,6 +35,10 @@
  *
  */
 
+#include <gecode/support.hh>
+
+#ifdef GECODE_HAS_THREADS
+
 #include <gecode/search/parallel/dfs.hh>
 
 namespace Gecode { namespace Search { namespace Parallel {
@@ -108,8 +112,8 @@ namespace Gecode { namespace Search { namespace Parallel {
                 break;
               case SS_SOLVED:
                 {
-                  // Deletes all pending branchings
-                  (void) cur->description();
+                  // Deletes all pending branchers
+                  (void) cur->choice();
                   Space* s = cur->clone(false);
                   delete cur;
                   cur = NULL;
@@ -128,9 +132,9 @@ namespace Gecode { namespace Search { namespace Parallel {
                     c = NULL;
                     d++;
                   }
-                  const BranchingDesc* desc = path.push(*this,cur,c);
-                  Worker::push(c,desc);
-                  cur->commit(*desc,0);
+                  const Choice* ch = path.push(*this,cur,c);
+                  Worker::push(c,ch);
+                  cur->commit(*ch,0);
                   m.release();
                 }
                 break;
@@ -167,4 +171,6 @@ namespace Gecode { namespace Search { namespace Parallel {
 
 }}}
 
+#endif
+
 // STATISTICS: search-parallel
