@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-11 22:16:29 +0100 (Thu, 11 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10418 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,65 +50,57 @@ namespace Gecode {
     case SET_ASSIGN_MIN_INC:
       {
         Branch::AssignValMin<true> a(home,o_vals);
-        (void) new (home) ViewValBrancher
-          <ViewSelNone<SetView>,Branch::AssignValMin<true> >
-          (home,xv,v,a);
+        ViewValBrancher<ViewSelNone<SetView>,Branch::AssignValMin<true> >
+          ::post(home,xv,v,a);
       }
       break;
     case SET_ASSIGN_MIN_EXC:
       {
         Branch::AssignValMin<false> a(home,o_vals);
-        (void) new (home) ViewValBrancher
-          <ViewSelNone<SetView>,Branch::AssignValMin<false> >
-          (home,xv,v,a);
+        ViewValBrancher<ViewSelNone<SetView>,Branch::AssignValMin<false> >
+          ::post(home,xv,v,a);
       }
       break;
     case SET_ASSIGN_MED_INC:
       {
         Branch::AssignValMed<true> a(home,o_vals);
-        (void) new (home) ViewValBrancher
-          <ViewSelNone<SetView>,Branch::AssignValMed<true> >
-          (home,xv,v,a);
+        ViewValBrancher<ViewSelNone<SetView>,Branch::AssignValMed<true> >
+          ::post(home,xv,v,a);
       }
       break;
     case SET_ASSIGN_MED_EXC:
       {
         Branch::AssignValMed<false> a(home,o_vals);
-        (void) new (home) ViewValBrancher
-          <ViewSelNone<SetView>,Branch::AssignValMed<false> >
-          (home,xv,v,a);
+        ViewValBrancher<ViewSelNone<SetView>,Branch::AssignValMed<false> >
+          ::post(home,xv,v,a);
       }
       break;
     case SET_ASSIGN_MAX_INC:
       {
         Branch::AssignValMax<true> a(home,o_vals);
-        (void) new (home) ViewValBrancher
-          <ViewSelNone<SetView>,Branch::AssignValMax<true> >
-          (home,xv,v,a);
+        ViewValBrancher<ViewSelNone<SetView>,Branch::AssignValMax<true> >
+          ::post(home,xv,v,a);
       }
       break;
     case SET_ASSIGN_MAX_EXC:
       {
         Branch::AssignValMax<false> a(home,o_vals);
-        (void) new (home) ViewValBrancher
-          <ViewSelNone<SetView>,Branch::AssignValMax<false> >
-          (home,xv,v,a);
+        ViewValBrancher<ViewSelNone<SetView>,Branch::AssignValMax<false> >
+          ::post(home,xv,v,a);
       }
       break;
     case SET_ASSIGN_RND_INC:
       {
         Branch::AssignValRnd<true> a(home,o_vals);
-        (void) new (home) ViewValBrancher
-          <ViewSelNone<SetView>,Branch::AssignValRnd<true> >
-          (home,xv,v,a);
+        ViewValBrancher<ViewSelNone<SetView>,Branch::AssignValRnd<true> >
+          ::post(home,xv,v,a);
       }
       break;
     case SET_ASSIGN_RND_EXC:
       {
         Branch::AssignValRnd<false> a(home,o_vals);
-        (void) new (home) ViewValBrancher
-          <ViewSelNone<SetView>,Branch::AssignValRnd<false> >
-          (home,xv,v,a);
+        ViewValBrancher<ViewSelNone<SetView>,Branch::AssignValRnd<false> >
+          ::post(home,xv,v,a);
       }
       break;
     default:
