@@ -11,8 +11,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,14 +50,14 @@ namespace Gecode {
     Set::Limits::check(j, "Set::cardinality");
     if (home.failed()) return;
     Set::SetView _x(x);
-    GECODE_ME_FAIL(home,_x.cardMin(home, i));
-    GECODE_ME_FAIL(home,_x.cardMax(home, j));
+    GECODE_ME_FAIL(_x.cardMin(home, i));
+    GECODE_ME_FAIL(_x.cardMax(home, j));
   }
 
   void
   cardinality(Home home, SetVar s, IntVar x) {
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Set::Int::Card<Set::SetView>::post(home,s, x));
+    GECODE_ES_FAIL(Set::Int::Card<Set::SetView>::post(home,s, x));
   }
 
 }
