@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -80,9 +80,8 @@ namespace Gecode { namespace Set { namespace Element {
   }
 
   template<class SView, class RView>
-  size_t
+  forceinline size_t
   ElementDisjoint<SView,RView>::dispose(Space& home) {
-    assert(!home.failed());
     x1.cancel(home,*this, PC_SET_ANY);
     iv.cancel(home,*this,PC_SET_ANY);
     (void) Propagator::dispose(home);
@@ -188,7 +187,7 @@ namespace Gecode { namespace Set { namespace Element {
 
       if (x1.cardMax()==0) {
         // Selector is empty, we're done
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
 
       {
@@ -314,7 +313,7 @@ namespace Gecode { namespace Set { namespace Element {
     if (!x1.assigned())
       allAssigned = false;
 
-    return allAssigned ? ES_SUBSUMED(*this,home) : ES_FIX;
+    return allAssigned ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 
