@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11192 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -268,7 +268,7 @@ namespace Gecode { namespace Set { namespace Element {
 
     // Test whether we determined x1 without determining x0
     if (x1.assigned() && !x0.assigned()) {
-      int ubsize = x1.lubSize();
+      int ubsize = static_cast<int>(x1.lubSize());
       if (ubsize > 2) {
         assert(ubsize==n);
         ViewArray<SView> is(home,ubsize);
