@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 10:56:06 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9902 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -69,7 +69,7 @@ namespace Gecode { namespace Set { namespace Element {
   }
 
   template<class SView, class RView>
-  size_t
+  forceinline size_t
   ElementUnionConst<SView,RView>::dispose(Space& home) {
     home.ignore(*this,AP_DISPOSE);
     if (!home.failed()) {
@@ -213,7 +213,7 @@ namespace Gecode { namespace Set { namespace Element {
             before[i].dispose(home);
         selectedInter.dispose(home);
         sofarBefore.dispose(home);
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
 
       if (x1.cardMin() > 0) {
@@ -278,7 +278,7 @@ namespace Gecode { namespace Set { namespace Element {
     } while (loopVar);
 
     if (x0.assigned() || x1.assigned()) {
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     return ES_FIX;
