@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,14 +43,14 @@ namespace Gecode {
   void
   wait(Home home, SetVar x, void (*c)(Space& home)) {
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Kernel::UnaryWait<Set::SetView>::post(home,x,c));
+    GECODE_ES_FAIL(Kernel::UnaryWait<Set::SetView>::post(home,x,c));
   }
 
   void
   wait(Home home, const SetVarArgs& x, void (*c)(Space& home)) {
     if (home.failed()) return;
     ViewArray<Set::SetView> xv(home,x);
-    GECODE_ES_FAIL(home,Kernel::NaryWait<Set::SetView>::post(home,xv,c));
+    GECODE_ES_FAIL(Kernel::NaryWait<Set::SetView>::post(home,xv,c));
   }
 
 }
