@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11192 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -266,7 +266,7 @@ namespace Gecode { namespace Set { namespace Int {
       Support::quicksort<int>(currentWeights, size, il);
 
       // The maximum number of elements that can still be added to x
-      int delta = std::min(x.unknownSize(), x.cardMax() - x.glbSize());
+      int delta = static_cast<int>(std::min(x.unknownSize(), x.cardMax() - x.glbSize()));
 
       // The weight of the elements already in x
       GlbRanges<View> glb(x);
