@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -172,7 +172,7 @@ namespace Gecode { namespace Set { namespace RelOp {
       if (x2.cardMax() == 0) {
         GECODE_ME_CHECK( x0.cardMax(home, 0) );
         GECODE_ME_CHECK( x1.cardMax(home, 0) );
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
 
       if (x0.cardMax() == 0)
@@ -183,10 +183,10 @@ namespace Gecode { namespace Set { namespace RelOp {
     } while(modified);
 
     if (shared(x0,x1,x2)) {
-      return (x0ass && x1ass && x2ass) ? ES_SUBSUMED(*this,home) : ES_NOFIX;
+      return (x0ass && x1ass && x2ass) ? home.ES_SUBSUMED(*this) : ES_NOFIX;
     } else {
       if (x0ass && x1ass && x2ass)
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       if (x0ass != x0.assigned() ||
           x1ass != x1.assigned() ||
           x2ass != x2.assigned()) {
@@ -308,7 +308,7 @@ namespace Gecode { namespace Set { namespace RelOp {
       BndSetRanges all2(unionOfDets);
       GECODE_ME_CHECK( y.includeI(home,all2) );
       unionOfDets.dispose(home);
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     return shared ? ES_NOFIX : ES_FIX;
