@@ -12,8 +12,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -68,9 +68,8 @@ namespace Gecode { namespace Set { namespace Rel {
   }
 
   template<class View0, class View1>
-  size_t
+  forceinline size_t
   ReEq<View0,View1>::dispose(Space& home) {
-    assert(!home.failed());
     b.cancel(home,*this, Gecode::Int::PC_INT_VAL);
     x0.cancel(home,*this, PC_SET_ANY);
     x1.cancel(home,*this, PC_SET_ANY);
@@ -108,15 +107,15 @@ namespace Gecode { namespace Set { namespace Rel {
         if (x0lb.min() != x1lb.min() ||
             x0lb.max() != x1lb.max()) {
           GECODE_ME_CHECK(b.zero_none(home));
-          return ES_SUBSUMED(*this,home);
+          return home.ES_SUBSUMED(*this);
         }
       }
       if (!x0lb() && !x1lb()) {
         GECODE_ME_CHECK(b.one_none(home));
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       } else {
         GECODE_ME_CHECK(b.zero_none(home));
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
     }
 
@@ -124,7 +123,7 @@ namespace Gecode { namespace Set { namespace Rel {
     if (x0.cardMin() > x1.cardMax() ||
         x1.cardMin() > x0.cardMax()) {
       GECODE_ME_CHECK(b.zero_none(home));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     // check glb(x0) subset lub(x1)
@@ -133,7 +132,7 @@ namespace Gecode { namespace Set { namespace Rel {
     Iter::Ranges::Diff<GlbRanges<View0>, LubRanges<View1> > diff1(x0lb, x1ub);
     if ( diff1() ) {
       GECODE_ME_CHECK(b.zero_none(home));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     // check glb(x1) subset lub(x0)
@@ -142,7 +141,7 @@ namespace Gecode { namespace Set { namespace Rel {
     Iter::Ranges::Diff<GlbRanges<View1>, LubRanges<View0> > diff2(x1lb, x0ub);
     if ( diff2() ) {
       GECODE_ME_CHECK(b.zero_none(home));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     return ES_FIX;
