@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -65,9 +65,8 @@ namespace Gecode { namespace Set { namespace Rel {
   }
 
   template<class View0, class View1>
-  size_t
+  forceinline size_t
   ReSubset<View0,View1>::dispose(Space& home) {
-    assert(!home.failed());
     b.cancel(home,*this, Gecode::Int::PC_INT_VAL);
     x0.cancel(home,*this, PC_SET_ANY);
     x1.cancel(home,*this, PC_SET_ANY);
@@ -100,7 +99,7 @@ namespace Gecode { namespace Set { namespace Rel {
     // check whether cardinalities still allow subset
     if (x0.cardMin() > x1.cardMax()) {
       GECODE_ME_CHECK(b.zero_none(home));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     // check lub(x0) subset glb(x1)
@@ -110,7 +109,7 @@ namespace Gecode { namespace Set { namespace Rel {
       Iter::Ranges::Diff<LubRanges<View0>,GlbRanges<View1> > d(x0ub,x1lb);
       if (!d()) {
         GECODE_ME_CHECK(b.one_none(home));
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
     }
 
@@ -121,10 +120,10 @@ namespace Gecode { namespace Set { namespace Rel {
       Iter::Ranges::Diff<GlbRanges<View0>,LubRanges<View1> > d(x0lb,x1ub);
       if (d()) {
         GECODE_ME_CHECK(b.zero_none(home));
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       } else if (x0.assigned() && x1.assigned()) {
         GECODE_ME_CHECK(b.one_none(home));
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
     }
 
@@ -135,7 +134,7 @@ namespace Gecode { namespace Set { namespace Rel {
         i(x0ub,x1ub);
       if (!i()) {
         GECODE_ME_CHECK(b.zero_none(home));
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
     }
 
