@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-06-02 21:01:00 +0200 (Wed, 02 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11008 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -667,11 +667,11 @@ namespace Gecode { namespace Set {
     /**
      * \brief Subscribe propagator \a p with propagation condition \a pc to variable
      *
-     * In case \a process is false, the propagator is just subscribed but
-     * not processed for execution (this must be used when creating
+     * In case \a schedule is false, the propagator is just subscribed but
+     * not scheduled for execution (this must be used when creating
      * subscriptions during propagation).
      */
-    void subscribe(Space& home, Propagator& p, PropCond pc, bool process=true);
+    void subscribe(Space& home, Propagator& p, PropCond pc, bool schedule=true);
     /// Cancel subscription of propagator \a p with propagation condition \a pc
     void cancel(Space& home, Propagator& p, PropCond pc);
     /// Subscribe advisor \a a to variable
@@ -693,8 +693,6 @@ namespace Gecode { namespace Set {
 
     /// \name Delta information for advisors
     //@{
-    /// Return modification event
-    static ModEvent modevent(const Delta& d);
     /// Return minimum value just pruned from glb
     static int glbMin(const Delta& d);
     /// Return maximum value just pruned from glb
@@ -717,16 +715,4 @@ namespace Gecode { namespace Set {
 
 #include <gecode/set/var-imp/set.hpp>
 
-namespace Gecode {
-
-  class SetVar;
-
-  /** \brief Traits class for variable implementations and variables */
-  template<>
-  class VarImpVarTraits<Set::SetVarImp> {
-  public:
-    typedef SetVar Var;
-  };
-}
-
 // STATISTICS: set-var
