@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-06-02 14:54:28 +0200 (Wed, 02 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11005 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -136,10 +136,6 @@ namespace Gecode { namespace Set {
    * Support for delta information
    *
    */
-  forceinline ModEvent
-  SetVarImp::modevent(const Delta& d) {
-    return d.modevent();
-  }
   forceinline int
   SetVarImp::glbMin(const Delta& d) {
     return static_cast<const SetDelta&>(d).glbMin();
@@ -279,6 +275,8 @@ namespace Gecode { namespace Set {
 
   forceinline ModEvent
   SetVarImp::include(Space& home, int i, int j) {
+    if (j<i)
+      return ME_SET_NONE;
     BndSetRanges ub(lub);
     Iter::Ranges::Singleton sij(i,j);
     if (!Iter::Ranges::subset(sij,ub)) {
@@ -352,6 +350,8 @@ namespace Gecode { namespace Set {
 
   forceinline ModEvent
   SetVarImp::exclude(Space& home, int i, int j) {
+    if (j<i)
+      return ME_SET_NONE;
     Iter::Ranges::Singleton sij(i,j);
     BndSetRanges lb(glb);
     Iter::Ranges::Inter<Iter::Ranges::Singleton,BndSetRanges> probe(sij,lb);
@@ -513,8 +513,8 @@ namespace Gecode { namespace Set {
    *
    */
   forceinline void
-  SetVarImp::subscribe(Space& home, Propagator& p, PropCond pc, bool process) {
-    SetVarImpBase::subscribe(home,p,pc,assigned(),process);
+  SetVarImp::subscribe(Space& home, Propagator& p, PropCond pc, bool schedule) {
+    SetVarImpBase::subscribe(home,p,pc,assigned(),schedule);
   }
   forceinline void
   SetVarImp::cancel(Space& home, Propagator& p, PropCond pc) {
