@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-11-23 15:38:32 +0100 (Mon, 23 Nov 2009) $ by $Author: schulte $
- *     $Revision: 10098 $
+ *     $Date: 2010-06-29 10:39:13 +0200 (Tue, 29 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11118 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -82,11 +82,10 @@ namespace Gecode { namespace Set {
   };
 
   forceinline
-  ConstantView::ConstantView(void) : ranges(NULL), size(0), domSize(0) {}
+  ConstSetView::ConstSetView(void) : ranges(NULL), size(0), domSize(0) {}
 
   forceinline
-  void
-  ConstantView::init(Space& home, const IntSet& dom) {
+  ConstSetView::ConstSetView(Space& home, const IntSet& dom) {
     size = dom.ranges();
     domSize = 0;
     if (size > 0) {
@@ -103,25 +102,17 @@ namespace Gecode { namespace Set {
     }
   }
 
-  forceinline
-  ConstantView::ConstantView(Space& home, const IntSet& dom) {
-    init(home, dom);
-  }
+  forceinline unsigned int
+  ConstSetView::glbSize(void) const { return domSize; }
+
+  forceinline unsigned int
+  ConstSetView::lubSize(void) const { return domSize; }
+
+  forceinline unsigned int
+  ConstSetView::unknownSize(void) const { return 0; }
 
   forceinline bool
-  ConstantView::assigned(void) const { return true; }
-
-  forceinline unsigned int
-  ConstantView::glbSize(void) const { return domSize; }
-
-  forceinline unsigned int
-  ConstantView::lubSize(void) const { return domSize; }
-
-  forceinline unsigned int
-  ConstantView::unknownSize(void) const { return 0; }
-
-  forceinline bool
-  ConstantView::contains(int i) const {
+  ConstSetView::contains(int i) const {
     for (int j=size; j--; ) {
       if (ranges[2*j+1] < i)
         return false;
@@ -132,54 +123,54 @@ namespace Gecode { namespace Set {
   }
 
   forceinline bool
-  ConstantView::notContains(int i) const {
+  ConstSetView::notContains(int i) const {
     return !contains(i);
   }
 
   forceinline unsigned int
-  ConstantView::cardMin(void) const { return domSize; }
+  ConstSetView::cardMin(void) const { return domSize; }
 
   forceinline unsigned int
-  ConstantView::cardMax(void) const { return domSize; }
+  ConstSetView::cardMax(void) const { return domSize; }
 
   forceinline int
-  ConstantView::lubMin(void) const {
+  ConstSetView::lubMin(void) const {
     return size==0 ? BndSet::MIN_OF_EMPTY : ranges[0];
   }
 
   forceinline int
-  ConstantView::lubMax(void) const {
+  ConstSetView::lubMax(void) const {
     return size==0 ? BndSet::MAX_OF_EMPTY : ranges[size*2-1];
   }
 
   forceinline int
-  ConstantView::glbMin(void) const { return lubMin(); }
+  ConstSetView::glbMin(void) const { return lubMin(); }
 
   forceinline int
-  ConstantView::glbMax(void) const { return lubMax(); }
+  ConstSetView::glbMax(void) const { return lubMax(); }
 
   forceinline ModEvent
-  ConstantView::cardMin(Space&,unsigned int c) {
+  ConstSetView::cardMin(Space&,unsigned int c) {
     return c<=domSize ? ME_SET_NONE : ME_SET_FAILED;
   }
 
   forceinline ModEvent
-  ConstantView::cardMax(Space&,unsigned int c) {
+  ConstSetView::cardMax(Space&,unsigned int c) {
     return c>=domSize ? ME_SET_NONE : ME_SET_FAILED;
   }
 
   forceinline ModEvent
-  ConstantView::include(Space&,int c) {
+  ConstSetView::include(Space&,int c) {
     return contains(c) ? ME_SET_NONE : ME_SET_FAILED;
   }
 
   forceinline ModEvent
-  ConstantView::exclude(Space&,int c) {
+  ConstSetView::exclude(Space&,int c) {
     return contains(c) ? ME_SET_FAILED : ME_SET_NONE;
   }
 
   forceinline ModEvent
-  ConstantView::intersect(Space&,int c) {
+  ConstSetView::intersect(Space&,int c) {
     return (size==0 ||
             (size==1 &&
              ranges[0]==ranges[1] && ranges[0]==c)) ?
@@ -187,13 +178,13 @@ namespace Gecode { namespace Set {
   }
 
   forceinline ModEvent
-  ConstantView::intersect(Space&,int i,int j) {
+  ConstSetView::intersect(Space&,int i,int j) {
     return (glbMin()>=i && glbMax()<=j) ?
       ME_SET_NONE : ME_SET_FAILED;
   }
 
   forceinline ModEvent
-  ConstantView::include(Space&,int i,int j) {
+  ConstSetView::include(Space&,int i,int j) {
     Iter::Ranges::Singleton single(i,j);
     ArrayRanges ar(ranges, size);
     return (single() && Iter::Ranges::subset(single, ar)) ?
@@ -201,7 +192,7 @@ namespace Gecode { namespace Set {
   }
 
   forceinline ModEvent
-  ConstantView::exclude(Space&,int i,int j) {
+  ConstSetView::exclude(Space&,int i,int j) {
     Iter::Ranges::Singleton single(i,j);
     ArrayRanges ar(ranges, size);
     return (single() && Iter::Ranges::subset(single, ar)) ?
@@ -209,55 +200,29 @@ namespace Gecode { namespace Set {
   }
 
   template<class I> ModEvent
-  ConstantView::excludeI(Space&,I& i) {
+  ConstSetView::excludeI(Space&,I& i) {
     Iter::Ranges::IsRangeIter<I>();
     ArrayRanges ar(ranges, size);
     return (i() && Iter::Ranges::subset(i, ar)) ? ME_SET_FAILED : ME_SET_NONE;
   }
 
   template<class I> ModEvent
-  ConstantView::includeI(Space&,I& i) {
+  ConstSetView::includeI(Space&,I& i) {
     Iter::Ranges::IsRangeIter<I>();
     ArrayRanges ar(ranges, size);
     return Iter::Ranges::subset(i, ar) ? ME_SET_NONE : ME_SET_FAILED;
   }
 
   template<class I> ModEvent
-  ConstantView::intersectI(Space&,I& i) {
+  ConstSetView::intersectI(Space&,I& i) {
     Iter::Ranges::IsRangeIter<I>();
     ArrayRanges ar(ranges, size);
     return Iter::Ranges::subset(ar, i) ? ME_SET_NONE : ME_SET_FAILED;
   }
 
   forceinline void
-  ConstantView::schedule(Space& home, Propagator& p, ModEvent me) {
-    return SetView::schedule(home,p,me);
-  }
-  forceinline ModEvent
-  ConstantView::me(const ModEventDelta&) {
-    return ME_SET_NONE;
-  }
-  forceinline ModEventDelta
-  ConstantView::med(ModEvent me) {
-    return SetVarImp::med(me);
-  }
-
-  forceinline void
-  ConstantView::subscribe(Space& home, Propagator& p, PropCond,
-                          bool process) {
-    if (process)
-      schedule(home,p,ME_SET_VAL);
-  }
-  forceinline void
-  ConstantView::cancel(Space&,Propagator&,PropCond) {}
-
-  forceinline void
-  ConstantView::subscribe(Space&, Advisor&) {}
-  forceinline void
-  ConstantView::cancel(Space&,Advisor&) {}
-
-  forceinline void
-  ConstantView::update(Space& home, bool, ConstantView& p) {
+  ConstSetView::update(Space& home, bool share, ConstSetView& p) {
+    ConstView<SetView>::update(home,share,p);
     // dispose old ranges
     if (size > 0)
       home.free<int>(ranges, 2);
@@ -281,45 +246,33 @@ namespace Gecode { namespace Set {
    * Delta information for advisors
    *
    */
-
-  forceinline ModEvent
-  ConstantView::modevent(const Delta&) {
-    GECODE_NEVER;
-    return ME_GEN_NONE;
-  }
-
   forceinline int
-  ConstantView::glbMin(const Delta&) const {
+  ConstSetView::glbMin(const Delta&) const {
     GECODE_NEVER;
     return 0;
   }
-
   forceinline int
-  ConstantView::glbMax(const Delta&) const {
+  ConstSetView::glbMax(const Delta&) const {
     GECODE_NEVER;
     return 0;
   }
-
   forceinline bool
-  ConstantView::glbAny(const Delta&) const {
+  ConstSetView::glbAny(const Delta&) const {
     GECODE_NEVER;
     return false;
   }
-
   forceinline int
-  ConstantView::lubMin(const Delta&) const {
+  ConstSetView::lubMin(const Delta&) const {
     GECODE_NEVER;
     return 0;
   }
-
   forceinline int
-  ConstantView::lubMax(const Delta&) const {
+  ConstSetView::lubMax(const Delta&) const {
     GECODE_NEVER;
     return 0;
   }
-
   forceinline bool
-  ConstantView::lubAny(const Delta&) const {
+  ConstSetView::lubAny(const Delta&) const {
     GECODE_NEVER;
     return false;
   }
@@ -329,9 +282,6 @@ namespace Gecode { namespace Set {
 
 
 
-  forceinline bool
-  EmptyView::assigned(void) const { return true; }
-
   forceinline unsigned int
   EmptyView::glbSize(void) const { return 0; }
 
@@ -415,48 +365,10 @@ namespace Gecode { namespace Set {
     return ME_SET_NONE;
   }
 
-  forceinline void
-  EmptyView::schedule(Space& home, Propagator& p, ModEvent me) {
-    return SetView::schedule(home,p,me);
-  }
-  forceinline ModEvent
-  EmptyView::me(const ModEventDelta&) {
-    return ME_SET_NONE;
-  }
-  forceinline ModEventDelta
-  EmptyView::med(ModEvent me) {
-    return SetVarImp::med(me);
-  }
-
-  forceinline void
-  EmptyView::subscribe(Space& home, Propagator& p, PropCond,
-                       bool process) {
-    if (process)
-      schedule(home,p,ME_SET_VAL);
-  }
-  forceinline void
-  EmptyView::cancel(Space&,Propagator&,PropCond) {}
-  forceinline void
-  EmptyView::subscribe(Space&, Advisor&) {}
-  forceinline void
-  EmptyView::cancel(Space&,Advisor&) {}
-
-
-  forceinline void
-  EmptyView::update(Space&, bool, EmptyView&) {}
-
-
   /*
    * Delta information for advisors
    *
    */
-
-  forceinline ModEvent
-  EmptyView::modevent(const Delta&) {
-    GECODE_NEVER;
-    return ME_GEN_NONE;
-  }
-
   forceinline int
   EmptyView::glbMin(const Delta&) const {
     GECODE_NEVER;
@@ -498,9 +410,6 @@ namespace Gecode { namespace Set {
   forceinline
   UniverseView::UniverseView(void) {}
 
-  forceinline bool
-  UniverseView::assigned(void) const { return true; }
-
   forceinline unsigned int
   UniverseView::glbSize(void) const { return Set::Limits::card; }
 
@@ -589,48 +498,11 @@ namespace Gecode { namespace Set {
       ME_SET_FAILED : ME_SET_NONE;
   }
 
-  forceinline void
-  UniverseView::schedule(Space& home, Propagator& p, ModEvent me) {
-    return SetView::schedule(home,p,me);
-  }
-  forceinline ModEvent
-  UniverseView::me(const ModEventDelta&) {
-    return ME_SET_NONE;
-  }
-  forceinline ModEventDelta
-  UniverseView::med(ModEvent me) {
-    return SetVarImp::med(me);
-  }
-  forceinline void
-  UniverseView::subscribe(Space& home, Propagator& p, PropCond,
-                          bool process) {
-    if (process)
-      schedule(home,p,ME_SET_VAL);
-  }
-  forceinline void
-  UniverseView::cancel(Space&,Propagator&,PropCond) {}
-
-  forceinline void
-  UniverseView::subscribe(Space&,Advisor&) {}
-  forceinline void
-  UniverseView::cancel(Space&,Advisor&) {}
-
-
-  forceinline void
-  UniverseView::update(Space&, bool, UniverseView&) {}
-
 
   /*
    * Delta information for advisors
    *
    */
-
-  forceinline ModEvent
-  UniverseView::modevent(const Delta&) {
-    GECODE_NEVER;
-    return ME_GEN_NONE;
-  }
-
   forceinline int
   UniverseView::glbMin(const Delta&) const {
     GECODE_NEVER;
@@ -762,7 +634,7 @@ namespace Gecode { namespace Set {
    * \ingroup TaskActorSetView
    */
   template<>
-  class LubRanges<ConstantView> {
+  class LubRanges<ConstSetView> {
   private:
     ArrayRanges ar;
   public:
@@ -771,9 +643,9 @@ namespace Gecode { namespace Set {
     /// Default constructor
     LubRanges(void) {}
     /// Initialize with ranges for view \a x
-    LubRanges(const ConstantView& x) : ar(x.ranges,x.size) {}
+    LubRanges(const ConstSetView& x) : ar(x.ranges,x.size) {}
     /// Initialize with ranges for view \a x
-    void init(const ConstantView& x) {
+    void init(const ConstSetView& x) {
       ar.init(x.ranges,x.size);
     }
     //@}
@@ -802,29 +674,27 @@ namespace Gecode { namespace Set {
    * \ingroup TaskActorSetView
    */
   template<>
-  class GlbRanges<ConstantView> : public LubRanges<ConstantView> {
+  class GlbRanges<ConstSetView> : public LubRanges<ConstSetView> {
   public:
     /// \name Constructors and initialization
     //@{
     /// Default constructor
     GlbRanges(void) {}
     /// Initialize with ranges for view \a x
-    GlbRanges(const ConstantView& x) : LubRanges<ConstantView>(x) {}
+    GlbRanges(const ConstSetView& x) : LubRanges<ConstSetView>(x) {}
     /// Initialize with ranges for view \a x
-    void init(const ConstantView& x) {
-      LubRanges<ConstantView>::init(x);
+    void init(const ConstSetView& x) {
+      LubRanges<ConstSetView>::init(x);
     }
     //@}
   };
-}
-
 
   /*
    * Testing
    *
    */
   forceinline bool
-  same(const Set::ConstantView& x, const Set::ConstantView& y) {
+  same(const ConstSetView& x, const ConstSetView& y) {
     if ((x.size != y.size) || (x.domSize != y.domSize))
       return false;
     for (int i=x.size; i--; )
@@ -834,7 +704,7 @@ namespace Gecode { namespace Set {
     return true;
   }
   forceinline bool
-  before(const Set::ConstantView& x, const Set::ConstantView& y) {
+  before(const ConstSetView& x, const ConstSetView& y) {
     if (x.size < y.size)
       return true;
     if (x.domSize < y.domSize)
@@ -848,24 +718,15 @@ namespace Gecode { namespace Set {
 
 
   forceinline bool
-  same(const Set::EmptyView&, const Set::EmptyView&) {
+  same(const EmptyView&, const EmptyView&) {
     return true;
   }
   forceinline bool
-  before(const Set::EmptyView&, const Set::EmptyView&) {
-    return false;
-  }
-
-  forceinline bool
-  same(const Set::UniverseView&, const Set::UniverseView&) {
+  same(const UniverseView&, const UniverseView&) {
     return true;
   }
-  forceinline bool
-  before(const Set::UniverseView&, const Set::UniverseView&) {
-    return false;
-  }
 
-}
+}}
 
 // STATISTICS: set-var
 
