@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-06-29 10:39:13 +0200 (Tue, 29 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11118 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -52,56 +52,64 @@ namespace Gecode { namespace Set {
   SetView::SetView(void) {}
   forceinline
   SetView::SetView(const SetVar& y)
-    : VarViewBase<SetVarImp>(y.var()) {}
+    : VarImpView<SetVarImp>(y.varimp()) {}
   forceinline
   SetView::SetView(SetVarImp* y)
-    : VarViewBase<SetVarImp>(y) {}
+    : VarImpView<SetVarImp>(y) {}
 
   /*
    * Variable information
    *
    */
 
-  forceinline bool
-  SetView::assigned(void)  const {
-    return varimp->assigned();
+  forceinline unsigned int
+  SetView::glbSize(void) const { 
+    return x->glbSize(); 
   }
-
   forceinline unsigned int
-  SetView::glbSize(void) const { return varimp->glbSize(); }
-
+  SetView::lubSize(void) const { 
+    return x->lubSize(); 
+  }
   forceinline unsigned int
-  SetView::lubSize(void) const { return varimp->lubSize(); }
-
-  forceinline unsigned int
-  SetView::unknownSize(void) const { return varimp->lubSize() - varimp->glbSize(); }
-
+  SetView::unknownSize(void) const { 
+    return x->lubSize() - x->glbSize(); 
+  }
   forceinline bool
-  SetView::contains(int i) const { return (varimp->knownIn(i)); }
-
+  SetView::contains(int i) const { 
+    return x->knownIn(i); 
+  }
   forceinline bool
-  SetView::notContains(int i) const { return (varimp->knownOut(i)); }
-
+  SetView::notContains(int i) const { 
+    return x->knownOut(i); 
+  }
   forceinline unsigned int
-  SetView::cardMin(void) const { return varimp->cardMin(); }
-
+  SetView::cardMin(void) const { 
+    return x->cardMin(); 
+  }
   forceinline unsigned int
-  SetView::cardMax(void) const { return varimp->cardMax(); }
-
+  SetView::cardMax(void) const { 
+    return x->cardMax(); 
+  }
   forceinline int
-  SetView::lubMin(void) const { return varimp->lubMin(); }
-
+  SetView::lubMin(void) const { 
+    return x->lubMin(); 
+  }
   forceinline int
-  SetView::lubMax(void) const { return varimp->lubMax(); }
-
+  SetView::lubMax(void) const { 
+    return x->lubMax(); 
+  }
   forceinline int
-  SetView::lubMinN(unsigned int n) const { return varimp->lubMinN(n); }
-
+  SetView::lubMinN(unsigned int n) const { 
+    return x->lubMinN(n); 
+  }
   forceinline int
-  SetView::glbMin(void) const { return varimp->glbMin(); }
-
+  SetView::glbMin(void) const { 
+    return x->glbMin(); 
+  }
   forceinline int
-  SetView::glbMax(void) const { return varimp->glbMax(); }
+  SetView::glbMax(void) const { 
+    return x->glbMax(); 
+  }
 
   /*
    * Tells
@@ -110,71 +118,58 @@ namespace Gecode { namespace Set {
 
   forceinline ModEvent
   SetView::cardMin(Space& home, unsigned int m) {
-    return varimp-> cardMin(home, m);
+    return x->cardMin(home, m);
   }
 
   forceinline ModEvent
   SetView::cardMax(Space& home, unsigned int m) {
-    return varimp-> cardMax(home, m);
+    return x->cardMax(home, m);
   }
 
   forceinline ModEvent
-  SetView::include (Space& home,int from, int to) {
-    return (varimp->include(home,from,to));
+  SetView::include (Space& home, int from, int to) {
+    return x->include(home,from,to);
   }
 
   forceinline ModEvent
-  SetView::include (Space& home,int n) {
-    return (varimp->include(home,n));
+  SetView::include (Space& home, int n) {
+    return x->include(home,n);
   }
 
   forceinline ModEvent
-  SetView::exclude (Space& home,int n) {
-    return (varimp->exclude(home, n));
+  SetView::exclude (Space& home, int n) {
+    return x->exclude(home, n);
   }
 
   forceinline ModEvent
-  SetView::intersect (Space& home,int from, int to) {
-    return (varimp->intersect(home,from,to));
+  SetView::intersect (Space& home, int from, int to) {
+    return x->intersect(home,from,to);
   }
 
   forceinline ModEvent
-  SetView::intersect (Space& home,int n) {
-    return (varimp->intersect(home,n));
+  SetView::intersect (Space& home, int n) {
+    return x->intersect(home,n);
   }
 
   template<class I> ModEvent
   SetView::includeI (Space& home, I& iter) {
     Iter::Ranges::IsRangeIter<I>();
-    return (varimp->includeI(home, iter));
+    return x->includeI(home, iter);
   }
 
   forceinline ModEvent
-  SetView::exclude (Space& home,int from, int to)
-  { return (varimp->exclude(home,from,to)); }
-
+  SetView::exclude (Space& home, int from, int to) { 
+    return x->exclude(home,from,to); 
+  }
   template<class I> ModEvent
   SetView::excludeI(Space& home, I& iter) {
     Iter::Ranges::IsRangeIter<I>();
-    return varimp->excludeI(home, iter);
+    return x->excludeI(home, iter);
   }
-
   template<class I> ModEvent
   SetView::intersectI(Space& home, I& iter) {
     Iter::Ranges::IsRangeIter<I>();
-    return varimp->intersectI(home, iter);
-  }
-
-
-
-  /*
-   * Cloning
-   *
-   */
-
-  forceinline void
-  SetView::update(Space& home, bool share, SetView& y) {
-    varimp = y.varimp->copy(home,share);
+    return x->intersectI(home, iter);
   }
 
 
@@ -228,11 +223,11 @@ namespace Gecode { namespace Set {
 
   forceinline
   LubRanges<SetView>::LubRanges(const SetView& x)
-    : LubRanges<SetVarImp*>(x.var()) {}
+    : LubRanges<SetVarImp*>(x.varimp()) {}
 
   forceinline void
   LubRanges<SetView>::init(const SetView& x) {
-    LubRanges<SetVarImp*>::init(x.var());
+    LubRanges<SetVarImp*>::init(x.varimp());
   }
 
 
@@ -258,11 +253,11 @@ namespace Gecode { namespace Set {
 
   forceinline
   GlbRanges<SetView>::GlbRanges(const SetView& x)
-    : GlbRanges<SetVarImp*>(x.var()) {}
+    : GlbRanges<SetVarImp*>(x.varimp()) {}
 
   forceinline void
   GlbRanges<SetView>::init(const SetView& x) {
-    GlbRanges<SetVarImp*>::init(x.var());
+    GlbRanges<SetVarImp*>::init(x.varimp());
   }
 
 }}
