@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2009-05-05 14:17:32 +0200 (Tue, 05 May 2009) $ by $Author: schulte $
- *     $Revision: 8982 $
+ *     $Date: 2009-10-15 11:39:29 +0200 (Thu, 15 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9919 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,6 +50,21 @@ namespace Gecode { namespace Support {
   }
 
 
+  /*
+   * Mutexes
+   *
+   */
+  forceinline void*
+  Mutex::operator new(size_t s) {
+    return Gecode::heap.ralloc(s);
+  }
+
+  forceinline void
+  Mutex::operator delete(void* p) {
+    Gecode::heap.rfree(p);
+  }
+
+
   /*
    * Locks
    */
@@ -62,6 +77,38 @@ namespace Gecode { namespace Support {
     m.release();
   }
 
+
+  /*
+   * Threads
+   */
+  inline void
+  Thread::Run::run(Runnable* r0) {
+    m.acquire();
+    r = r0;
+    m.release();
+    e.signal();
+  }
+  inline void
+  Thread::run(Runnable* r) {
+    m.acquire();
+    if (idle != NULL) {
+      idle->run(r);
+      idle = idle->n;
+      m.release();
+    } else {
+      m.release();
+      (void) new Run(r);
+    }
+  }
+  forceinline void
+  Thread::Run::operator delete(void* p) {
+    heap.rfree(p);
+  }
+  forceinline void*
+  Thread::Run::operator new(size_t s) {
+    return heap.ralloc(s);
+  }
+
 }}
 
 // STATISTICS: support-any
