@@ -7,8 +7,8 @@
  *     Christian Schulte, 2006
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-06-04 16:13:00 +0200 (Fri, 04 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11028 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -76,14 +76,14 @@ namespace Test { namespace Int {
          for (int i=4; i--; ) {
            if (xoff != 0) {
              IntVar xo(home, xoff, 3+xoff);
-             Gecode::post(home, x[i] == xo-xoff);
+             Gecode::rel(home, x[i] == xo-xoff);
              xa[i] = xo;
            } else {
              xa[i] = x[i];
            }
            if (yoff != 0) {
              IntVar yo(home, yoff, 3+yoff);
-             Gecode::post(home, x[4+i] == yo-yoff);
+             Gecode::rel(home, x[4+i] == yo-yoff);
              ya[i] = yo;
            } else {
              ya[i] = x[4+i];
@@ -112,9 +112,7 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         Gecode::IntVarArgs y(6);
-         for (int i=0; i<6; i++)
-           y[i].init(home,dom);
+         Gecode::IntVarArgs y(home,6,dom);
          for (int i=0; i<6; i++)
            for (int j=0; j<6; j++) {
              Gecode::BoolVar b(home,0,1);
