@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-05-08 13:09:21 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10907 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -102,7 +102,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        LinExprInt(const LinInstr* lis0, const std::string& s)
-         : Test("MiniModel::LinExpr::Int::"+s,4,-3,3), lis(lis0) {}
+         : Test("MiniModel::LinExpr::Int::"+s,4,-3,3), lis(lis0) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int reg[3] = {x[0],x[1],x[2]};
@@ -112,7 +114,7 @@ namespace Test { namespace Int {
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
          Gecode::LinExpr reg[3] = {x[0],x[1],x[2]};
-         rel(home, x[3], IRT_EQ, Gecode::post(home, eval(lis,reg)));
+         rel(home, x[3], IRT_EQ, Gecode::expr(home, eval(lis,reg)));
        }
      };
 
@@ -124,7 +126,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        LinExprBool(const LinInstr* lis0, const std::string& s)
-         : Test("MiniModel::LinExpr::Bool::"+s,4,-3,3), lis(lis0) {}
+         : Test("MiniModel::LinExpr::Bool::"+s,4,-3,3), lis(lis0) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          for (int i=3; i--; )
@@ -139,7 +143,7 @@ namespace Test { namespace Int {
          Gecode::LinExpr reg[3] = {
            channel(home,x[0]),channel(home,x[1]),channel(home,x[2])
          };
-         rel(home, x[3], IRT_EQ, Gecode::post(home, eval(lis,reg)));
+         rel(home, x[3], IRT_EQ, Gecode::expr(home, eval(lis,reg)));
        }
      };
 
@@ -151,7 +155,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        LinExprMixed(const LinInstr* lis0, const std::string& s)
-         : Test("MiniModel::LinExpr::Mixed::"+s,4,-3,3), lis(lis0) {}
+         : Test("MiniModel::LinExpr::Mixed::"+s,4,-3,3), lis(lis0) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          if ((x[2] < 0) || (x[2] > 1))
@@ -165,7 +171,7 @@ namespace Test { namespace Int {
          Gecode::LinExpr reg[3] = {
            x[0],x[1],channel(home,x[2])
          };
-         rel(home, x[3], IRT_EQ, Gecode::post(home, eval(lis,reg)));
+         rel(home, x[3], IRT_EQ, Gecode::expr(home, eval(lis,reg)));
        }
      };
 
@@ -184,7 +190,9 @@ namespace Test { namespace Int {
        LinRelInt(const LinInstr* l_lis0, const LinInstr* r_lis0,
                  Gecode::IntRelType irt0, const std::string& s)
          : Test("MiniModel::LinRel::Int::"+s+"::"+str(irt0),3,-3,3,true),
-           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {}
+           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int l_reg[3] = {x[0],x[1],x[2]};
@@ -199,27 +207,27 @@ namespace Test { namespace Int {
          switch (irt) {
          case IRT_EQ:
            {
-             IntVar x = Gecode::post(home,eval(l_lis,l_reg));
-             IntVar y = Gecode::post(home,eval(r_lis,r_reg));
+             IntVar x = Gecode::expr(home,eval(l_lis,l_reg));
+             IntVar y = Gecode::expr(home,eval(r_lis,r_reg));
              IntArgs a(2, 1,-1);
              IntVarArgs xy(2); xy[0]=x; xy[1]=y;
-             Gecode::post(home, tt(0 == sum(a,xy)));
+             Gecode::rel(home, 0 == sum(a,xy));
            }
            break;
          case IRT_NQ:
-           Gecode::post(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
+           Gecode::rel(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
            break;
          case IRT_LQ:
-           Gecode::post(home, ff(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
+           Gecode::rel(home, !(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
            break;
          case IRT_LE:
-           Gecode::post(home, tt(eval(l_lis,l_reg) < eval(r_lis,r_reg)));
+           Gecode::rel(home, eval(l_lis,l_reg) < eval(r_lis,r_reg));
            break;
          case IRT_GQ:
-           Gecode::post(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
+           Gecode::rel(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
            break;
          case IRT_GR:
-           Gecode::post(home, ff(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
+           Gecode::rel(home, !(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
            break;
          default: GECODE_NEVER;
          }
@@ -232,30 +240,30 @@ namespace Test { namespace Int {
          Gecode::LinExpr r_reg[3] = {x[0],x[1],x[2]};
          switch (irt) {
          case IRT_EQ:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)==eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)==eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_NQ:
-           Gecode::post(home,
-                        tt(eqv(~(eval(l_lis,l_reg)!=eval(r_lis,r_reg)),b)));
+           Gecode::rel(home,
+                       (eval(l_lis,l_reg)!=eval(r_lis,r_reg)) == b);
            break;
          case IRT_LQ:
-           Gecode::post(home,
-                        ff(~(eval(l_lis,l_reg)<=eval(r_lis,r_reg))^b));
+           Gecode::rel(home,
+                       !((eval(l_lis,l_reg)<=eval(r_lis,r_reg))^b));
            break;
          case IRT_LE:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)<eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)<eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_GQ:
-           Gecode::post(home,
-                        tt(eqv(~(eval(l_lis,l_reg)>=eval(r_lis,r_reg)),b)));
+           Gecode::rel(home,
+                       (eval(l_lis,l_reg)>=eval(r_lis,r_reg)) == b);
            break;
          case IRT_GR:
-           Gecode::post(home,
-                        ff(~(eval(l_lis,l_reg)>eval(r_lis,r_reg))^b));
+           Gecode::rel(home,
+                       !((eval(l_lis,l_reg)>eval(r_lis,r_reg))^b));
            break;
          default: GECODE_NEVER;
          }
@@ -276,7 +284,9 @@ namespace Test { namespace Int {
        LinRelBool(const LinInstr* l_lis0, const LinInstr* r_lis0,
                   Gecode::IntRelType irt0, const std::string& s)
          : Test("MiniModel::LinRel::Bool::"+s+"::"+str(irt0),3,0,1,true),
-           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {}
+           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int l_reg[3] = {x[0],x[1],x[2]};
@@ -294,27 +304,27 @@ namespace Test { namespace Int {
          switch (irt) {
          case IRT_EQ:
            {
-             IntVar x = Gecode::post(home,eval(l_lis,l_reg));
-             IntVar y = Gecode::post(home,eval(r_lis,r_reg));
+             IntVar x = Gecode::expr(home,eval(l_lis,l_reg));
+             IntVar y = Gecode::expr(home,eval(r_lis,r_reg));
              IntArgs a(2, -2,2);
              IntVarArgs xy(2); xy[0]=x; xy[1]=y;
-             Gecode::post(home, tt(0 == sum(a,xy)));
+             Gecode::rel(home, 0 == sum(a,xy));
            }
            break;
          case IRT_NQ:
-           Gecode::post(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
+           Gecode::rel(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
            break;
          case IRT_LQ:
-           Gecode::post(home, ff(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
+           Gecode::rel(home, !(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
            break;
          case IRT_LE:
-           Gecode::post(home, tt(eval(l_lis,l_reg) < eval(r_lis,r_reg)));
+           Gecode::rel(home, eval(l_lis,l_reg) < eval(r_lis,r_reg));
            break;
          case IRT_GQ:
-           Gecode::post(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
+           Gecode::rel(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
            break;
          case IRT_GR:
-           Gecode::post(home, ff(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
+           Gecode::rel(home, !(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
            break;
          default: GECODE_NEVER;
          }
@@ -330,30 +340,30 @@ namespace Test { namespace Int {
          Gecode::LinExpr r_reg[3] = {y[0],y[1],y[2]};
          switch (irt) {
          case IRT_EQ:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)==eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)==eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_NQ:
-           Gecode::post(home,
-                        tt(eqv(~(eval(l_lis,l_reg)!=eval(r_lis,r_reg)),b)));
+           Gecode::rel(home,
+                       (eval(l_lis,l_reg)!=eval(r_lis,r_reg)) == b);
            break;
          case IRT_LQ:
-           Gecode::post(home,
-                        ff(~(eval(l_lis,l_reg)<=eval(r_lis,r_reg))^b));
+           Gecode::rel(home,
+                       !((eval(l_lis,l_reg)<=eval(r_lis,r_reg))^b));
            break;
          case IRT_LE:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)<eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)<eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_GQ:
-           Gecode::post(home,
-                        tt(eqv(~(eval(l_lis,l_reg)>=eval(r_lis,r_reg)),b)));
+           Gecode::rel(home,
+                       (eval(l_lis,l_reg)>=eval(r_lis,r_reg)) == b);
            break;
          case IRT_GR:
-           Gecode::post(home,
-                        ff(~(eval(l_lis,l_reg)>eval(r_lis,r_reg))^b));
+           Gecode::rel(home,
+                       !((eval(l_lis,l_reg)>eval(r_lis,r_reg))^b));
            break;
          default: GECODE_NEVER;
          }
@@ -374,7 +384,9 @@ namespace Test { namespace Int {
        LinRelMixed(const LinInstr* l_lis0, const LinInstr* r_lis0,
                    Gecode::IntRelType irt0, const std::string& s)
          : Test("MiniModel::LinRel::Mixed::"+s+"::"+str(irt0),6,0,1,true),
-           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {}
+           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int l_reg[3] = {x[0],x[1],x[2]};
@@ -389,22 +401,22 @@ namespace Test { namespace Int {
                                      channel(home,x[5])};
          switch (irt) {
          case IRT_EQ:
-           Gecode::post(home, tt(0 == eval(l_lis,l_reg) - eval(r_lis,r_reg)));
+           Gecode::rel(home, 0 == eval(l_lis,l_reg) - eval(r_lis,r_reg));
            break;
          case IRT_NQ:
-           Gecode::post(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
+           Gecode::rel(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
            break;
          case IRT_LQ:
-           Gecode::post(home, ff(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
+           Gecode::rel(home, !(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
            break;
          case IRT_LE:
-           Gecode::post(home, tt(eval(l_lis,l_reg) < eval(r_lis,r_reg)));
+           Gecode::rel(home, eval(l_lis,l_reg) < eval(r_lis,r_reg));
            break;
          case IRT_GQ:
-           Gecode::post(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
+           Gecode::rel(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
            break;
          case IRT_GR:
-           Gecode::post(home, ff(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
+           Gecode::rel(home, !(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
            break;
          default: GECODE_NEVER;
          }
@@ -418,33 +430,33 @@ namespace Test { namespace Int {
                                      channel(home,x[5])};
          switch (irt) {
          case IRT_EQ:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)==eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)==eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_NQ:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)!=eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)!=eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_LQ:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)<=eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)<=eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_LE:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)<eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)<eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_GQ:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)>=eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)>=eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          case IRT_GR:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)>eval(r_lis,r_reg))),
+           rel(home, Gecode::expr(home,
+                                  (eval(l_lis,l_reg)>eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
          default: GECODE_NEVER;
