@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-06-04 16:13:00 +0200 (Fri, 04 Jun 2010) $ by $Author: schulte $
+ *     $Revision: 11028 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -178,7 +178,7 @@ namespace Test {
           {
             IntVarArgs y(6);
             for (int i=0; i<6; i++)
-              y[i].init(*this, s.x[i].val(), s.x[i].val());
+              y[i] = IntVar(*this, s.x[i].val(), s.x[i].val());
             lex(*this, x, (htc == HTC_LEX_LE) ? IRT_LE : IRT_GR, y);
             break;
           }
@@ -187,15 +187,15 @@ namespace Test {
           {
             IntVarArgs y(6);
             for (int i=0; i<6; i++)
-              y[i].init(*this, s.x[i].val(), s.x[i].val());
+              y[i] = IntVar(*this, s.x[i].val(), s.x[i].val());
             IntVar xs(*this, -18, 18);
             IntVar ys(*this, -18, 18);
-            post(*this, x[0]+x[1]+x[2]-x[3]-x[4]-x[5] == xs);
-            post(*this, y[0]+y[1]+y[2]-y[3]-y[4]-y[5] == ys);
+            rel(*this, x[0]+x[1]+x[2]-x[3]-x[4]-x[5] == xs);
+            rel(*this, y[0]+y[1]+y[2]-y[3]-y[4]-y[5] == ys);
             rel(*this,
-                abs(*this,xs),
+                expr(*this,abs(xs)),
                 (htc == HTC_BAL_LE) ? IRT_LE : IRT_GR,
-                abs(*this,ys));
+                expr(*this,abs(ys)));
             break;
           }
         }
