@@ -7,8 +7,8 @@
  *     Guido Tack, 2005
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-05-08 12:56:03 +0200 (Sat, 08 May 2010) $ by $Author: tack $
+ *     $Revision: 10906 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -393,8 +393,8 @@ namespace Test { namespace Set {
       }
       /// Post constraint on \a x
       virtual void post(Space& home, SetVarArray& x, IntVarArray& y) {
-        Gecode::post(home, minWeight <= y[0]);
-        Gecode::post(home, maxWeight >= y[0]);
+        Gecode::rel(home, minWeight <= y[0]);
+        Gecode::rel(home, maxWeight >= y[0]);
         Gecode::weights(home, elements, weights, x[0], y[0]);
       }
     };
